/* Generated by Nim Compiler v1.6.14 */
#define NIM_INTBITS 64

#include "nimbase.h"
#include <string.h>
#undef LANGUAGE_C
#undef MIPSEB
#undef MIPSEL
#undef PPC
#undef R3000
#undef R4000
#undef i386
#undef linux
#undef mips
#undef near
#undef far
#undef powerpc
#undef unix
#define nimfr_(x, y)
#define nimln_(x, y)
typedef struct tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw;
typedef struct tyObject_TContext__TE0bwjD2I16QW6s9c4AgPvw tyObject_TContext__TE0bwjD2I16QW6s9c4AgPvw;
typedef struct tyObject_TIdTable__Cs7vbulfMjKciTA2Uv9b6vQ tyObject_TIdTable__Cs7vbulfMjKciTA2Uv9b6vQ;
typedef struct tySequence__ZQPym9bf1jM5qaSn7LUXMKA tySequence__ZQPym9bf1jM5qaSn7LUXMKA;
typedef struct tyObject_TSym__3r34mwqcVmg5JFNmiaVncw tyObject_TSym__3r34mwqcVmg5JFNmiaVncw;
typedef struct tyObject_LayeredIdTablecolonObjectType___9aSR8D74Pb4ozXN6gEJ9a1Pw tyObject_LayeredIdTablecolonObjectType___9aSR8D74Pb4ozXN6gEJ9a1Pw;
typedef struct TNimType TNimType;
typedef struct TNimNode TNimNode;
typedef struct tyObject_TReplTypeVars__itU2h89a2PcJoJ5bHADfePw tyObject_TReplTypeVars__itU2h89a2PcJoJ5bHADfePw;
typedef struct tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw;
typedef struct tyObject_TPassContext__dmp6pRpfXxJk6gIZHkm7dw tyObject_TPassContext__dmp6pRpfXxJk6gIZHkm7dw;
typedef struct RootObj RootObj;
typedef struct tyObject_IdGeneratorcolonObjectType___WVCsDyf9bR1PcjDFjcjm9bRg tyObject_IdGeneratorcolonObjectType___WVCsDyf9bR1PcjDFjcjm9bRg;
typedef struct tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA;
typedef struct tyObject_TScope__9aTSl1tODXnq8aZe4E3GxoQ tyObject_TScope__9aTSl1tODXnq8aZe4E3GxoQ;
typedef struct tySequence__9boKiNhY9cnRQF2k9b9a9bGKbrA tySequence__9boKiNhY9cnRQF2k9b9a9bGKbrA;
typedef struct tyObject_TProcCon__9aK41DZ7WNm5NSRfb1CbcRA tyObject_TProcCon__9aK41DZ7WNm5NSRfb1CbcRA;
typedef struct tyObject_TMatchedConcept__0kS5yo4t68pnIalDqA39crw tyObject_TMatchedConcept__0kS5yo4t68pnIalDqA39crw;
typedef struct tySequence__ed0C0uAUZPhvw3RAc5hfYg tySequence__ed0C0uAUZPhvw3RAc5hfYg;
typedef struct tySequence__vvBerF0axaNtu9aMA2gnsrA tySequence__vvBerF0axaNtu9aMA2gnsrA;
typedef struct tySequence__9c3OY0aBmSBgwdsnBAPf4Ag tySequence__9c3OY0aBmSBgwdsnBAPf4Ag;
typedef struct tyObject_PackedSet__THXDbzJSs2hcC9a33en2pdw tyObject_PackedSet__THXDbzJSs2hcC9a33en2pdw;
typedef struct tyObject_TrunkcolonObjectType___2fEZuM4UuXkgO9bDnaMLLWg tyObject_TrunkcolonObjectType___2fEZuM4UuXkgO9bDnaMLLWg;
typedef struct tySequence__q9cq1Li6c1nMjHpacEbCj0g tySequence__q9cq1Li6c1nMjHpacEbCj0g;
typedef struct tyObject_TStrTable__CJQ42V2zij8fd39a9aMiwtZw tyObject_TStrTable__CJQ42V2zij8fd39a9aMiwtZw;
typedef struct tyObject_TCtx__CRPlhL1hATwZc5hefTGOQQ tyObject_TCtx__CRPlhL1hATwZc5hefTGOQQ;
typedef struct tySequence__yH9bx9bpa6jqsU89cxjyTAlPQ tySequence__yH9bx9bpa6jqsU89cxjyTAlPQ;
typedef struct tyObject_TIdent__PKDcQ7dqdhiSW9c9cXUFFpMg tyObject_TIdent__PKDcQ7dqdhiSW9c9cXUFFpMg;
typedef struct tyObject_IdentCachecolonObjectType___ssh0vzVb9aCQuB6ShpimfIQ tyObject_IdentCachecolonObjectType___ssh0vzVb9aCQuB6ShpimfIQ;
typedef struct tyObject_ModuleGraphcolonObjectType___nOSrcYqJTxXt2ptNc0gnWg tyObject_ModuleGraphcolonObjectType___nOSrcYqJTxXt2ptNc0gnWg;
typedef struct NimStringDesc NimStringDesc;
typedef struct TGenericSeq TGenericSeq;
typedef struct tySequence__Jhh6ks9carRtwV9aOuM8yMNw tySequence__Jhh6ks9carRtwV9aOuM8yMNw;
typedef struct tyObject_HashSet__qEsCgvAiLX6rSzzn9cFnYvQ tyObject_HashSet__qEsCgvAiLX6rSzzn9cFnYvQ;
typedef struct tySequence__Bis5AbpONWcIRrPyPJS8Yw tySequence__Bis5AbpONWcIRrPyPJS8Yw;
typedef struct tyObject_Table__7ACYz5IhOEwzTBvwo6BO9bg tyObject_Table__7ACYz5IhOEwzTBvwo6BO9bg;
typedef struct tySequence__E8pi9b5QNahsURYzXMjh3qw tySequence__E8pi9b5QNahsURYzXMjh3qw;
typedef struct tyObject_Table__g9cTlJykWlQLKMuaRBpUEZg tyObject_Table__g9cTlJykWlQLKMuaRBpUEZg;
typedef struct tySequence__XDpbjnuseLNZDGLBQ2Qzow tySequence__XDpbjnuseLNZDGLBQ2Qzow;
typedef struct tyObject_Table__cBohObSCAwRxvYFXQHv2wA tyObject_Table__cBohObSCAwRxvYFXQHv2wA;
typedef struct tySequence__QqvaCqCpEE1QmQZbcZLi5A tySequence__QqvaCqCpEE1QmQZbcZLi5A;
typedef struct tyObject_TIdObj__1qw9bcK4rZXhGbJEJhkKQFA tyObject_TIdObj__1qw9bcK4rZXhGbJEJhkKQFA;
typedef struct tyObject_ItemId__wg9aowaxscbUe2F0nV9btZLg tyObject_ItemId__wg9aowaxscbUe2F0nV9btZLg;
typedef struct tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw;
typedef struct tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ;
typedef struct tyObject_TLib__W49cDqPTe2Tvc1mw7CVZOFg tyObject_TLib__W49cDqPTe2Tvc1mw7CVZOFg;
typedef struct tySequence__IeU9azYSNIK3V9b36Ir6NZcw tySequence__IeU9azYSNIK3V9b36Ir6NZcw;
typedef struct tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ;
typedef struct tySequence__RNhZxf20g9beyq5VBOGxhDg tySequence__RNhZxf20g9beyq5VBOGxhDg;
typedef struct tySequence__JbK5aK9aVhc9cJZzQYg1wQlQ tySequence__JbK5aK9aVhc9cJZzQYg1wQlQ;
typedef struct tySequence__lFbCtu5P2Kf7YDYtGjkxAQ tySequence__lFbCtu5P2Kf7YDYtGjkxAQ;
typedef struct tyObject_Table__nODIJ5l6JnEl9a6LYuqISLA tyObject_Table__nODIJ5l6JnEl9a6LYuqISLA;
typedef struct tySequence__ijtae5OneaLys0hN9alAicA tySequence__ijtae5OneaLys0hN9alAicA;
typedef struct tyObject_Table__s3itmS9cUUFQ19alF7UA0T1w tyObject_Table__s3itmS9cUUFQ19alF7UA0T1w;
typedef struct tySequence__SerjNoUujW2dUouVBrJiCw tySequence__SerjNoUujW2dUouVBrJiCw;
typedef struct tyObject_Table__r0v8BdcBPKhl73K8p2VMUA tyObject_Table__r0v8BdcBPKhl73K8p2VMUA;
typedef struct tySequence__K9agbtcb0qPZuSJFXB9cTe6g tySequence__K9agbtcb0qPZuSJFXB9cTe6g;
typedef struct tyObject_Table__KsPP7K7LW9aa3YAq1XN9cDZg tyObject_Table__KsPP7K7LW9aa3YAq1XN9cDZg;
typedef struct tySequence__m88qdML9cQOuqGAQn6XWL1A tySequence__m88qdML9cQOuqGAQn6XWL1A;
typedef struct tyObject_Table__1hIWbTQWYT4BmhdESze57A tyObject_Table__1hIWbTQWYT4BmhdESze57A;
typedef struct tySequence__naEbXEp9b9aiW1zXJorqf9cXQ tySequence__naEbXEp9b9aiW1zXJorqf9cXQ;
typedef struct tyObject_Table__9cHFtxtpgztIcDsypRz9byKw tyObject_Table__9cHFtxtpgztIcDsypRz9byKw;
typedef struct tySequence__7lEisrXlQEzwtUKW5pzRCw tySequence__7lEisrXlQEzwtUKW5pzRCw;
typedef struct tyObject_PackedConfig__aqQhF9bElTH51s7bVamv3vA tyObject_PackedConfig__aqQhF9bElTH51s7bVamv3vA;
typedef struct tyObject_Table__imojfg883tkWsWJwyshGqQ tyObject_Table__imojfg883tkWsWJwyshGqQ;
typedef struct tySequence__fdmz6VkIf1ewwrssKYqRFg tySequence__fdmz6VkIf1ewwrssKYqRFg;
typedef struct tyObject_Table__BCPh85PHtwxox9bv7NLFrlg tyObject_Table__BCPh85PHtwxox9bv7NLFrlg;
typedef struct tySequence__kxu4GK0onha2t9bo86mdVAg tySequence__kxu4GK0onha2t9bo86mdVAg;
typedef struct tySequence__48JTohSgTy339bRxHzUD8KA tySequence__48JTohSgTy339bRxHzUD8KA;
typedef struct tyObject_Table__mLYbj79bHyPPDPv4GGJx9bqA tyObject_Table__mLYbj79bHyPPDPv4GGJx9bqA;
typedef struct tySequence__KgiZ29chkJAD01p9aLRB32qw tySequence__KgiZ29chkJAD01p9aLRB32qw;
typedef struct tyObject_Table__LM44poVdVEn4Mo4N4L8c3A tyObject_Table__LM44poVdVEn4Mo4N4L8c3A;
typedef struct tySequence__rkYRZrbHVYL3nhXlQW3K9bw tySequence__rkYRZrbHVYL3nhXlQW3K9bw;
typedef struct tySequence__IRFEb1e9bxgbJLuB5xrdZsQ tySequence__IRFEb1e9bxgbJLuB5xrdZsQ;
typedef struct tyObject_Table__sEMwnZ9aATDhH19cNIt9bn9cyQ tyObject_Table__sEMwnZ9aATDhH19cNIt9bn9cyQ;
typedef struct tySequence__YmPd0eWfcTfrVYrthlXPYA tySequence__YmPd0eWfcTfrVYrthlXPYA;
typedef struct tyObject_Table__WtPprFMQ6tkKi9bQSH3IVpw tyObject_Table__WtPprFMQ6tkKi9bQSH3IVpw;
typedef struct tySequence__fIB1rTQ55aFonoft9a9bmljQ tySequence__fIB1rTQ55aFonoft9a9bmljQ;
typedef struct tyObject_Table__9cOd7jTOg5Zc4i0IfnGho1Q tyObject_Table__9cOd7jTOg5Zc4i0IfnGho1Q;
typedef struct tySequence__Hz5SYwQU29b9aFLt09blvVQPg tySequence__Hz5SYwQU29b9aFLt09blvVQPg;
typedef struct tyObject_Table__YnoEqrDMrd9cI9bBg8gj5H3g tyObject_Table__YnoEqrDMrd9cI9bBg8gj5H3g;
typedef struct tySequence__squ9b9bUH4OLHf6cEMrt6hVA tySequence__squ9b9bUH4OLHf6cEMrt6hVA;
typedef struct tyObject_Table__R7JnJQEipxxOlJWXQz7jWg tyObject_Table__R7JnJQEipxxOlJWXQz7jWg;
typedef struct tySequence__3G9aA9cLXaPxuRxMKm3anacQ tySequence__3G9aA9cLXaPxuRxMKm3anacQ;
typedef struct tySequence__bPFv6ypvvCX2A9a9al8utL2Q tySequence__bPFv6ypvvCX2A9a9al8utL2Q;
typedef struct tyObject_Operators__dR4s9bCO53rZjV9a30JJfUOg tyObject_Operators__dR4s9bCO53rZjV9a30JJfUOg;
typedef struct tySequence__vKogasEnJSPhbQmA8r4Y9aA tySequence__vKogasEnJSPhbQmA8r4Y9aA;
typedef struct tyTuple__kN8up2W6YKc5YA9avn5mV5w tyTuple__kN8up2W6YKc5YA9avn5mV5w;
typedef struct tySequence__dlD6tEGzYLLpKVq3XwuFlA tySequence__dlD6tEGzYLLpKVq3XwuFlA;
typedef struct tyObject_LazyType__wgv9a1JCOBXm9azerxcvz5gQ tyObject_LazyType__wgv9a1JCOBXm9azerxcvz5gQ;
typedef struct tyObject_FullId__L64puUgQnoQ6OMvT9c6V9cPg tyObject_FullId__L64puUgQnoQ6OMvT9c6V9cPg;
typedef struct tyObject_PackedItemId__QkYBSICiQaMI6SmH4FJVoQ tyObject_PackedItemId__QkYBSICiQaMI6SmH4FJVoQ;
typedef struct tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g;
typedef struct tyObject_CellSeq__nav876ELHgxScHhs30CKiA tyObject_CellSeq__nav876ELHgxScHhs30CKiA;
typedef struct tyObject_GcHeap__ZRn9bWCksoiGwT2drZZzyWQ tyObject_GcHeap__ZRn9bWCksoiGwT2drZZzyWQ;
typedef struct tyObject_GcStack__qFeGMKlnq6c9cTM2vPWycQQ tyObject_GcStack__qFeGMKlnq6c9cTM2vPWycQQ;
typedef struct tyObject_MemRegion__6QRscFDo4mEwbg9aL76vDGQ tyObject_MemRegion__6QRscFDo4mEwbg9aL76vDGQ;
typedef struct tyObject_SmallChunk__eUrTKmsk1Dqt5tm2WUT2Lw tyObject_SmallChunk__eUrTKmsk1Dqt5tm2WUT2Lw;
typedef struct tyObject_BigChunk__39bC3HTk2w4NGDjG74oNjmA tyObject_BigChunk__39bC3HTk2w4NGDjG74oNjmA;
typedef struct tyObject_LLChunk__Fjkr5Ya6Zl0UoUGxG047hA tyObject_LLChunk__Fjkr5Ya6Zl0UoUGxG047hA;
typedef struct tyObject_IntSet__WrQriiGmHk59cB1lNPtGo6A tyObject_IntSet__WrQriiGmHk59cB1lNPtGo6A;
typedef struct tyObject_Trunk__Ju1AURWHenTn3cJwAjbUhg tyObject_Trunk__Ju1AURWHenTn3cJwAjbUhg;
typedef struct tyObject_AvlNode__aGkK1t9a0WoXjpugXR6FWpw tyObject_AvlNode__aGkK1t9a0WoXjpugXR6FWpw;
typedef struct tyObject_HeapLinks__5IkCDh5QlsYpsfEMJf6zNw tyObject_HeapLinks__5IkCDh5QlsYpsfEMJf6zNw;
typedef struct tyTuple__p2vAp9cQ6YrpDq9cI3XzEDWA tyTuple__p2vAp9cQ6YrpDq9cI3XzEDWA;
typedef struct tyObject_GcStat__OG9ams3mtFJyICkjTOHbc9bg tyObject_GcStat__OG9ams3mtFJyICkjTOHbc9bg;
typedef struct tyObject_CellSet__A0mJvGLunfUxGkLUtesjdA tyObject_CellSet__A0mJvGLunfUxGkLUtesjdA;
typedef struct tyObject_PageDesc__N7tjEodqPVJaQ6oKQW8YfQ tyObject_PageDesc__N7tjEodqPVJaQ6oKQW8YfQ;
typedef struct tyTuple__RWXAsQlFoGYyEQZp1G65sg tyTuple__RWXAsQlFoGYyEQZp1G65sg;
typedef struct tySequence__m4PVWjcAAjfxlwJxLkKn8A tySequence__m4PVWjcAAjfxlwJxLkKn8A;
typedef struct tyObject_LazySym__Xts9a2Mw4b4jtq73p6MrfJg tyObject_LazySym__Xts9a2Mw4b4jtq73p6MrfJg;
typedef struct tyObject_TIdPair__CEfaiHL4gHg86NKgeeQ7lA tyObject_TIdPair__CEfaiHL4gHg86NKgeeQ7lA;
typedef struct tyObject_ImportedModule__ABXo2nVfMtcWNYv5zEiXDg tyObject_ImportedModule__ABXo2nVfMtcWNYv5zEiXDg;
typedef struct tyObject_TOptionEntry__KcSoeh10J9aas3WZevEUD7Q tyObject_TOptionEntry__KcSoeh10J9aas3WZevEUD7Q;
typedef struct tyObject_TInstantiationPair__d4lcZMnmQK2Jh2jYkdgB4w tyObject_TInstantiationPair__d4lcZMnmQK2Jh2jYkdgB4w;
typedef struct tyObject_TInstantiation__ScJwrSJM8Lp9ahM9b3AS1apA tyObject_TInstantiation__ScJwrSJM8Lp9ahM9b3AS1apA;
typedef struct tyTuple__8vGER9aaTtt9bUk9avNQ3fEIg tyTuple__8vGER9aaTtt9bUk9avNQ3fEIg;
typedef struct tyTuple__NAaJgGVgNmlGoqmiWxdOHQ tyTuple__NAaJgGVgNmlGoqmiWxdOHQ;
typedef struct tyTuple__1v9bKyksXWMsm0vNwmZ4EuQ tyTuple__1v9bKyksXWMsm0vNwmZ4EuQ;
typedef struct tyTuple__47w2DboNEPf69aPgubZdd7Q tyTuple__47w2DboNEPf69aPgubZdd7Q;
typedef struct tyTuple__VbApVidEWCFLq9a29bPtaS7A tyTuple__VbApVidEWCFLq9a29bPtaS7A;
typedef struct tySequence__k7EQb9bN3Uhl608xoPGMRJA tySequence__k7EQb9bN3Uhl608xoPGMRJA;
typedef struct tyTuple__toqrUPSdp8zSxOdlxMJj9cA tyTuple__toqrUPSdp8zSxOdlxMJj9cA;
typedef struct tyTuple__EbsafWGli8bW2GRJQ9apsjA tyTuple__EbsafWGli8bW2GRJQ9apsjA;
typedef struct tySequence__qwqHTkRvwhrRyENtudHQ7g tySequence__qwqHTkRvwhrRyENtudHQ7g;
typedef struct tyObject_Iface__4y9aWdJBxraQYTl5Pa1NMuQ tyObject_Iface__4y9aWdJBxraQYTl5Pa1NMuQ;
typedef struct tySequence__qeAsXh2i1GAL5Nl0g3OP8g tySequence__qeAsXh2i1GAL5Nl0g3OP8g;
typedef struct tyObject_LoadedModule__fihS6xbKhtLC0fhM28Cpeg tyObject_LoadedModule__fihS6xbKhtLC0fhM28Cpeg;
typedef struct tyObject_PackedModule__Lx6uQ9baEALysaHmfFGXw9ag tyObject_PackedModule__Lx6uQ9baEALysaHmfFGXw9ag;
typedef struct tySequence__PXIzfWocnrafGz5p3CP5LA tySequence__PXIzfWocnrafGz5p3CP5LA;
typedef struct tySequence__9bAGqSvkAaFL9bWjsEPslrFA tySequence__9bAGqSvkAaFL9bWjsEPslrFA;
typedef struct tyObject_PackedTree__om9aqqVmbmBPgd8MeBkGtqg tyObject_PackedTree__om9aqqVmbmBPgd8MeBkGtqg;
typedef struct tySequence__4Murtwnm0Fyc7F9acrytEXw tySequence__4Murtwnm0Fyc7F9acrytEXw;
typedef struct tySequence__b89aLriiJnVTD186H6zNIgg tySequence__b89aLriiJnVTD186H6zNIgg;
typedef struct tySequence__wE9cZkGC9cv7Iz9ckZOIyaW9aw tySequence__wE9cZkGC9cv7Iz9ckZOIyaW9aw;
typedef struct tySequence__QnmOtn1Iv4LvxOXoMn8Rbg tySequence__QnmOtn1Iv4LvxOXoMn8Rbg;
typedef struct tySequence__oKtVqsc9bQVCNyrijELM4OQ tySequence__oKtVqsc9bQVCNyrijELM4OQ;
typedef struct tySequence__qy6Iwdy00wN560qud54HTg tySequence__qy6Iwdy00wN560qud54HTg;
typedef struct tySequence__k67v9bwvvQDmS1ynyGGUbeQ tySequence__k67v9bwvvQDmS1ynyGGUbeQ;
typedef struct tySequence__cLsClAAfd0MKkoBQVyvdvw tySequence__cLsClAAfd0MKkoBQVyvdvw;
typedef struct tySequence__sM4lkSb7zS6F7OVMvW9cffQ tySequence__sM4lkSb7zS6F7OVMvW9cffQ;
typedef struct tySequence__q9bTuOB0JXh1iZ3CSGdRLbg tySequence__q9bTuOB0JXh1iZ3CSGdRLbg;
typedef struct tySequence__DPZr9aMyRppVlNZ9ajSyOZ9bw tySequence__DPZr9aMyRppVlNZ9ajSyOZ9bw;
typedef struct tyObject_BiTable__f1TRECC4Lgx6Suak6pB8oQ tyObject_BiTable__f1TRECC4Lgx6Suak6pB8oQ;
typedef struct tyObject_BiTable__YFXXoy9ajAIwHK4kQgVvjcw tyObject_BiTable__YFXXoy9ajAIwHK4kQgVvjcw;
typedef struct tySequence__IHUFRsFxZNv7YydiUO2esQ tySequence__IHUFRsFxZNv7YydiUO2esQ;
typedef struct tyObject_Table__jSCM9c8LtAedYb1zTNR73sQ tyObject_Table__jSCM9c8LtAedYb1zTNR73sQ;
typedef struct tySequence__C3r8jsj9chA4sIlYfDN5aDw tySequence__C3r8jsj9chA4sIlYfDN5aDw;
typedef struct tyObject_PackedEncoder__ftUl9bxYRlbT5ToKkxHdbfQ tyObject_PackedEncoder__ftUl9bxYRlbT5ToKkxHdbfQ;
typedef struct tyObject_Table__7OytuYts9c9a3BX9aQNPGI0gQ tyObject_Table__7OytuYts9c9a3BX9aQNPGI0gQ;
typedef struct tySequence__9cnx3zXnWzeclW8Ko4oUgAQ tySequence__9cnx3zXnWzeclW8Ko4oUgAQ;
typedef struct tyTuple__UluY8x0Nj6cp9b0o88wJ0lg tyTuple__UluY8x0Nj6cp9b0o88wJ0lg;
typedef struct tyTuple__rZZA0skon1OsHdiEvT8RZQ tyTuple__rZZA0skon1OsHdiEvT8RZQ;
typedef struct tySequence__6OFCSvqRaxyEgUqWtnZSlw tySequence__6OFCSvqRaxyEgUqWtnZSlw;
typedef struct tyObject_LazyInstantiation__0l1i6PfjQKnMEvpGMAoN8Q tyObject_LazyInstantiation__0l1i6PfjQKnMEvpGMAoN8Q;
typedef struct tySequence__UnGSk9aaLosDroi2QDrlOfQ tySequence__UnGSk9aaLosDroi2QDrlOfQ;
typedef struct tyTuple__q13Zt16VkCqu6Zg5jWqwHA tyTuple__q13Zt16VkCqu6Zg5jWqwHA;
typedef struct tyTuple__aWN9bNzF9bubXNJV9ciomgpfA tyTuple__aWN9bNzF9bubXNJV9ciomgpfA;
typedef struct tyTuple__RmGJuqOgEaHckHndh0LEsw tyTuple__RmGJuqOgEaHckHndh0LEsw;
typedef struct tyTuple__xYhUhS7X82rKTqbT9bRfCnw tyTuple__xYhUhS7X82rKTqbT9bRfCnw;
typedef struct tyTuple__1mtQ8sCEE7DbfIuQciv9b5Q tyTuple__1mtQ8sCEE7DbfIuQciv9b5Q;
typedef struct tyTuple__xDU9bZmv1ZbZkJDaATBekIQ tyTuple__xDU9bZmv1ZbZkJDaATBekIQ;
typedef struct tyTuple__J4cxakKjhKxTIJR9bojMmXw tyTuple__J4cxakKjhKxTIJR9bojMmXw;
typedef struct tySequence__i89c5kdtWKzK3OEiI81pkkw tySequence__i89c5kdtWKzK3OEiI81pkkw;
typedef struct tyObject_SymInfoPair__SjZT5Rln3r9befMWWSryQ0A tyObject_SymInfoPair__SjZT5Rln3r9befMWWSryQ0A;
typedef struct tyTuple__VwWg1orPZ9b5Rg9aZAI6SIaQ tyTuple__VwWg1orPZ9b5Rg9aZAI6SIaQ;
typedef struct tySequence__GR8qmV1kNRcoQ2g76VFy3A tySequence__GR8qmV1kNRcoQ2g76VFy3A;
typedef struct tyObject_SuggestcolonObjectType___VUPO9alfTq2Ar9a7ZtY9cSPDg tyObject_SuggestcolonObjectType___VUPO9alfTq2Ar9a7ZtY9cSPDg;
typedef struct tyTuple__a7QginWFapakKbWJBJ2vfA tyTuple__a7QginWFapakKbWJBJ2vfA;
typedef struct tyTuple__mPT6B9cVWqwVnWb1Fxx9bgyA tyTuple__mPT6B9cVWqwVnWb1Fxx9bgyA;
typedef struct tyTuple__OJFzEczluV8Jmo9bRpBfkzw tyTuple__OJFzEczluV8Jmo9bRpBfkzw;
typedef struct tyTuple__kbX6x85REySUrk9auORL0vw tyTuple__kbX6x85REySUrk9auORL0vw;
typedef struct tyTuple__F3gkSrMB1qp2Tvf9bixVXwg tyTuple__F3gkSrMB1qp2Tvf9bixVXwg;
typedef struct tyTuple__Ah6ua9a8WyUOs9aO9afW59cy0g tyTuple__Ah6ua9a8WyUOs9aO9afW59cy0g;
typedef struct tyObject_BTree__R2EgvhuH9cLMYvSPesdcu5Q tyObject_BTree__R2EgvhuH9cLMYvSPesdcu5Q;
typedef struct tyObject_NodecolonObjectType___NOM0ZpqV9bLtofkCilAnZ8A tyObject_NodecolonObjectType___NOM0ZpqV9bLtofkCilAnZ8A;
typedef struct tyTuple__nF9cH4hinXgGEUwO4G2bshw tyTuple__nF9cH4hinXgGEUwO4G2bshw;
typedef struct tyTuple__0q9cmhneJEKnQERTpXXdz6Q tyTuple__0q9cmhneJEKnQERTpXXdz6Q;
typedef struct tyObject_PackedNode__9aA1ZskrZ0b0RCXxY4Hw8YA tyObject_PackedNode__9aA1ZskrZ0b0RCXxY4Hw8YA;
typedef struct tyObject_PackedLineInfo__wqhF27DCtLcrB2XHUZKKiA tyObject_PackedLineInfo__wqhF27DCtLcrB2XHUZKKiA;
typedef struct tyTuple__Izx9aRSX9a0diDXD84jOS9aMQ tyTuple__Izx9aRSX9a0diDXD84jOS9aMQ;
typedef struct tyTuple__PsEhl3dzznmmJiLAuIXZOg tyTuple__PsEhl3dzznmmJiLAuIXZOg;
typedef struct tyTuple__Dg3ILQdzHFjrYRx6Xwbq3w tyTuple__Dg3ILQdzHFjrYRx6Xwbq3w;
typedef struct tyTuple__Db8CrQifKGIsKc3w71w7Lw tyTuple__Db8CrQifKGIsKc3w71w7Lw;
typedef struct tyObject_PackedInstantiation__wt9ao6lqcInu9aOmUoxgkWcg tyObject_PackedInstantiation__wt9ao6lqcInu9aOmUoxgkWcg;
typedef struct tySequence__lo3S1lKyiPLhGGB9cBawd6A tySequence__lo3S1lKyiPLhGGB9cBawd6A;
typedef struct tyTuple__Q9cwWJO3ddVfos2xI7N9cHHQ tyTuple__Q9cwWJO3ddVfos2xI7N9cHHQ;
typedef struct tyTuple__FEYH9alRJhHD0uTKF2vnIqw tyTuple__FEYH9alRJhHD0uTKF2vnIqw;
typedef struct tyObject_PackedSym__fAjcBcJ2JPtzDDxyIN8WmA tyObject_PackedSym__fAjcBcJ2JPtzDDxyIN8WmA;
typedef struct tyObject_PackedLib__djDv9aFBRsdjnMVLdFGA0nA tyObject_PackedLib__djDv9aFBRsdjnMVLdFGA0nA;
typedef struct tyObject_PackedType__MvipqCfEd9b9bJbbBPwsUOiw tyObject_PackedType__MvipqCfEd9b9bJbbBPwsUOiw;
typedef struct tyTuple__VUJ5Hjm4tKAResBsRHJvYg tyTuple__VUJ5Hjm4tKAResBsRHJvYg;
typedef struct tyTuple__UvldbCB6B9ayi9bGYW7vJNLA tyTuple__UvldbCB6B9ayi9bGYW7vJNLA;
struct tyObject_TIdTable__Cs7vbulfMjKciTA2Uv9b6vQ {
NI counter;
tySequence__ZQPym9bf1jM5qaSn7LUXMKA* data;
};
struct tyObject_LayeredIdTablecolonObjectType___9aSR8D74Pb4ozXN6gEJ9a1Pw {
tyObject_TIdTable__Cs7vbulfMjKciTA2Uv9b6vQ topLayer;
tyObject_LayeredIdTablecolonObjectType___9aSR8D74Pb4ozXN6gEJ9a1Pw* nextLayer;
};
typedef NU8 tyEnum_TNimKind__pspQAsqJLrw3jEKBD9bxmyQ;
typedef NU8 tySet_tyEnum_TNimTypeFlag__Yt5hq6z2IoHhKZrzIVrc1w;
typedef N_NIMCALL_PTR(void, tyProc__ojoeKfW4VYIm36I9cpDTQIg) (void* p, NI op);
typedef N_NIMCALL_PTR(void*, tyProc__WSm2xU5ARYv9aAR4l0z9c9auQ) (void* p);
struct TNimType {
NI size;
NI align;
tyEnum_TNimKind__pspQAsqJLrw3jEKBD9bxmyQ kind;
tySet_tyEnum_TNimTypeFlag__Yt5hq6z2IoHhKZrzIVrc1w flags;
TNimType* base;
TNimNode* node;
void* finalizer;
tyProc__ojoeKfW4VYIm36I9cpDTQIg marker;
tyProc__WSm2xU5ARYv9aAR4l0z9c9auQ deepcopy;
};
typedef NU8 tyEnum_TNimNodeKind__rrp49bl1h9aEkXfXp9bNg0yZw;
struct TNimNode {
tyEnum_TNimNodeKind__rrp49bl1h9aEkXfXp9bNg0yZw kind;
NI offset;
TNimType* typ;
NCSTRING name;
NI len;
TNimNode** sons;
};
struct tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw {
NU16 line;
NI16 col;
NI32 fileIndex;
};
struct tyObject_TReplTypeVars__itU2h89a2PcJoJ5bHADfePw {
tyObject_TContext__TE0bwjD2I16QW6s9c4AgPvw* c;
tyObject_LayeredIdTablecolonObjectType___9aSR8D74Pb4ozXN6gEJ9a1Pw* typeMap;
tyObject_TIdTable__Cs7vbulfMjKciTA2Uv9b6vQ symMap;
tyObject_TIdTable__Cs7vbulfMjKciTA2Uv9b6vQ localCache;
tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw info;
NIM_BOOL allowMetaTypes;
NIM_BOOL skipTypedesc;
NIM_BOOL isReturnType;
tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* owner;
NI recursionLimit;
};
struct RootObj {
TNimType* m_type;
};
struct tyObject_TPassContext__dmp6pRpfXxJk6gIZHkm7dw {
  RootObj Sup;
tyObject_IdGeneratorcolonObjectType___WVCsDyf9bR1PcjDFjcjm9bRg* idgen;
};
typedef tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* tyArray__aaEwD7wUZoIxDUprFEbfMQ[38];
typedef N_NIMCALL_PTR(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw*, tyProc__q9caIJqxIEVMlKzDKc7PN3A) (tyObject_TContext__TE0bwjD2I16QW6s9c4AgPvw* c, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n, tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* expectedType);
typedef NU32 tySet_tyEnum_TExprFlag__r6ni9cszPdxrSgot9bYmbKjw;
typedef N_NIMCALL_PTR(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw*, tyProc__Kiet6YwcQwPvcQYHHEqqqQ) (tyObject_TContext__TE0bwjD2I16QW6s9c4AgPvw* c, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n, tySet_tyEnum_TExprFlag__r6ni9cszPdxrSgot9bYmbKjw flags, tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* expectedType);
typedef N_NIMCALL_PTR(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw*, tyProc__PSlVV9bxpH9avY5YrjCD5uqA) (tyObject_TContext__TE0bwjD2I16QW6s9c4AgPvw* c, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n, tySet_tyEnum_TExprFlag__r6ni9cszPdxrSgot9bYmbKjw flags);
typedef N_NIMCALL_PTR(NIM_BOOL, tyProc__8k9afYvvfaH1tjWAwlISb0A) (tyObject_TContext__TE0bwjD2I16QW6s9c4AgPvw* c, tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* t);
typedef struct {
N_NIMCALL_PTR(NIM_BOOL, ClP_0) (tyObject_TContext__TE0bwjD2I16QW6s9c4AgPvw* c, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n, void* ClE_0);
void* ClE_0;
} tyProc__9bnYcX9avusKBraL3FJXBwJw;
typedef N_NIMCALL_PTR(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw*, tyProc__uojbiMfaKLMuGW9bbomtTBg) (tyObject_TContext__TE0bwjD2I16QW6s9c4AgPvw* c, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n);
typedef NU32 tySet_tyEnum_TSymKind__sjiB9b9aO1FRPetW6gPYZbfw;
typedef N_NIMCALL_PTR(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw*, tyProc__bqRyngJC8bSPcUqqn9bn73w) (tyObject_TContext__TE0bwjD2I16QW6s9c4AgPvw* c, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* nOrig, tySet_tyEnum_TSymKind__sjiB9b9aO1FRPetW6gPYZbfw filter, tySet_tyEnum_TExprFlag__r6ni9cszPdxrSgot9bYmbKjw flags);
typedef N_NIMCALL_PTR(tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA*, tyProc__F6LocU8y66ng5Ra4XoVWJA) (tyObject_TContext__TE0bwjD2I16QW6s9c4AgPvw* c, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n, tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* prev);
typedef struct {
N_NIMCALL_PTR(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw*, ClP_0) (tyObject_TContext__TE0bwjD2I16QW6s9c4AgPvw* c, tyObject_TIdTable__Cs7vbulfMjKciTA2Uv9b6vQ pt, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n, void* ClE_0);
void* ClE_0;
} tyProc__Nc9aAsBDTkr61wP9a9cnds8Og;
typedef struct {
N_NIMCALL_PTR(tyObject_TSym__3r34mwqcVmg5JFNmiaVncw*, ClP_0) (tyObject_TContext__TE0bwjD2I16QW6s9c4AgPvw* c, tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* fn, tyObject_TIdTable__Cs7vbulfMjKciTA2Uv9b6vQ pt, tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw info, void* ClE_0);
void* ClE_0;
} tyProc__z8FaSv6eEIc72FZ9c9cBcaGg;
typedef NI tyArray__emiAJ8okywrJw7ZHLzlXbQ[34];
struct tyObject_PackedSet__THXDbzJSs2hcC9a33en2pdw {
NI elems;
NI counter;
NI max;
tyObject_TrunkcolonObjectType___2fEZuM4UuXkgO9bDnaMLLWg* head;
tySequence__q9cq1Li6c1nMjHpacEbCj0g* data;
tyArray__emiAJ8okywrJw7ZHLzlXbQ a;
};
struct tyObject_TStrTable__CJQ42V2zij8fd39a9aMiwtZw {
NI counter;
tySequence__ed0C0uAUZPhvw3RAc5hfYg* data;
};
typedef NU8 tyEnum_TTypeAttachedOp__0IDqFfYT9a3F5i6tmCmdORQ;
typedef N_NIMCALL_PTR(tyObject_TSym__3r34mwqcVmg5JFNmiaVncw*, tyProc__9aa59awckKpa9areOQSBOwSeQ) (tyObject_TContext__TE0bwjD2I16QW6s9c4AgPvw* c, tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* dc, tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* t, tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw info, tyEnum_TTypeAttachedOp__0IDqFfYT9a3F5i6tmCmdORQ op, NI col);
struct TGenericSeq {
NI len;
NI reserved;
};
struct NimStringDesc {
  TGenericSeq Sup;
NIM_CHAR data[SEQ_DECL_SIZE];
};
typedef NU32 tySet_tyEnum_Feature__T2jOg7rgtA4lKTKRASHfHw;
struct tyObject_HashSet__qEsCgvAiLX6rSzzn9cFnYvQ {
tySequence__Bis5AbpONWcIRrPyPJS8Yw* data;
NI counter;
};
struct tyObject_Table__7ACYz5IhOEwzTBvwo6BO9bg {
tySequence__E8pi9b5QNahsURYzXMjh3qw* data;
NI counter;
};
struct tyObject_Table__g9cTlJykWlQLKMuaRBpUEZg {
tySequence__XDpbjnuseLNZDGLBQ2Qzow* data;
NI counter;
};
struct tyObject_Table__cBohObSCAwRxvYFXQHv2wA {
tySequence__QqvaCqCpEE1QmQZbcZLi5A* data;
NI counter;
};
struct tyObject_TContext__TE0bwjD2I16QW6s9c4AgPvw {
  tyObject_TPassContext__dmp6pRpfXxJk6gIZHkm7dw Sup;
tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* enforceVoidContext;
tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* voidType;
tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* module;
tyObject_TScope__9aTSl1tODXnq8aZe4E3GxoQ* currentScope;
tyObject_TScope__9aTSl1tODXnq8aZe4E3GxoQ* moduleScope;
tySequence__9boKiNhY9cnRQF2k9b9a9bGKbrA* imports;
tyObject_TScope__9aTSl1tODXnq8aZe4E3GxoQ* topLevelScope;
tyObject_TProcCon__9aK41DZ7WNm5NSRfb1CbcRA* p;
tyArray__aaEwD7wUZoIxDUprFEbfMQ intTypeCache;
tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* nilTypeCache;
tyObject_TMatchedConcept__0kS5yo4t68pnIalDqA39crw* matchedConcept;
tySequence__ed0C0uAUZPhvw3RAc5hfYg* friendModules;
NI instCounter;
NI* templInstCounter;
NI inGenericContext;
NI inStaticContext;
NI inUnrolledContext;
NI compilesContextId;
NI compilesContextIdGenerator;
NI inGenericInst;
tySequence__ed0C0uAUZPhvw3RAc5hfYg* converters;
tySequence__ed0C0uAUZPhvw3RAc5hfYg* patterns;
tySequence__vvBerF0axaNtu9aMA2gnsrA* optionStack;
tyObject_TIdTable__Cs7vbulfMjKciTA2Uv9b6vQ symMapping;
tySequence__9c3OY0aBmSBgwdsnBAPf4Ag* libs;
tyProc__q9caIJqxIEVMlKzDKc7PN3A semConstExpr;
tyProc__Kiet6YwcQwPvcQYHHEqqqQ semExpr;
tyProc__PSlVV9bxpH9avY5YrjCD5uqA semTryExpr;
tyProc__q9caIJqxIEVMlKzDKc7PN3A semTryConstExpr;
tyProc__8k9afYvvfaH1tjWAwlISb0A computeRequiresInit;
tyProc__9bnYcX9avusKBraL3FJXBwJw hasUnresolvedArgs;
tyProc__PSlVV9bxpH9avY5YrjCD5uqA semOperand;
tyProc__uojbiMfaKLMuGW9bbomtTBg semConstBoolExpr;
tyProc__bqRyngJC8bSPcUqqn9bn73w semOverloadedCall;
tyProc__F6LocU8y66ng5Ra4XoVWJA semTypeNode;
tyProc__Nc9aAsBDTkr61wP9a9cnds8Og semInferredLambda;
tyProc__z8FaSv6eEIc72FZ9c9cBcaGg semGenerateInstance;
tyObject_PackedSet__THXDbzJSs2hcC9a33en2pdw includedFiles;
tyObject_TStrTable__CJQ42V2zij8fd39a9aMiwtZw pureEnumFields;
tyObject_TStrTable__CJQ42V2zij8fd39a9aMiwtZw userPragmas;
tyObject_TCtx__CRPlhL1hATwZc5hefTGOQQ* evalContext;
tyObject_PackedSet__THXDbzJSs2hcC9a33en2pdw unknownIdents;
tySequence__yH9bx9bpa6jqsU89cxjyTAlPQ* generics;
NI topStmts;
NI lastGenericIdx;
NI hloLoopDetector;
NI inParallelStmt;
tyProc__9aa59awckKpa9areOQSBOwSeQ instTypeBoundOp;
tyObject_TIdent__PKDcQ7dqdhiSW9c9cXUFFpMg* selfName;
tyObject_IdentCachecolonObjectType___ssh0vzVb9aCQuB6ShpimfIQ* cache;
tyObject_ModuleGraphcolonObjectType___nOSrcYqJTxXt2ptNc0gnWg* graph;
tyObject_TStrTable__CJQ42V2zij8fd39a9aMiwtZw signatures;
NimStringDesc* recursiveDep;
NIM_BOOL suggestionsMade;
NIM_BOOL isAmbiguous;
tySet_tyEnum_Feature__T2jOg7rgtA4lKTKRASHfHw features;
NI inTypeContext;
NI inConceptDecl;
tySequence__Jhh6ks9carRtwV9aOuM8yMNw* unusedImports;
tyObject_HashSet__qEsCgvAiLX6rSzzn9cFnYvQ exportIndirections;
tyObject_Table__7ACYz5IhOEwzTBvwo6BO9bg importModuleMap;
tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw lastTLineInfo;
tyObject_Table__g9cTlJykWlQLKMuaRBpUEZg sideEffects;
NI inUncheckedAssignSection;
tyObject_Table__cBohObSCAwRxvYFXQHv2wA importModuleLookup;
};
struct tyObject_ItemId__wg9aowaxscbUe2F0nV9btZLg {
NI32 module;
NI32 item;
};
struct tyObject_TIdObj__1qw9bcK4rZXhGbJEJhkKQFA {
  RootObj Sup;
tyObject_ItemId__wg9aowaxscbUe2F0nV9btZLg itemId;
};
typedef NU8 tyEnum_TSymKind__sjiB9b9aO1FRPetW6gPYZbfw;
typedef NU16 tyEnum_TMagic__3qAy6bDUDlF8Fc2RR6pF9ag;
typedef NU64 tySet_tyEnum_TSymFlag__9be9c6fEXk5NwyPvxxb6toPA;
typedef NU32 tySet_tyEnum_TOption__HPX9bEWraE8wyYLoP9bHbKYQ;
typedef NU8 tyEnum_TLocKind__pD6N6rEUmrrqJbKE02Sezw;
typedef NU8 tyEnum_TStorageLoc__JIS9cieRcL9cZccyO9bM9aBmFQ;
typedef NU16 tySet_tyEnum_TLocFlag__Ic4ywZl9cdJtKSUkG4WZfHw;
struct tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw {
tyEnum_TLocKind__pD6N6rEUmrrqJbKE02Sezw k;
tyEnum_TStorageLoc__JIS9cieRcL9cZccyO9bM9aBmFQ storage;
tySet_tyEnum_TLocFlag__Ic4ywZl9cdJtKSUkG4WZfHw flags;
tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* lode;
tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* r;
};
struct tyObject_TSym__3r34mwqcVmg5JFNmiaVncw {
  tyObject_TIdObj__1qw9bcK4rZXhGbJEJhkKQFA Sup;
tyEnum_TSymKind__sjiB9b9aO1FRPetW6gPYZbfw kind;
union{
struct {tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* gcUnsafetyReason;
tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* transformedBody;
} _kind_1;
struct {tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* guard;
NI bitsize;
NI alignment;
} _kind_2;
};
tyEnum_TMagic__3qAy6bDUDlF8Fc2RR6pF9ag magic;
tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* typ;
tyObject_TIdent__PKDcQ7dqdhiSW9c9cXUFFpMg* name;
tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw info;
tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* owner;
tySet_tyEnum_TSymFlag__9be9c6fEXk5NwyPvxxb6toPA flags;
tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* ast;
tySet_tyEnum_TOption__HPX9bEWraE8wyYLoP9bHbKYQ options;
NI position;
NI offset;
tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw loc;
tyObject_TLib__W49cDqPTe2Tvc1mw7CVZOFg* annex;
tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* constraint;
};
typedef NU32 tySet_tyEnum_TNodeFlag__0RUKWdbLPY3l0smKVGDLMg;
typedef NU8 tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw;
struct tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw {
tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* typ;
tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw info;
tySet_tyEnum_TNodeFlag__0RUKWdbLPY3l0smKVGDLMg flags;
tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw kind;
union{
struct {NI64 intVal;
} _kind_1;
struct {NF floatVal;
} _kind_2;
struct {NimStringDesc* strVal;
} _kind_3;
struct {tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* sym;
} _kind_4;
struct {tyObject_TIdent__PKDcQ7dqdhiSW9c9cXUFFpMg* ident;
} _kind_5;
struct {tySequence__IeU9azYSNIK3V9b36Ir6NZcw* sons;
} _kind_6;
};
};
struct tyObject_Table__nODIJ5l6JnEl9a6LYuqISLA {
tySequence__ijtae5OneaLys0hN9alAicA* data;
NI counter;
};
struct tyObject_Table__s3itmS9cUUFQ19alF7UA0T1w {
tySequence__SerjNoUujW2dUouVBrJiCw* data;
NI counter;
};
struct tyObject_Table__r0v8BdcBPKhl73K8p2VMUA {
tySequence__K9agbtcb0qPZuSJFXB9cTe6g* data;
NI counter;
};
typedef tyObject_Table__r0v8BdcBPKhl73K8p2VMUA tyArray__46hjIasL27aUz9c7kgtWooQ[5];
struct tyObject_Table__KsPP7K7LW9aa3YAq1XN9cDZg {
tySequence__m88qdML9cQOuqGAQn6XWL1A* data;
NI counter;
};
struct tyObject_Table__1hIWbTQWYT4BmhdESze57A {
tySequence__naEbXEp9b9aiW1zXJorqf9cXQ* data;
NI counter;
};
struct tyObject_Table__9cHFtxtpgztIcDsypRz9byKw {
tySequence__7lEisrXlQEzwtUKW5pzRCw* data;
NI counter;
};
typedef NU8 tyEnum_TBackend__zoooocqvga73vZuhGAAy6A;
typedef NU8 tyEnum_TGCMode__yHeclYqeKaCEfMHNbcWn4w;
typedef NU8 tyEnum_TSystemCC__DqbWIQj9a2XvtXkztox3VFQ;
typedef NU64 tySet_tyEnum_TGlobalOption__WCvlY9b2UxZ4Fz8D59cE3YSg;
struct tyObject_PackedConfig__aqQhF9bElTH51s7bVamv3vA {
tyEnum_TBackend__zoooocqvga73vZuhGAAy6A backend;
tyEnum_TGCMode__yHeclYqeKaCEfMHNbcWn4w selectedGC;
tyEnum_TSystemCC__DqbWIQj9a2XvtXkztox3VFQ cCompiler;
tySet_tyEnum_TOption__HPX9bEWraE8wyYLoP9bHbKYQ options;
tySet_tyEnum_TGlobalOption__WCvlY9b2UxZ4Fz8D59cE3YSg globalOptions;
};
struct tyObject_Table__imojfg883tkWsWJwyshGqQ {
tySequence__fdmz6VkIf1ewwrssKYqRFg* data;
NI counter;
};
struct tyObject_Table__BCPh85PHtwxox9bv7NLFrlg {
tySequence__kxu4GK0onha2t9bo86mdVAg* data;
NI counter;
};
typedef struct {
N_NIMCALL_PTR(NIM_BOOL, ClP_0) (void* ClE_0);
void* ClE_0;
} tyProc__In3g79a0qTcRmbTbJp9ba9ctg;
struct tyObject_Table__mLYbj79bHyPPDPv4GGJx9bqA {
tySequence__KgiZ29chkJAD01p9aLRB32qw* data;
NI counter;
};
struct tyObject_Table__LM44poVdVEn4Mo4N4L8c3A {
tySequence__rkYRZrbHVYL3nhXlQW3K9bw* data;
NI counter;
};
typedef tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* tyArray__9atk2qEPO7ASGmt9cDlOE9b9cg[65];
struct tyObject_Table__sEMwnZ9aATDhH19cNIt9bn9cyQ {
tySequence__YmPd0eWfcTfrVYrthlXPYA* data;
NI counter;
};
struct tyObject_Table__WtPprFMQ6tkKi9bQSH3IVpw {
tySequence__fIB1rTQ55aFonoft9a9bmljQ* data;
NI counter;
};
typedef N_NIMCALL_PTR(tyObject_TSym__3r34mwqcVmg5JFNmiaVncw*, tyProc__I6rzVhdiYtUh7jwWJQoeyw) (tyObject_ModuleGraphcolonObjectType___nOSrcYqJTxXt2ptNc0gnWg* graph, tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* m, NI32 fileIdx);
typedef N_NIMCALL_PTR(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw*, tyProc__EQOAUyRkp9c3eeiGlHvCThA) (tyObject_ModuleGraphcolonObjectType___nOSrcYqJTxXt2ptNc0gnWg* graph, tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* m, NI32 fileIdx);
struct tyObject_Table__9cOd7jTOg5Zc4i0IfnGho1Q {
tySequence__Hz5SYwQU29b9aFLt09blvVQPg* data;
NI counter;
};
struct tyObject_Table__YnoEqrDMrd9cI9bBg8gj5H3g {
tySequence__squ9b9bUH4OLHf6cEMrt6hVA* data;
NI counter;
};
struct tyObject_Table__R7JnJQEipxxOlJWXQz7jWg {
tySequence__3G9aA9cLXaPxuRxMKm3anacQ* data;
NI counter;
};
typedef N_NIMCALL_PTR(void, tyProc__1CO5eEh25fBKUWGagpikwg) (tyObject_ModuleGraphcolonObjectType___nOSrcYqJTxXt2ptNc0gnWg* graph, tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* s, tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw info);
typedef N_NIMCALL_PTR(void, tyProc__VcUg5jOhttLagdxUmVN8Tg) (tyObject_ModuleGraphcolonObjectType___nOSrcYqJTxXt2ptNc0gnWg* graph, tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* owner, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* body);
typedef N_NIMCALL_PTR(NIM_BOOL, tyProc__XOkru1xuh2bHzmkw1UYzLA) (tyObject_ModuleGraphcolonObjectType___nOSrcYqJTxXt2ptNc0gnWg* graph, tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* formal, tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* actual);
struct tyObject_Operators__dR4s9bCO53rZjV9a30JJfUOg {
tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* opNot;
tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* opContains;
tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* opLe;
tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* opLt;
tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* opAnd;
tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* opOr;
tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* opIsNil;
tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* opEq;
tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* opAdd;
tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* opSub;
tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* opMul;
tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* opDiv;
tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* opLen;
};
struct tyObject_ModuleGraphcolonObjectType___nOSrcYqJTxXt2ptNc0gnWg {
tySequence__RNhZxf20g9beyq5VBOGxhDg* ifaces;
tySequence__JbK5aK9aVhc9cJZzQYg1wQlQ* packed_0;
tySequence__lFbCtu5P2Kf7YDYtGjkxAQ* encoders;
tyObject_Table__nODIJ5l6JnEl9a6LYuqISLA typeInstCache;
tyObject_Table__s3itmS9cUUFQ19alF7UA0T1w procInstCache;
tyArray__46hjIasL27aUz9c7kgtWooQ attachedOps;
tyObject_Table__KsPP7K7LW9aa3YAq1XN9cDZg methodsPerType;
tyObject_Table__1hIWbTQWYT4BmhdESze57A enumToStringProcs;
tyObject_Table__9cHFtxtpgztIcDsypRz9byKw emittedTypeInfo;
tyObject_PackedConfig__aqQhF9bElTH51s7bVamv3vA startupPackedConfig;
tyObject_TStrTable__CJQ42V2zij8fd39a9aMiwtZw packageSyms;
tyObject_PackedSet__THXDbzJSs2hcC9a33en2pdw deps;
tyObject_Table__imojfg883tkWsWJwyshGqQ importDeps;
NIM_BOOL suggestMode;
NIM_BOOL invalidTransitiveClosure;
tyObject_Table__BCPh85PHtwxox9bv7NLFrlg inclToMod;
tySequence__48JTohSgTy339bRxHzUD8KA* importStack;
RootObj* backend;
tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ* config;
tyObject_IdentCachecolonObjectType___ssh0vzVb9aCQuB6ShpimfIQ* cache;
RootObj* vm;
tyProc__In3g79a0qTcRmbTbJp9ba9ctg doStopCompile;
tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* usageSym;
tySequence__ed0C0uAUZPhvw3RAc5hfYg* owners;
tyObject_Table__mLYbj79bHyPPDPv4GGJx9bqA suggestSymbols;
tyObject_Table__LM44poVdVEn4Mo4N4L8c3A suggestErrors;
tySequence__IRFEb1e9bxgbJLuB5xrdZsQ* methods;
tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* systemModule;
tyArray__9atk2qEPO7ASGmt9cDlOE9b9cg sysTypes;
tyObject_TStrTable__CJQ42V2zij8fd39a9aMiwtZw compilerprocs;
tyObject_TStrTable__CJQ42V2zij8fd39a9aMiwtZw exposed;
tyObject_TStrTable__CJQ42V2zij8fd39a9aMiwtZw packageTypes;
tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* emptyNode;
tyObject_Table__sEMwnZ9aATDhH19cNIt9bn9cyQ canonTypes;
tyObject_Table__WtPprFMQ6tkKi9bQSH3IVpw symBodyHashes;
tyProc__I6rzVhdiYtUh7jwWJQoeyw importModuleCallback;
tyProc__EQOAUyRkp9c3eeiGlHvCThA includeFileCallback;
tyObject_Table__9cOd7jTOg5Zc4i0IfnGho1Q cacheSeqs;
tyObject_Table__YnoEqrDMrd9cI9bBg8gj5H3g cacheCounters;
tyObject_Table__R7JnJQEipxxOlJWXQz7jWg cacheTables;
tySequence__bPFv6ypvvCX2A9a9al8utL2Q* passes;
tyProc__1CO5eEh25fBKUWGagpikwg onDefinition;
tyProc__1CO5eEh25fBKUWGagpikwg onDefinitionResolveForward;
tyProc__1CO5eEh25fBKUWGagpikwg onUsage;
tySequence__IeU9azYSNIK3V9b36Ir6NZcw* globalDestructors;
tyProc__VcUg5jOhttLagdxUmVN8Tg strongSemCheck;
tyProc__XOkru1xuh2bHzmkw1UYzLA compatibleProps;
tyObject_IdGeneratorcolonObjectType___WVCsDyf9bR1PcjDFjcjm9bRg* idgen;
tyObject_Operators__dR4s9bCO53rZjV9a30JJfUOg operators;
};
typedef NU8 tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg;
typedef NU8 tyEnum_TCallingConvention__5kpSva5OFmGFHujbio7C9cg;
typedef NU64 tySet_tyEnum_TTypeFlag__Vrztsndr9a9bj8bQ3cn49bwWw;
struct tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA {
  tyObject_TIdObj__1qw9bcK4rZXhGbJEJhkKQFA Sup;
tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg kind;
tyEnum_TCallingConvention__5kpSva5OFmGFHujbio7C9cg callConv;
tySet_tyEnum_TTypeFlag__Vrztsndr9a9bj8bQ3cn49bwWw flags;
tySequence__vKogasEnJSPhbQmA8r4Y9aA* sons;
tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n;
tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* owner;
tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* sym;
NI64 size;
NI16 align;
NI16 paddingAtEnd;
NI16 lockLevel;
tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw loc;
tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* typeInst;
tyObject_ItemId__wg9aowaxscbUe2F0nV9btZLg uniqueId;
};
struct tyTuple__kN8up2W6YKc5YA9avn5mV5w {
NimStringDesc* Field0;
NI Field1;
NI Field2;
};
struct tyObject_PackedItemId__QkYBSICiQaMI6SmH4FJVoQ {
NU32 module;
NI32 item;
};
struct tyObject_FullId__L64puUgQnoQ6OMvT9c6V9cPg {
NI module;
tyObject_PackedItemId__QkYBSICiQaMI6SmH4FJVoQ packed_0;
};
struct tyObject_LazyType__wgv9a1JCOBXm9azerxcvz5gQ {
tyObject_FullId__L64puUgQnoQ6OMvT9c6V9cPg id;
tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* typ;
};
typedef NU8 tyEnum_TDistinctCompare__UuPcvyG2RecjPyQDW4WlFw;
typedef NU8 tySet_tyEnum_TTypeCmpFlag__IRq9bqtrf9ctEUyeRMyvWy4Q;
typedef NU8 tyEnum_TTypeFlag__Vrztsndr9a9bj8bQ3cn49bwWw;
typedef NU8 tyEnum_TMsgKind__J0cVyqzpFKvufCivtQUgHQ;
typedef NU8 tyEnum_TErrorHandling__sOC1wCv9bUYRquMih1VRi3w;
typedef NU8 tyEnum_TPreferedDesc__lx9aDnWjKktcSUo0yfjOvMg;
struct tyObject_IdGeneratorcolonObjectType___WVCsDyf9bR1PcjDFjcjm9bRg {
NI32 module;
NI32 symId;
NI32 typeId_0;
NIM_BOOL sealed;
};
struct tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g {
NI refcount;
TNimType* typ;
};
struct tyObject_GcStack__qFeGMKlnq6c9cTM2vPWycQQ {
void* bottom;
};
struct tyObject_CellSeq__nav876ELHgxScHhs30CKiA {
NI len;
NI cap;
tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g** d;
};
typedef tyObject_SmallChunk__eUrTKmsk1Dqt5tm2WUT2Lw* tyArray__1eFxjkcKGHnofywkmCV8oQ[256];
typedef NU32 tyArray__BHbOSqU1t9b3Gt7K2c6fQig[24];
typedef tyObject_BigChunk__39bC3HTk2w4NGDjG74oNjmA* tyArray__KxTmKT9a3kTkdwYfqXhEYSw[32];
typedef tyArray__KxTmKT9a3kTkdwYfqXhEYSw tyArray__ATT5LBefmjy9bg8ApRmg3rw[24];
typedef tyObject_Trunk__Ju1AURWHenTn3cJwAjbUhg* tyArray__RxhBwkGQwTHLKhoK685Xfg[256];
struct tyObject_IntSet__WrQriiGmHk59cB1lNPtGo6A {
tyArray__RxhBwkGQwTHLKhoK685Xfg data;
};
typedef tyObject_AvlNode__aGkK1t9a0WoXjpugXR6FWpw* tyArray__DrxDrI9bg9apB70ydOoNZrWw[2];
struct tyObject_AvlNode__aGkK1t9a0WoXjpugXR6FWpw {
tyArray__DrxDrI9bg9apB70ydOoNZrWw link;
NI key;
NI upperBound;
NI level;
};
struct tyTuple__p2vAp9cQ6YrpDq9cI3XzEDWA {
tyObject_BigChunk__39bC3HTk2w4NGDjG74oNjmA* Field0;
NI Field1;
};
typedef tyTuple__p2vAp9cQ6YrpDq9cI3XzEDWA tyArray__wsokuoa9bVBSU4gPLKbFaaw[30];
struct tyObject_HeapLinks__5IkCDh5QlsYpsfEMJf6zNw {
NI len;
tyArray__wsokuoa9bVBSU4gPLKbFaaw chunks;
tyObject_HeapLinks__5IkCDh5QlsYpsfEMJf6zNw* next;
};
struct tyObject_MemRegion__6QRscFDo4mEwbg9aL76vDGQ {
NI minLargeObj;
NI maxLargeObj;
tyArray__1eFxjkcKGHnofywkmCV8oQ freeSmallChunks;
NU32 flBitmap;
tyArray__BHbOSqU1t9b3Gt7K2c6fQig slBitmap;
tyArray__ATT5LBefmjy9bg8ApRmg3rw matrix;
tyObject_LLChunk__Fjkr5Ya6Zl0UoUGxG047hA* llmem;
NI currMem;
NI maxMem;
NI freeMem;
NI occ;
NI lastSize;
tyObject_IntSet__WrQriiGmHk59cB1lNPtGo6A chunkStarts;
tyObject_AvlNode__aGkK1t9a0WoXjpugXR6FWpw* root;
tyObject_AvlNode__aGkK1t9a0WoXjpugXR6FWpw* deleted;
tyObject_AvlNode__aGkK1t9a0WoXjpugXR6FWpw* last;
tyObject_AvlNode__aGkK1t9a0WoXjpugXR6FWpw* freeAvlNodes;
NIM_BOOL locked;
NIM_BOOL blockChunkSizeIncrease;
NI nextChunkSize;
tyObject_AvlNode__aGkK1t9a0WoXjpugXR6FWpw bottomData;
tyObject_HeapLinks__5IkCDh5QlsYpsfEMJf6zNw heapLinks;
};
struct tyObject_GcStat__OG9ams3mtFJyICkjTOHbc9bg {
NI stackScans;
NI cycleCollections;
NI maxThreshold;
NI maxStackSize;
NI maxStackCells;
NI cycleTableSize;
NI64 maxPause;
};
struct tyObject_CellSet__A0mJvGLunfUxGkLUtesjdA {
NI counter;
NI max;
tyObject_PageDesc__N7tjEodqPVJaQ6oKQW8YfQ* head;
tyObject_PageDesc__N7tjEodqPVJaQ6oKQW8YfQ** data;
};
struct tyObject_GcHeap__ZRn9bWCksoiGwT2drZZzyWQ {
tyObject_GcStack__qFeGMKlnq6c9cTM2vPWycQQ stack;
NI cycleThreshold;
NI zctThreshold;
tyObject_CellSeq__nav876ELHgxScHhs30CKiA zct;
tyObject_CellSeq__nav876ELHgxScHhs30CKiA decStack;
tyObject_CellSeq__nav876ELHgxScHhs30CKiA tempStack;
NI recGcLock;
tyObject_MemRegion__6QRscFDo4mEwbg9aL76vDGQ region;
tyObject_GcStat__OG9ams3mtFJyICkjTOHbc9bg stat;
tyObject_CellSet__A0mJvGLunfUxGkLUtesjdA marked;
tyObject_CellSeq__nav876ELHgxScHhs30CKiA additionalRoots;
NI gcThreadId;
};
typedef NU8 tyEnum_TSymFlag__9be9c6fEXk5NwyPvxxb6toPA;
typedef NU8 tySet_tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg[9];
struct tyObject_LazySym__Xts9a2Mw4b4jtq73p6MrfJg {
tyObject_FullId__L64puUgQnoQ6OMvT9c6V9cPg id;
tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* sym;
};
struct tyTuple__RWXAsQlFoGYyEQZp1G65sg {
NI Field0;
tyObject_LazySym__Xts9a2Mw4b4jtq73p6MrfJg Field1;
};
struct tyObject_TIdent__PKDcQ7dqdhiSW9c9cXUFFpMg {
NI id;
NimStringDesc* s;
tyObject_TIdent__PKDcQ7dqdhiSW9c9cXUFFpMg* next;
NI h;
};
struct tyObject_TIdPair__CEfaiHL4gHg86NKgeeQ7lA {
tyObject_TIdObj__1qw9bcK4rZXhGbJEJhkKQFA* key;
RootObj* val;
};
typedef NU8 tyEnum_ImportMode__4kYBzhtdX1Hkta8RDDKjrQ;
struct tyObject_ImportedModule__ABXo2nVfMtcWNYv5zEiXDg {
tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* m;
tyEnum_ImportMode__4kYBzhtdX1Hkta8RDDKjrQ mode;
union{
struct {tyObject_PackedSet__THXDbzJSs2hcC9a33en2pdw imported;
} _mode_2;
struct {tyObject_PackedSet__THXDbzJSs2hcC9a33en2pdw exceptSet;
} _mode_3;
};
};
struct tyObject_TInstantiationPair__d4lcZMnmQK2Jh2jYkdgB4w {
tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* genericSym;
tyObject_TInstantiation__ScJwrSJM8Lp9ahM9b3AS1apA* inst;
};
struct tyTuple__8vGER9aaTtt9bUk9avNQ3fEIg {
tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* Field0;
tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw Field1;
};
struct tyTuple__1v9bKyksXWMsm0vNwmZ4EuQ {
NI Field0;
NI Field1;
};
struct tyTuple__NAaJgGVgNmlGoqmiWxdOHQ {
NI Field0;
tyTuple__1v9bKyksXWMsm0vNwmZ4EuQ Field1;
};
struct tyTuple__47w2DboNEPf69aPgubZdd7Q {
NI Field0;
NI Field1;
NI Field2;
};
struct tyTuple__toqrUPSdp8zSxOdlxMJj9cA {
tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw Field0;
tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* Field1;
};
struct tyTuple__VbApVidEWCFLq9a29bPtaS7A {
NI Field0;
NI Field1;
tySequence__k7EQb9bN3Uhl608xoPGMRJA* Field2;
};
struct tyTuple__EbsafWGli8bW2GRJQ9apsjA {
NI Field0;
NI Field1;
tySequence__qwqHTkRvwhrRyENtudHQ7g* Field2;
};
struct tyObject_Iface__4y9aWdJBxraQYTl5Pa1NMuQ {
tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* module;
tySequence__qeAsXh2i1GAL5Nl0g3OP8g* converters;
tySequence__qeAsXh2i1GAL5Nl0g3OP8g* patterns;
tySequence__qeAsXh2i1GAL5Nl0g3OP8g* pureEnums;
tyObject_TStrTable__CJQ42V2zij8fd39a9aMiwtZw interf;
tyObject_TStrTable__CJQ42V2zij8fd39a9aMiwtZw interfHidden;
tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* uniqueName;
};
typedef NU8 tyEnum_ModuleStatus__K6X1Kd9cJ9a0hyG1Twv69bMNg;
struct tyObject_PackedTree__om9aqqVmbmBPgd8MeBkGtqg {
tySequence__4Murtwnm0Fyc7F9acrytEXw* nodes;
};
typedef NU8 tySet_tyEnum_ModuleBackendFlag__1OX8mHZmOJcGSH2EQV6eCQ;
struct tyObject_BiTable__f1TRECC4Lgx6Suak6pB8oQ {
tySequence__sM4lkSb7zS6F7OVMvW9cffQ* vals;
tySequence__9bAGqSvkAaFL9bWjsEPslrFA* keys;
};
struct tyObject_BiTable__YFXXoy9ajAIwHK4kQgVvjcw {
tySequence__IHUFRsFxZNv7YydiUO2esQ* vals;
tySequence__9bAGqSvkAaFL9bWjsEPslrFA* keys;
};
struct tyObject_PackedModule__Lx6uQ9baEALysaHmfFGXw9ag {
NimStringDesc* definedSymbols;
tySet_tyEnum_TSymFlag__9be9c6fEXk5NwyPvxxb6toPA moduleFlags;
tySequence__PXIzfWocnrafGz5p3CP5LA* includes;
tySequence__9bAGqSvkAaFL9bWjsEPslrFA* imports;
tyObject_PackedTree__om9aqqVmbmBPgd8MeBkGtqg toReplay;
tyObject_PackedTree__om9aqqVmbmBPgd8MeBkGtqg topLevel;
tyObject_PackedTree__om9aqqVmbmBPgd8MeBkGtqg bodies;
tySequence__b89aLriiJnVTD186H6zNIgg* exports;
tySequence__b89aLriiJnVTD186H6zNIgg* hidden;
tySequence__wE9cZkGC9cv7Iz9ckZOIyaW9aw* reexports;
tySequence__b89aLriiJnVTD186H6zNIgg* compilerProcs;
tySequence__48JTohSgTy339bRxHzUD8KA* converters;
tySequence__48JTohSgTy339bRxHzUD8KA* methods;
tySequence__48JTohSgTy339bRxHzUD8KA* trmacros;
tySequence__48JTohSgTy339bRxHzUD8KA* pureEnums;
tySequence__QnmOtn1Iv4LvxOXoMn8Rbg* macroUsages;
tySequence__oKtVqsc9bQVCNyrijELM4OQ* typeInstCache;
tySequence__qy6Iwdy00wN560qud54HTg* procInstCache;
tySequence__k67v9bwvvQDmS1ynyGGUbeQ* attachedOps;
tySequence__cLsClAAfd0MKkoBQVyvdvw* methodsPerType;
tySequence__oKtVqsc9bQVCNyrijELM4OQ* enumToStringProcs;
tySequence__sM4lkSb7zS6F7OVMvW9cffQ* emittedTypeInfo;
tySet_tyEnum_ModuleBackendFlag__1OX8mHZmOJcGSH2EQV6eCQ backendFlags;
tySequence__q9bTuOB0JXh1iZ3CSGdRLbg* syms;
tySequence__DPZr9aMyRppVlNZ9ajSyOZ9bw* types;
tyObject_BiTable__f1TRECC4Lgx6Suak6pB8oQ strings;
tyObject_BiTable__YFXXoy9ajAIwHK4kQgVvjcw numbers;
tyObject_PackedConfig__aqQhF9bElTH51s7bVamv3vA cfg;
};
struct tyObject_Table__jSCM9c8LtAedYb1zTNR73sQ {
tySequence__C3r8jsj9chA4sIlYfDN5aDw* data;
NI counter;
};
struct tyObject_LoadedModule__fihS6xbKhtLC0fhM28Cpeg {
tyEnum_ModuleStatus__K6X1Kd9cJ9a0hyG1Twv69bMNg status;
NIM_BOOL symsInit;
NIM_BOOL typesInit;
NIM_BOOL loadedButAliveSetChanged;
tyObject_PackedModule__Lx6uQ9baEALysaHmfFGXw9ag fromDisk;
tySequence__ed0C0uAUZPhvw3RAc5hfYg* syms;
tySequence__vKogasEnJSPhbQmA8r4Y9aA* types;
tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* module;
tyObject_Table__jSCM9c8LtAedYb1zTNR73sQ iface;
tyObject_Table__jSCM9c8LtAedYb1zTNR73sQ ifaceHidden;
};
struct tyObject_Table__7OytuYts9c9a3BX9aQNPGI0gQ {
tySequence__9cnx3zXnWzeclW8Ko4oUgAQ* data;
NI counter;
};
struct tyObject_PackedEncoder__ftUl9bxYRlbT5ToKkxHdbfQ {
NI32 thisModule;
NI32 lastFile;
NU32 lastLit;
tyObject_Table__7OytuYts9c9a3BX9aQNPGI0gQ filenames;
tySequence__vKogasEnJSPhbQmA8r4Y9aA* pendingTypes;
tySequence__ed0C0uAUZPhvw3RAc5hfYg* pendingSyms;
tyObject_PackedSet__THXDbzJSs2hcC9a33en2pdw typeMarker;
tyObject_PackedSet__THXDbzJSs2hcC9a33en2pdw symMarker;
tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ* config;
};
struct tyTuple__UluY8x0Nj6cp9b0o88wJ0lg {
NI Field0;
tyObject_ItemId__wg9aowaxscbUe2F0nV9btZLg Field1;
tySequence__dlD6tEGzYLLpKVq3XwuFlA* Field2;
};
struct tyObject_LazyInstantiation__0l1i6PfjQKnMEvpGMAoN8Q {
NI module;
tyObject_FullId__L64puUgQnoQ6OMvT9c6V9cPg sym;
tySequence__UnGSk9aaLosDroi2QDrlOfQ* concreteTypes;
tyObject_TInstantiation__ScJwrSJM8Lp9ahM9b3AS1apA* inst;
};
struct tyTuple__rZZA0skon1OsHdiEvT8RZQ {
NI Field0;
tyObject_ItemId__wg9aowaxscbUe2F0nV9btZLg Field1;
tySequence__6OFCSvqRaxyEgUqWtnZSlw* Field2;
};
struct tyTuple__q13Zt16VkCqu6Zg5jWqwHA {
NI Field0;
tyObject_ItemId__wg9aowaxscbUe2F0nV9btZLg Field1;
tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* Field2;
};
struct tyTuple__aWN9bNzF9bubXNJV9ciomgpfA {
NI Field0;
tyObject_ItemId__wg9aowaxscbUe2F0nV9btZLg Field1;
tySequence__m4PVWjcAAjfxlwJxLkKn8A* Field2;
};
struct tyTuple__RmGJuqOgEaHckHndh0LEsw {
NI Field0;
tyObject_ItemId__wg9aowaxscbUe2F0nV9btZLg Field1;
tyObject_LazySym__Xts9a2Mw4b4jtq73p6MrfJg Field2;
};
struct tyTuple__xYhUhS7X82rKTqbT9bRfCnw {
NI Field0;
NimStringDesc* Field1;
NI32 Field2;
};
struct tyTuple__1mtQ8sCEE7DbfIuQciv9b5Q {
NI Field0;
NI32 Field1;
tySequence__48JTohSgTy339bRxHzUD8KA* Field2;
};
struct tyTuple__xDU9bZmv1ZbZkJDaATBekIQ {
NI Field0;
NI32 Field1;
NI32 Field2;
};
struct tyObject_SymInfoPair__SjZT5Rln3r9befMWWSryQ0A {
tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* sym;
tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw info;
};
struct tyTuple__J4cxakKjhKxTIJR9bojMmXw {
NI Field0;
NI32 Field1;
tySequence__i89c5kdtWKzK3OEiI81pkkw* Field2;
};
struct tyTuple__VwWg1orPZ9b5Rg9aZAI6SIaQ {
NI Field0;
NI32 Field1;
tySequence__GR8qmV1kNRcoQ2g76VFy3A* Field2;
};
struct tyTuple__a7QginWFapakKbWJBJ2vfA {
tySequence__ed0C0uAUZPhvw3RAc5hfYg* Field0;
tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* Field1;
};
typedef NU8 tyArray__qtqsWM5aXmcpMIVmvq3kAA[16];
struct tyTuple__mPT6B9cVWqwVnWb1Fxx9bgyA {
NI Field0;
tyArray__qtqsWM5aXmcpMIVmvq3kAA Field1;
tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* Field2;
};
struct tyTuple__OJFzEczluV8Jmo9bRpBfkzw {
NI Field0;
NI Field1;
tyArray__qtqsWM5aXmcpMIVmvq3kAA Field2;
};
struct tyTuple__kbX6x85REySUrk9auORL0vw {
NI Field0;
NimStringDesc* Field1;
tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* Field2;
};
struct tyTuple__F3gkSrMB1qp2Tvf9bixVXwg {
NI Field0;
NimStringDesc* Field1;
NI64 Field2;
};
struct tyObject_BTree__R2EgvhuH9cLMYvSPesdcu5Q {
tyObject_NodecolonObjectType___NOM0ZpqV9bLtofkCilAnZ8A* root;
NI entries;
};
struct tyTuple__Ah6ua9a8WyUOs9aO9afW59cy0g {
NI Field0;
NimStringDesc* Field1;
tyObject_BTree__R2EgvhuH9cLMYvSPesdcu5Q Field2;
};
typedef N_NIMCALL_PTR(tyObject_TPassContext__dmp6pRpfXxJk6gIZHkm7dw*, tyProc__kqPx9c4py2HW6KcFMhNvxtg) (tyObject_ModuleGraphcolonObjectType___nOSrcYqJTxXt2ptNc0gnWg* graph, tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* module, tyObject_IdGeneratorcolonObjectType___WVCsDyf9bR1PcjDFjcjm9bRg* idgen);
typedef N_NIMCALL_PTR(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw*, tyProc__9c6qRjwy7Es8UkDTIUwAfFA) (tyObject_TPassContext__dmp6pRpfXxJk6gIZHkm7dw* p, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* topLevelStmt);
typedef N_NIMCALL_PTR(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw*, tyProc__mv4BsRs5VEnhcxzV6pQU5w) (tyObject_ModuleGraphcolonObjectType___nOSrcYqJTxXt2ptNc0gnWg* graph, tyObject_TPassContext__dmp6pRpfXxJk6gIZHkm7dw* p, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n);
struct tyTuple__nF9cH4hinXgGEUwO4G2bshw {
tyProc__kqPx9c4py2HW6KcFMhNvxtg Field0;
tyProc__9c6qRjwy7Es8UkDTIUwAfFA Field1;
tyProc__mv4BsRs5VEnhcxzV6pQU5w Field2;
NIM_BOOL Field3;
};
struct tyTuple__0q9cmhneJEKnQERTpXXdz6Q {
NU32 Field0;
NimStringDesc* Field1;
};
struct tyObject_PackedLineInfo__wqhF27DCtLcrB2XHUZKKiA {
NU16 line;
NI16 col;
NU32 file;
};
struct tyObject_PackedNode__9aA1ZskrZ0b0RCXxY4Hw8YA {
tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw kind;
tySet_tyEnum_TNodeFlag__0RUKWdbLPY3l0smKVGDLMg flags;
NI32 operand;
tyObject_PackedItemId__QkYBSICiQaMI6SmH4FJVoQ typeId_0;
tyObject_PackedLineInfo__wqhF27DCtLcrB2XHUZKKiA info;
};
struct tyTuple__Izx9aRSX9a0diDXD84jOS9aMQ {
NU32 Field0;
NI32 Field1;
};
struct tyTuple__PsEhl3dzznmmJiLAuIXZOg {
NU32 Field0;
tyObject_PackedItemId__QkYBSICiQaMI6SmH4FJVoQ Field1;
};
struct tyTuple__Dg3ILQdzHFjrYRx6Xwbq3w {
tyObject_PackedItemId__QkYBSICiQaMI6SmH4FJVoQ Field0;
tyObject_PackedLineInfo__wqhF27DCtLcrB2XHUZKKiA Field1;
};
struct tyTuple__Db8CrQifKGIsKc3w71w7Lw {
tyObject_PackedItemId__QkYBSICiQaMI6SmH4FJVoQ Field0;
tyObject_PackedItemId__QkYBSICiQaMI6SmH4FJVoQ Field1;
};
struct tyObject_PackedInstantiation__wt9ao6lqcInu9aOmUoxgkWcg {
tyObject_PackedItemId__QkYBSICiQaMI6SmH4FJVoQ key;
tyObject_PackedItemId__QkYBSICiQaMI6SmH4FJVoQ sym;
tySequence__lo3S1lKyiPLhGGB9cBawd6A* concreteTypes;
};
struct tyTuple__Q9cwWJO3ddVfos2xI7N9cHHQ {
tyEnum_TTypeAttachedOp__0IDqFfYT9a3F5i6tmCmdORQ Field0;
tyObject_PackedItemId__QkYBSICiQaMI6SmH4FJVoQ Field1;
tyObject_PackedItemId__QkYBSICiQaMI6SmH4FJVoQ Field2;
};
struct tyTuple__FEYH9alRJhHD0uTKF2vnIqw {
tyObject_PackedItemId__QkYBSICiQaMI6SmH4FJVoQ Field0;
NI Field1;
tyObject_PackedItemId__QkYBSICiQaMI6SmH4FJVoQ Field2;
};
typedef NU8 tyEnum_TLibKind__tW9cjoYNrpn2JX4q6fqRnxQ;
struct tyObject_PackedLib__djDv9aFBRsdjnMVLdFGA0nA {
tyEnum_TLibKind__tW9cjoYNrpn2JX4q6fqRnxQ kind;
NIM_BOOL generated;
NIM_BOOL isOverriden;
NU32 name;
NI32 path;
};
struct tyObject_PackedSym__fAjcBcJ2JPtzDDxyIN8WmA {
tyEnum_TSymKind__sjiB9b9aO1FRPetW6gPYZbfw kind;
NU32 name;
tyObject_PackedItemId__QkYBSICiQaMI6SmH4FJVoQ typ;
tySet_tyEnum_TSymFlag__9be9c6fEXk5NwyPvxxb6toPA flags;
tyEnum_TMagic__3qAy6bDUDlF8Fc2RR6pF9ag magic;
tyObject_PackedLineInfo__wqhF27DCtLcrB2XHUZKKiA info;
NI32 ast;
tyObject_PackedItemId__QkYBSICiQaMI6SmH4FJVoQ owner;
tyObject_PackedItemId__QkYBSICiQaMI6SmH4FJVoQ guard;
NI bitsize;
NI alignment;
tySet_tyEnum_TOption__HPX9bEWraE8wyYLoP9bHbKYQ options;
NI position;
NI offset;
NU32 externalName;
tySet_tyEnum_TLocFlag__Ic4ywZl9cdJtKSUkG4WZfHw locFlags;
tyObject_PackedLib__djDv9aFBRsdjnMVLdFGA0nA annex;
NI32 constraint;
};
struct tyObject_PackedType__MvipqCfEd9b9bJbbBPwsUOiw {
tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg kind;
tyEnum_TCallingConvention__5kpSva5OFmGFHujbio7C9cg callConv;
tySet_tyEnum_TTypeFlag__Vrztsndr9a9bj8bQ3cn49bwWw flags;
tySequence__lo3S1lKyiPLhGGB9cBawd6A* types;
NI32 n;
tyObject_PackedItemId__QkYBSICiQaMI6SmH4FJVoQ sym;
tyObject_PackedItemId__QkYBSICiQaMI6SmH4FJVoQ owner;
NI64 size;
NI16 align;
NI16 paddingAtEnd;
NI16 lockLevel;
tyObject_PackedItemId__QkYBSICiQaMI6SmH4FJVoQ typeInst;
NI32 nonUniqueId;
};
struct tyTuple__VUJ5Hjm4tKAResBsRHJvYg {
NI Field0;
tyObject_TIdent__PKDcQ7dqdhiSW9c9cXUFFpMg* Field1;
tySequence__lo3S1lKyiPLhGGB9cBawd6A* Field2;
};
struct tyTuple__UvldbCB6B9ayi9bGYW7vJNLA {
NI Field0;
NI32 Field1;
NU32 Field2;
};
struct tySequence__vKogasEnJSPhbQmA8r4Y9aA {
  TGenericSeq Sup;
  tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* data[SEQ_DECL_SIZE];
};
struct tySequence__IeU9azYSNIK3V9b36Ir6NZcw {
  TGenericSeq Sup;
  tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* data[SEQ_DECL_SIZE];
};
struct tySequence__ZQPym9bf1jM5qaSn7LUXMKA {
  TGenericSeq Sup;
  tyObject_TIdPair__CEfaiHL4gHg86NKgeeQ7lA data[SEQ_DECL_SIZE];
};
struct tySequence__9boKiNhY9cnRQF2k9b9a9bGKbrA {
  TGenericSeq Sup;
  tyObject_ImportedModule__ABXo2nVfMtcWNYv5zEiXDg data[SEQ_DECL_SIZE];
};
struct tySequence__ed0C0uAUZPhvw3RAc5hfYg {
  TGenericSeq Sup;
  tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* data[SEQ_DECL_SIZE];
};
struct tySequence__vvBerF0axaNtu9aMA2gnsrA {
  TGenericSeq Sup;
  tyObject_TOptionEntry__KcSoeh10J9aas3WZevEUD7Q* data[SEQ_DECL_SIZE];
};
struct tySequence__9c3OY0aBmSBgwdsnBAPf4Ag {
  TGenericSeq Sup;
  tyObject_TLib__W49cDqPTe2Tvc1mw7CVZOFg* data[SEQ_DECL_SIZE];
};
struct tySequence__q9cq1Li6c1nMjHpacEbCj0g {
  TGenericSeq Sup;
  tyObject_TrunkcolonObjectType___2fEZuM4UuXkgO9bDnaMLLWg* data[SEQ_DECL_SIZE];
};
struct tySequence__yH9bx9bpa6jqsU89cxjyTAlPQ {
  TGenericSeq Sup;
  tyObject_TInstantiationPair__d4lcZMnmQK2Jh2jYkdgB4w data[SEQ_DECL_SIZE];
};
struct tySequence__Jhh6ks9carRtwV9aOuM8yMNw {
  TGenericSeq Sup;
  tyTuple__8vGER9aaTtt9bUk9avNQ3fEIg data[SEQ_DECL_SIZE];
};
struct tySequence__Bis5AbpONWcIRrPyPJS8Yw {
  TGenericSeq Sup;
  tyTuple__NAaJgGVgNmlGoqmiWxdOHQ data[SEQ_DECL_SIZE];
};
struct tySequence__E8pi9b5QNahsURYzXMjh3qw {
  TGenericSeq Sup;
  tyTuple__47w2DboNEPf69aPgubZdd7Q data[SEQ_DECL_SIZE];
};
struct tySequence__k7EQb9bN3Uhl608xoPGMRJA {
  TGenericSeq Sup;
  tyTuple__toqrUPSdp8zSxOdlxMJj9cA data[SEQ_DECL_SIZE];
};
struct tySequence__XDpbjnuseLNZDGLBQ2Qzow {
  TGenericSeq Sup;
  tyTuple__VbApVidEWCFLq9a29bPtaS7A data[SEQ_DECL_SIZE];
};
struct tySequence__qwqHTkRvwhrRyENtudHQ7g {
  TGenericSeq Sup;
  NI data[SEQ_DECL_SIZE];
};
struct tySequence__QqvaCqCpEE1QmQZbcZLi5A {
  TGenericSeq Sup;
  tyTuple__EbsafWGli8bW2GRJQ9apsjA data[SEQ_DECL_SIZE];
};
struct tySequence__RNhZxf20g9beyq5VBOGxhDg {
  TGenericSeq Sup;
  tyObject_Iface__4y9aWdJBxraQYTl5Pa1NMuQ data[SEQ_DECL_SIZE];
};
struct tySequence__JbK5aK9aVhc9cJZzQYg1wQlQ {
  TGenericSeq Sup;
  tyObject_LoadedModule__fihS6xbKhtLC0fhM28Cpeg data[SEQ_DECL_SIZE];
};
struct tySequence__lFbCtu5P2Kf7YDYtGjkxAQ {
  TGenericSeq Sup;
  tyObject_PackedEncoder__ftUl9bxYRlbT5ToKkxHdbfQ data[SEQ_DECL_SIZE];
};
struct tySequence__dlD6tEGzYLLpKVq3XwuFlA {
  TGenericSeq Sup;
  tyObject_LazyType__wgv9a1JCOBXm9azerxcvz5gQ data[SEQ_DECL_SIZE];
};
struct tySequence__ijtae5OneaLys0hN9alAicA {
  TGenericSeq Sup;
  tyTuple__UluY8x0Nj6cp9b0o88wJ0lg data[SEQ_DECL_SIZE];
};
struct tySequence__6OFCSvqRaxyEgUqWtnZSlw {
  TGenericSeq Sup;
  tyObject_LazyInstantiation__0l1i6PfjQKnMEvpGMAoN8Q data[SEQ_DECL_SIZE];
};
struct tySequence__SerjNoUujW2dUouVBrJiCw {
  TGenericSeq Sup;
  tyTuple__rZZA0skon1OsHdiEvT8RZQ data[SEQ_DECL_SIZE];
};
struct tySequence__K9agbtcb0qPZuSJFXB9cTe6g {
  TGenericSeq Sup;
  tyTuple__q13Zt16VkCqu6Zg5jWqwHA data[SEQ_DECL_SIZE];
};
struct tySequence__m4PVWjcAAjfxlwJxLkKn8A {
  TGenericSeq Sup;
  tyTuple__RWXAsQlFoGYyEQZp1G65sg data[SEQ_DECL_SIZE];
};
struct tySequence__m88qdML9cQOuqGAQn6XWL1A {
  TGenericSeq Sup;
  tyTuple__aWN9bNzF9bubXNJV9ciomgpfA data[SEQ_DECL_SIZE];
};
struct tySequence__naEbXEp9b9aiW1zXJorqf9cXQ {
  TGenericSeq Sup;
  tyTuple__RmGJuqOgEaHckHndh0LEsw data[SEQ_DECL_SIZE];
};
struct tySequence__7lEisrXlQEzwtUKW5pzRCw {
  TGenericSeq Sup;
  tyTuple__xYhUhS7X82rKTqbT9bRfCnw data[SEQ_DECL_SIZE];
};
struct tySequence__48JTohSgTy339bRxHzUD8KA {
  TGenericSeq Sup;
  NI32 data[SEQ_DECL_SIZE];
};
struct tySequence__fdmz6VkIf1ewwrssKYqRFg {
  TGenericSeq Sup;
  tyTuple__1mtQ8sCEE7DbfIuQciv9b5Q data[SEQ_DECL_SIZE];
};
struct tySequence__kxu4GK0onha2t9bo86mdVAg {
  TGenericSeq Sup;
  tyTuple__xDU9bZmv1ZbZkJDaATBekIQ data[SEQ_DECL_SIZE];
};
struct tySequence__i89c5kdtWKzK3OEiI81pkkw {
  TGenericSeq Sup;
  tyObject_SymInfoPair__SjZT5Rln3r9befMWWSryQ0A data[SEQ_DECL_SIZE];
};
struct tySequence__KgiZ29chkJAD01p9aLRB32qw {
  TGenericSeq Sup;
  tyTuple__J4cxakKjhKxTIJR9bojMmXw data[SEQ_DECL_SIZE];
};
struct tySequence__GR8qmV1kNRcoQ2g76VFy3A {
  TGenericSeq Sup;
  tyObject_SuggestcolonObjectType___VUPO9alfTq2Ar9a7ZtY9cSPDg* data[SEQ_DECL_SIZE];
};
struct tySequence__rkYRZrbHVYL3nhXlQW3K9bw {
  TGenericSeq Sup;
  tyTuple__VwWg1orPZ9b5Rg9aZAI6SIaQ data[SEQ_DECL_SIZE];
};
struct tySequence__IRFEb1e9bxgbJLuB5xrdZsQ {
  TGenericSeq Sup;
  tyTuple__a7QginWFapakKbWJBJ2vfA data[SEQ_DECL_SIZE];
};
struct tySequence__YmPd0eWfcTfrVYrthlXPYA {
  TGenericSeq Sup;
  tyTuple__mPT6B9cVWqwVnWb1Fxx9bgyA data[SEQ_DECL_SIZE];
};
struct tySequence__fIB1rTQ55aFonoft9a9bmljQ {
  TGenericSeq Sup;
  tyTuple__OJFzEczluV8Jmo9bRpBfkzw data[SEQ_DECL_SIZE];
};
struct tySequence__Hz5SYwQU29b9aFLt09blvVQPg {
  TGenericSeq Sup;
  tyTuple__kbX6x85REySUrk9auORL0vw data[SEQ_DECL_SIZE];
};
struct tySequence__squ9b9bUH4OLHf6cEMrt6hVA {
  TGenericSeq Sup;
  tyTuple__F3gkSrMB1qp2Tvf9bixVXwg data[SEQ_DECL_SIZE];
};
struct tySequence__3G9aA9cLXaPxuRxMKm3anacQ {
  TGenericSeq Sup;
  tyTuple__Ah6ua9a8WyUOs9aO9afW59cy0g data[SEQ_DECL_SIZE];
};
struct tySequence__bPFv6ypvvCX2A9a9al8utL2Q {
  TGenericSeq Sup;
  tyTuple__nF9cH4hinXgGEUwO4G2bshw data[SEQ_DECL_SIZE];
};
struct tySequence__qeAsXh2i1GAL5Nl0g3OP8g {
  TGenericSeq Sup;
  tyObject_LazySym__Xts9a2Mw4b4jtq73p6MrfJg data[SEQ_DECL_SIZE];
};
struct tySequence__PXIzfWocnrafGz5p3CP5LA {
  TGenericSeq Sup;
  tyTuple__0q9cmhneJEKnQERTpXXdz6Q data[SEQ_DECL_SIZE];
};
struct tySequence__9bAGqSvkAaFL9bWjsEPslrFA {
  TGenericSeq Sup;
  NU32 data[SEQ_DECL_SIZE];
};
struct tySequence__4Murtwnm0Fyc7F9acrytEXw {
  TGenericSeq Sup;
  tyObject_PackedNode__9aA1ZskrZ0b0RCXxY4Hw8YA data[SEQ_DECL_SIZE];
};
struct tySequence__b89aLriiJnVTD186H6zNIgg {
  TGenericSeq Sup;
  tyTuple__Izx9aRSX9a0diDXD84jOS9aMQ data[SEQ_DECL_SIZE];
};
struct tySequence__wE9cZkGC9cv7Iz9ckZOIyaW9aw {
  TGenericSeq Sup;
  tyTuple__PsEhl3dzznmmJiLAuIXZOg data[SEQ_DECL_SIZE];
};
struct tySequence__QnmOtn1Iv4LvxOXoMn8Rbg {
  TGenericSeq Sup;
  tyTuple__Dg3ILQdzHFjrYRx6Xwbq3w data[SEQ_DECL_SIZE];
};
struct tySequence__oKtVqsc9bQVCNyrijELM4OQ {
  TGenericSeq Sup;
  tyTuple__Db8CrQifKGIsKc3w71w7Lw data[SEQ_DECL_SIZE];
};
struct tySequence__qy6Iwdy00wN560qud54HTg {
  TGenericSeq Sup;
  tyObject_PackedInstantiation__wt9ao6lqcInu9aOmUoxgkWcg data[SEQ_DECL_SIZE];
};
struct tySequence__k67v9bwvvQDmS1ynyGGUbeQ {
  TGenericSeq Sup;
  tyTuple__Q9cwWJO3ddVfos2xI7N9cHHQ data[SEQ_DECL_SIZE];
};
struct tySequence__cLsClAAfd0MKkoBQVyvdvw {
  TGenericSeq Sup;
  tyTuple__FEYH9alRJhHD0uTKF2vnIqw data[SEQ_DECL_SIZE];
};
struct tySequence__sM4lkSb7zS6F7OVMvW9cffQ {
  TGenericSeq Sup;
  NimStringDesc* data[SEQ_DECL_SIZE];
};
struct tySequence__q9bTuOB0JXh1iZ3CSGdRLbg {
  TGenericSeq Sup;
  tyObject_PackedSym__fAjcBcJ2JPtzDDxyIN8WmA data[SEQ_DECL_SIZE];
};
struct tySequence__DPZr9aMyRppVlNZ9ajSyOZ9bw {
  TGenericSeq Sup;
  tyObject_PackedType__MvipqCfEd9b9bJbbBPwsUOiw data[SEQ_DECL_SIZE];
};
struct tySequence__IHUFRsFxZNv7YydiUO2esQ {
  TGenericSeq Sup;
  NI64 data[SEQ_DECL_SIZE];
};
struct tySequence__lo3S1lKyiPLhGGB9cBawd6A {
  TGenericSeq Sup;
  tyObject_PackedItemId__QkYBSICiQaMI6SmH4FJVoQ data[SEQ_DECL_SIZE];
};
struct tySequence__C3r8jsj9chA4sIlYfDN5aDw {
  TGenericSeq Sup;
  tyTuple__VUJ5Hjm4tKAResBsRHJvYg data[SEQ_DECL_SIZE];
};
struct tySequence__9cnx3zXnWzeclW8Ko4oUgAQ {
  TGenericSeq Sup;
  tyTuple__UvldbCB6B9ayi9bGYW7vJNLA data[SEQ_DECL_SIZE];
};
struct tySequence__UnGSk9aaLosDroi2QDrlOfQ {
  TGenericSeq Sup;
  tyObject_FullId__L64puUgQnoQ6OMvT9c6V9cPg data[SEQ_DECL_SIZE];
};
N_LIB_PRIVATE N_NIMCALL(tyObject_LayeredIdTablecolonObjectType___9aSR8D74Pb4ozXN6gEJ9a1Pw*, initLayeredTypeMap__semtypinst_134)(tyObject_TIdTable__Cs7vbulfMjKciTA2Uv9b6vQ pt);
N_LIB_PRIVATE N_NIMCALL(void, nimGCvisit)(void* d, NI op);
static N_NIMCALL(void, Marker_tyRef__bE7TGBjv9bCsVJO148OW9cHA)(void* p, NI op);
N_LIB_PRIVATE N_NOINLINE(void*, newObj)(TNimType* typ, NI size);
N_LIB_PRIVATE N_NIMCALL(void, copyIdTable__ast_3589)(tyObject_TIdTable__Cs7vbulfMjKciTA2Uv9b6vQ* dest, tyObject_TIdTable__Cs7vbulfMjKciTA2Uv9b6vQ src);
static N_INLINE(void, nimZeroMem)(void* p, NI size);
static N_INLINE(void, nimSetMem__systemZmemory_7)(void* a, int v, NI size);
N_LIB_PRIVATE N_NIMCALL(void, initTypeVars__semtypinst_1018)(tyObject_TContext__TE0bwjD2I16QW6s9c4AgPvw* p, tyObject_LayeredIdTablecolonObjectType___9aSR8D74Pb4ozXN6gEJ9a1Pw* typeMap, tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw info, tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* owner, tyObject_TReplTypeVars__itU2h89a2PcJoJ5bHADfePw* Result);
N_LIB_PRIVATE N_NIMCALL(void, unsureAsgnRef)(void** dest, void* src);
N_LIB_PRIVATE N_NIMCALL(void, initIdTable__ast_4084)(tyObject_TIdTable__Cs7vbulfMjKciTA2Uv9b6vQ* x);
N_LIB_PRIVATE N_NIMCALL(void, pushInfoContext__msgs_500)(tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ* conf, tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw info, NimStringDesc* detail);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw*, replaceTypeVarsN__semtypinst_130)(tyObject_TReplTypeVars__itU2h89a2PcJoJ5bHADfePw* cl, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n, NI start);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw*, copyNode__ast_4324)(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* src);
N_LIB_PRIVATE N_NIMCALL(tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA*, replaceTypeVarsT__semtypinst_178)(tyObject_TReplTypeVars__itU2h89a2PcJoJ5bHADfePw* cl, tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* t);
N_LIB_PRIVATE N_NIMCALL(tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA*, replaceTypeVarsTAux__semtypinst_124)(tyObject_TReplTypeVars__itU2h89a2PcJoJ5bHADfePw* cl, tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* t);
N_LIB_PRIVATE N_NIMCALL(tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA*, lookup__semtypinst_158)(tyObject_LayeredIdTablecolonObjectType___9aSR8D74Pb4ozXN6gEJ9a1Pw* typeMap, tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* key);
N_LIB_PRIVATE N_NIMCALL(RootObj*, idTableGet__astalgo_64)(tyObject_TIdTable__Cs7vbulfMjKciTA2Uv9b6vQ t, tyObject_TIdObj__1qw9bcK4rZXhGbJEJhkKQFA* key);
N_LIB_PRIVATE N_NIMCALL(tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA*, handleGenericInvocation__semtypinst_521)(tyObject_TReplTypeVars__itU2h89a2PcJoJ5bHADfePw* cl, tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* t);
N_LIB_PRIVATE N_NIMCALL(void, internalErrorImpl__msgs_1441)(tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ* conf, tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw info, NimStringDesc* errMsg, tyTuple__kN8up2W6YKc5YA9avn5mV5w info2);
N_LIB_PRIVATE N_NIMCALL(tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA*, searchInstTypes__semtypinst_44)(tyObject_ModuleGraphcolonObjectType___nOSrcYqJTxXt2ptNc0gnWg* g, tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* key);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, contains__modulegraphs_3033)(tyObject_Table__nODIJ5l6JnEl9a6LYuqISLA t, tyObject_ItemId__wg9aowaxscbUe2F0nV9btZLg key);
N_LIB_PRIVATE N_NIMCALL(tySequence__dlD6tEGzYLLpKVq3XwuFlA**, X5BX5D___modulegraphs_3349)(tyObject_Table__nODIJ5l6JnEl9a6LYuqISLA* t, tyObject_ItemId__wg9aowaxscbUe2F0nV9btZLg key);
N_LIB_PRIVATE N_NIMCALL(tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA*, resolveType__modulegraphs_2889)(tyObject_ModuleGraphcolonObjectType___nOSrcYqJTxXt2ptNc0gnWg* g, tyObject_LazyType__wgv9a1JCOBXm9azerxcvz5gQ* t);
static N_INLINE(NI, len__ast_3990)(tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* n);
static N_INLINE(NIM_BOOL, sameFlags__types_2287)(tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* a, tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* b);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, compareTypes__types_2720)(tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* x, tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* y, tyEnum_TDistinctCompare__UuPcvyG2RecjPyQDW4WlFw cmp, tySet_tyEnum_TTypeCmpFlag__IRq9bqtrf9ctEUyeRMyvWy4Q flags);
N_LIB_PRIVATE N_NIMCALL(tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA*, lookupTypeVar__semtypinst_476)(tyObject_TReplTypeVars__itU2h89a2PcJoJ5bHADfePw* cl, tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* t);
N_LIB_PRIVATE N_NOINLINE(void, liMessage__msgs_1128)(tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ* conf, tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw info, tyEnum_TMsgKind__J0cVyqzpFKvufCivtQUgHQ msg, NimStringDesc* arg, tyEnum_TErrorHandling__sOC1wCv9bUYRquMih1VRi3w eh, tyTuple__kN8up2W6YKc5YA9avn5mV5w info2, NIM_BOOL isRaw);
static N_INLINE(void, appendString)(NimStringDesc* dest, NimStringDesc* src);
static N_INLINE(void, copyMem__system_1733)(void* dest, void* source, NI size);
static N_INLINE(void, nimCopyMem)(void* dest, void* source, NI size);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, typeToString__types_50)(tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* typ, tyEnum_TPreferedDesc__lx9aDnWjKktcSUo0yfjOvMg prefer);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, rawNewString)(NI space);
N_LIB_PRIVATE N_NIMCALL(tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA*, errorType__semdata_1032)(tyObject_TContext__TE0bwjD2I16QW6s9c4AgPvw* c);
N_LIB_PRIVATE N_NIMCALL(void, idTablePut__astalgo_70)(tyObject_TIdTable__Cs7vbulfMjKciTA2Uv9b6vQ* t, tyObject_TIdObj__1qw9bcK4rZXhGbJEJhkKQFA* key, RootObj* val);
N_LIB_PRIVATE N_NIMCALL(tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA*, instCopyType__semtypinst_492)(tyObject_TReplTypeVars__itU2h89a2PcJoJ5bHADfePw* cl, tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* t);
N_LIB_PRIVATE N_NIMCALL(tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA*, exactReplica__ast_4039)(tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* t);
N_LIB_PRIVATE N_NIMCALL(tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA*, copyType__ast_4034)(tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* t, tyObject_ItemId__wg9aowaxscbUe2F0nV9btZLg id, tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* owner);
static N_INLINE(tyObject_ItemId__wg9aowaxscbUe2F0nV9btZLg, nextTypeId__ast_3122)(tyObject_IdGeneratorcolonObjectType___WVCsDyf9bR1PcjDFjcjm9bRg* x);
N_LIB_PRIVATE N_NIMCALL(void, copyTypeProps__modulegraphs_8910)(tyObject_ModuleGraphcolonObjectType___nOSrcYqJTxXt2ptNc0gnWg* g, NI module, tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* dest, tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* src);
static N_INLINE(void, asgnRef)(void** dest, void* src);
static N_INLINE(void, incRef__system_5311)(tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g* c);
static N_INLINE(NI, pluspercent___system_696)(NI x, NI y);
static N_INLINE(tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g*, usrToCell__system_5273)(void* usr);
static N_INLINE(NI, minuspercent___system_716)(NI x, NI y);
static N_INLINE(void, decRef__system_5318)(tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g* c);
static N_INLINE(NIM_BOOL, ltpercent___system_1005)(NI x, NI y);
static N_INLINE(void, rtlAddZCT__system_5316)(tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g* c);
N_LIB_PRIVATE N_NOINLINE(void, addZCT__system_5267)(tyObject_CellSeq__nav876ELHgxScHhs30CKiA* s, tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g* c);
N_LIB_PRIVATE N_NIMCALL(void, propagateToOwner__ast_4207)(tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* owner, tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* elem, NIM_BOOL propagateHasAsgn);
N_LIB_PRIVATE N_NIMCALL(tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA*, newType__ast_3884)(tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg kind, tyObject_ItemId__wg9aowaxscbUe2F0nV9btZLg id, tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* owner);
N_LIB_PRIVATE N_NIMCALL(void*, newSeq)(TNimType* typ, NI len);
N_LIB_PRIVATE N_NIMCALL(void, cacheTypeInst__semtypinst_88)(tyObject_TContext__TE0bwjD2I16QW6s9c4AgPvw* c, tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* inst);
N_LIB_PRIVATE N_NIMCALL(tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA*, lastSon__ast_3731)(tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* n);
N_LIB_PRIVATE N_NIMCALL(void, addToGenericCache__semdata_2424)(tyObject_TContext__TE0bwjD2I16QW6s9c4AgPvw* c, tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* s, tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* inst);
N_LIB_PRIVATE N_NIMCALL(tyObject_LayeredIdTablecolonObjectType___9aSR8D74Pb4ozXN6gEJ9a1Pw*, newTypeMapLayer__semtypinst_155)(tyObject_TReplTypeVars__itU2h89a2PcJoJ5bHADfePw* cl);
N_LIB_PRIVATE N_NIMCALL(void, rawAddSon__ast_4276)(tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* father, tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* son, NIM_BOOL propagateHasAsgn);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, isGenericAlias__types_2267)(tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* t);
N_LIB_PRIVATE N_NIMCALL(tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA*, skipGenericAlias__types_2281)(tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* t);
N_LIB_PRIVATE N_NIMCALL(void, checkPartialConstructedType__semtypinst_13)(tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ* conf, tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw info, tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* t);
N_LIB_PRIVATE N_NIMCALL(tyObject_TSym__3r34mwqcVmg5JFNmiaVncw*, getAttachedOp__modulegraphs_4049)(tyObject_ModuleGraphcolonObjectType___nOSrcYqJTxXt2ptNc0gnWg* g, tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* t, tyEnum_TTypeAttachedOp__0IDqFfYT9a3F5i6tmCmdORQ op);
N_LIB_PRIVATE N_NIMCALL(void, setAttachedOp__modulegraphs_4445)(tyObject_ModuleGraphcolonObjectType___nOSrcYqJTxXt2ptNc0gnWg* g, NI module, tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* t, tyEnum_TTypeAttachedOp__0IDqFfYT9a3F5i6tmCmdORQ op, tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* value);
N_LIB_PRIVATE N_NIMCALL(tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA*, skipTypes__ast_3723)(tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* t, tySet_tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg kinds);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, contains__modulegraphs_7294)(tyObject_Table__KsPP7K7LW9aa3YAq1XN9cDZg t, tyObject_ItemId__wg9aowaxscbUe2F0nV9btZLg key);
N_LIB_PRIVATE N_NIMCALL(tySequence__m4PVWjcAAjfxlwJxLkKn8A**, X5BX5D___modulegraphs_7610)(tyObject_Table__KsPP7K7LW9aa3YAq1XN9cDZg* t, tyObject_ItemId__wg9aowaxscbUe2F0nV9btZLg key);
N_LIB_PRIVATE N_NIMCALL(tyObject_TSym__3r34mwqcVmg5JFNmiaVncw*, resolveSym__modulegraphs_2904)(tyObject_ModuleGraphcolonObjectType___nOSrcYqJTxXt2ptNc0gnWg* g, tyObject_LazySym__Xts9a2Mw4b4jtq73p6MrfJg* t);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw*, prepareNode__semtypinst_182)(tyObject_TReplTypeVars__itU2h89a2PcJoJ5bHADfePw* cl, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n);
N_LIB_PRIVATE N_NIMCALL(tyObject_TSym__3r34mwqcVmg5JFNmiaVncw*, replaceTypeVarsS__semtypinst_127)(tyObject_TReplTypeVars__itU2h89a2PcJoJ5bHADfePw* cl, tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* s);
N_LIB_PRIVATE N_NIMCALL(tyObject_TSym__3r34mwqcVmg5JFNmiaVncw*, copySym__ast_4042)(tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* s, tyObject_ItemId__wg9aowaxscbUe2F0nV9btZLg id);
static N_INLINE(tyObject_ItemId__wg9aowaxscbUe2F0nV9btZLg, nextSymId__ast_3103)(tyObject_IdGeneratorcolonObjectType___WVCsDyf9bR1PcjDFjcjm9bRg* x);
static N_INLINE(NI, safeLen__ast_3148)(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n);
static N_INLINE(NI, len__ast_3155)(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n);
N_LIB_PRIVATE N_NIMCALL(void, add__ast_4798)(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* father, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* son);
N_LIB_PRIVATE N_NIMCALL(tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA*, newTypeS__semdata_763)(tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg kind, tyObject_TContext__TE0bwjD2I16QW6s9c4AgPvw* c);
static N_INLINE(void, nimGCunrefNoCycle)(void* p);
N_LIB_PRIVATE N_NIMCALL(void*, newSeqRC1)(TNimType* typ, NI len);
static N_INLINE(tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA*, skipIntLit__magicsys_124)(tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* t, tyObject_IdGeneratorcolonObjectType___WVCsDyf9bR1PcjDFjcjm9bRg* id);
N_LIB_PRIVATE N_NIMCALL(tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA*, makeTypeDesc__concepts_49)(tyObject_TContext__TE0bwjD2I16QW6s9c4AgPvw* c, tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* typ);
N_LIB_PRIVATE N_NIMCALL(tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA*, base__types_63)(tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* t);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, containsGenericType__types_3412)(tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* t);
static N_INLINE(NimStringDesc*, toFileLineCol__msgs_625)(tyTuple__kN8up2W6YKc5YA9avn5mV5w info);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, resizeString)(NimStringDesc* dest, NI addlen);
static N_INLINE(void, addInt__stdZprivateZdigitsutils_189)(NimStringDesc** result, NI x);
N_LIB_PRIVATE N_NIMCALL(void, addInt__stdZprivateZdigitsutils_167)(NimStringDesc** result, NI64 x);
N_LIB_PRIVATE N_NIMCALL(void, propagateFieldFlags__semtypinst_786)(tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* t, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n);
N_LIB_PRIVATE N_NIMCALL(void, eraseVoidParams__semtypinst_694)(tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* t);
N_LIB_PRIVATE N_NIMCALL(TGenericSeq*, setLengthSeqV2)(TGenericSeq* s, TNimType* typ, NI newLen);
N_LIB_PRIVATE N_NIMCALL(void, skipIntLiteralParams__semtypinst_750)(tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* t, tyObject_IdGeneratorcolonObjectType___WVCsDyf9bR1PcjDFjcjm9bRg* idgen);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw*, replaceObjBranches__semtypinst_277)(tyObject_TReplTypeVars__itU2h89a2PcJoJ5bHADfePw* cl, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n);
N_LIB_PRIVATE N_NIMCALL(void, illFormedAst__semdata_1101)(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n, tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ* conf);
N_LIB_PRIVATE N_NIMCALL(void, checkSonsLen__semdata_1107)(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n, NI length, tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ* conf);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw*, newNodeI__ast_3320)(tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw kind, tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw info);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, hasValuelessStatics__semtypinst_329)(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw*, reResolveCallsWithTypedescParams__semtypinst_246)(tyObject_TReplTypeVars__itU2h89a2PcJoJ5bHADfePw* cl, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, isTypeParam__semtypinst_227)(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw*, newSymNode__ast_3704)(tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* sym);
N_LIB_PRIVATE N_NIMCALL(void, newSons__semtypinst_416)(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* father, NI length);
N_LIB_PRIVATE N_NIMCALL(void, popInfoContext__msgs_517)(tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ* conf);
N_LIB_PRIVATE N_NIMCALL(void, recomputeFieldPositions__semtypinst_1042)(tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* t, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* obj, NI* currPosition);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw*, lastSon__ast_4833)(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n);
N_LIB_PRIVATE N_NIMCALL(NI64, computeSize__types_3369)(tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ* conf, tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* typ);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, isTupleRecursive__types_4060)(tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* t);
N_LIB_PRIVATE TNimType NTIlayeredidtable58objecttype__9aSR8D74Pb4ozXN6gEJ9a1Pw_;
extern TNimType NTItidtable__Cs7vbulfMjKciTA2Uv9b6vQ_;
N_LIB_PRIVATE TNimType NTIlayeredidtable__bE7TGBjv9bCsVJO148OW9cHA_;
STRING_LITERAL(TM__ro83HSRkGiU2zIkT6iR9aSA_3, "no generic body", 15);
STRING_LITERAL(TM__ro83HSRkGiU2zIkT6iR9aSA_5, "/home/runner/work/nightlies/nightlies/nim/compiler/semtypinst.nim", 65);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__ro83HSRkGiU2zIkT6iR9aSA_4 = {((NimStringDesc*) &TM__ro83HSRkGiU2zIkT6iR9aSA_5),
((NI) 348),
((NI) 17)}
;
STRING_LITERAL(TM__ro83HSRkGiU2zIkT6iR9aSA_6, "cannot instantiate: \'", 21);
STRING_LITERAL(TM__ro83HSRkGiU2zIkT6iR9aSA_7, "\'", 1);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__ro83HSRkGiU2zIkT6iR9aSA_8 = {((NimStringDesc*) &TM__ro83HSRkGiU2zIkT6iR9aSA_5),
((NI) 312),
((NI) 14)}
;
STRING_LITERAL(TM__ro83HSRkGiU2zIkT6iR9aSA_9, "substitution with generic parameter", 35);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__ro83HSRkGiU2zIkT6iR9aSA_10 = {((NimStringDesc*) &TM__ro83HSRkGiU2zIkT6iR9aSA_5),
((NI) 319),
((NI) 17)}
;
extern TNimType NTIttypeseq__vKogasEnJSPhbQmA8r4Y9aA_;
STRING_LITERAL(TM__ro83HSRkGiU2zIkT6iR9aSA_11, "type \'var var\' is not allowed", 29);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__ro83HSRkGiU2zIkT6iR9aSA_12 = {((NimStringDesc*) &TM__ro83HSRkGiU2zIkT6iR9aSA_5),
((NI) 21),
((NI) 14)}
;
static NIM_CONST tySet_tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg TM__ro83HSRkGiU2zIkT6iR9aSA_13 = {
0x10, 0xa9, 0xe0, 0x00, 0x00, 0xe0, 0x80, 0x00,
0x00}
;
STRING_LITERAL(TM__ro83HSRkGiU2zIkT6iR9aSA_14, "\'; Maybe generic arguments are missing\?", 39);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__ro83HSRkGiU2zIkT6iR9aSA_15 = {((NimStringDesc*) &TM__ro83HSRkGiU2zIkT6iR9aSA_5),
((NI) 557),
((NI) 14)}
;
static NIM_CONST tySet_tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg TM__ro83HSRkGiU2zIkT6iR9aSA_16 = {
0x00, 0x01, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
0x00}
;
STRING_LITERAL(TM__ro83HSRkGiU2zIkT6iR9aSA_17, "cannot instantiate \'", 20);
STRING_LITERAL(TM__ro83HSRkGiU2zIkT6iR9aSA_18, "\' inside of type definition: \'", 30);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__ro83HSRkGiU2zIkT6iR9aSA_19 = {((NimStringDesc*) &TM__ro83HSRkGiU2zIkT6iR9aSA_5),
((NI) 631),
((NI) 22)}
;
static NIM_CONST tySet_tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg TM__ro83HSRkGiU2zIkT6iR9aSA_20 = {
0x10, 0x00, 0x00, 0x00, 0x00, 0x60, 0x00, 0x00,
0x00}
;
static NIM_CONST tySet_tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg TM__ro83HSRkGiU2zIkT6iR9aSA_21 = {
0x00, 0x00, 0x60, 0x00, 0x00, 0x00, 0x00, 0x00,
0x00}
;
STRING_LITERAL(TM__ro83HSRkGiU2zIkT6iR9aSA_22, "(", 1);
STRING_LITERAL(TM__ro83HSRkGiU2zIkT6iR9aSA_23, ", ", 2);
STRING_LITERAL(TM__ro83HSRkGiU2zIkT6iR9aSA_24, ")", 1);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__ro83HSRkGiU2zIkT6iR9aSA_25 = {((NimStringDesc*) &TM__ro83HSRkGiU2zIkT6iR9aSA_5),
((NI) 650),
((NI) 23)}
;
extern NIM_CONST tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw unknownLineInfo__lineinfos_284;
extern TNimType NTItnodeseq__IeU9azYSNIK3V9b36Ir6NZcw_;
static NIM_CONST tySet_tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg TM__ro83HSRkGiU2zIkT6iR9aSA_26 = {
0x00, 0x20, 0x00, 0x00, 0x00, 0x00, 0x00, 0x10,
0x00}
;
STRING_LITERAL(TM__ro83HSRkGiU2zIkT6iR9aSA_27, "ReplaceTypeVarsN: when condition not a bool", 43);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__ro83HSRkGiU2zIkT6iR9aSA_28 = {((NimStringDesc*) &TM__ro83HSRkGiU2zIkT6iR9aSA_5),
((NI) 179),
((NI) 23)}
;
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__ro83HSRkGiU2zIkT6iR9aSA_29 = {((NimStringDesc*) &TM__ro83HSRkGiU2zIkT6iR9aSA_5),
((NI) 238),
((NI) 25)}
;
static NIM_CONST tySet_tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg TM__ro83HSRkGiU2zIkT6iR9aSA_30 = {
0x10, 0xa9, 0x00, 0x00, 0x00, 0x60, 0x80, 0x00,
0x00}
;
static NIM_CONST tySet_tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg TM__ro83HSRkGiU2zIkT6iR9aSA_31 = {
0x10, 0x09, 0xe0, 0x00, 0x00, 0xe0, 0x80, 0x00,
0x00}
;
static NIM_CONST tySet_tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg TM__ro83HSRkGiU2zIkT6iR9aSA_32 = {
0x00, 0x20, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
0x00}
;
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__ro83HSRkGiU2zIkT6iR9aSA_33 = {((NimStringDesc*) &TM__ro83HSRkGiU2zIkT6iR9aSA_5),
((NI) 27),
((NI) 14)}
;
STRING_LITERAL(TM__ro83HSRkGiU2zIkT6iR9aSA_34, "illegal recursion in type \'", 27);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__ro83HSRkGiU2zIkT6iR9aSA_35 = {((NimStringDesc*) &TM__ro83HSRkGiU2zIkT6iR9aSA_5),
((NI) 29),
((NI) 14)}
;
extern tySet_tyEnum_TTypeFlag__Vrztsndr9a9bj8bQ3cn49bwWw eqTypeFlags__ast_481;
extern tyObject_GcHeap__ZRn9bWCksoiGwT2drZZzyWQ gch__system_5220;
static N_NIMCALL(void, Marker_tyRef__bE7TGBjv9bCsVJO148OW9cHA)(void* p, NI op) {
	tyObject_LayeredIdTablecolonObjectType___9aSR8D74Pb4ozXN6gEJ9a1Pw* a;
	a = (tyObject_LayeredIdTablecolonObjectType___9aSR8D74Pb4ozXN6gEJ9a1Pw*)p;
	nimGCvisit((void*)(*a).topLayer.data, op);
	nimGCvisit((void*)(*a).nextLayer, op);
}
N_LIB_PRIVATE N_NIMCALL(tyObject_LayeredIdTablecolonObjectType___9aSR8D74Pb4ozXN6gEJ9a1Pw*, initLayeredTypeMap__semtypinst_134)(tyObject_TIdTable__Cs7vbulfMjKciTA2Uv9b6vQ pt) {
	tyObject_LayeredIdTablecolonObjectType___9aSR8D74Pb4ozXN6gEJ9a1Pw* result;
	tyObject_LayeredIdTablecolonObjectType___9aSR8D74Pb4ozXN6gEJ9a1Pw* T1_;
	result = NIM_NIL;
	T1_ = NIM_NIL;
	T1_ = (tyObject_LayeredIdTablecolonObjectType___9aSR8D74Pb4ozXN6gEJ9a1Pw*) newObj((&NTIlayeredidtable__bE7TGBjv9bCsVJO148OW9cHA_), sizeof(tyObject_LayeredIdTablecolonObjectType___9aSR8D74Pb4ozXN6gEJ9a1Pw));
	result = T1_;
	copyIdTable__ast_3589((&(*result).topLayer), pt);
	return result;
}
static N_INLINE(void, nimSetMem__systemZmemory_7)(void* a, int v, NI size) {
	void* T1_;
	T1_ = (void*)0;
	T1_ = memset(a, v, ((size_t) (size)));
}
static N_INLINE(void, nimZeroMem)(void* p, NI size) {
	nimSetMem__systemZmemory_7(p, ((int) 0), size);
}
N_LIB_PRIVATE N_NIMCALL(void, initTypeVars__semtypinst_1018)(tyObject_TContext__TE0bwjD2I16QW6s9c4AgPvw* p, tyObject_LayeredIdTablecolonObjectType___9aSR8D74Pb4ozXN6gEJ9a1Pw* typeMap, tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw info, tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* owner, tyObject_TReplTypeVars__itU2h89a2PcJoJ5bHADfePw* Result) {
	unsureAsgnRef((void**)&(*Result).c, NIM_NIL);
	unsureAsgnRef((void**)&(*Result).typeMap, NIM_NIL);
	(*Result).symMap.counter = 0;
	unsureAsgnRef((void**)&(*Result).symMap.data, NIM_NIL);
	(*Result).localCache.counter = 0;
	unsureAsgnRef((void**)&(*Result).localCache.data, NIM_NIL);
	(*Result).info.line = 0;
	(*Result).info.col = 0;
	(*Result).info.fileIndex = 0;
	(*Result).allowMetaTypes = 0;
	(*Result).skipTypedesc = 0;
	(*Result).isReturnType = 0;
	unsureAsgnRef((void**)&(*Result).owner, NIM_NIL);
	(*Result).recursionLimit = 0;
	initIdTable__ast_4084((&(*Result).symMap));
	initIdTable__ast_4084((&(*Result).localCache));
	unsureAsgnRef((void**) (&(*Result).typeMap), typeMap);
	(*Result).info = info;
	unsureAsgnRef((void**) (&(*Result).c), p);
	unsureAsgnRef((void**) (&(*Result).owner), owner);
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA*, lookup__semtypinst_158)(tyObject_LayeredIdTablecolonObjectType___9aSR8D74Pb4ozXN6gEJ9a1Pw* typeMap, tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* key) {
	tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* result;
	tyObject_LayeredIdTablecolonObjectType___9aSR8D74Pb4ozXN6gEJ9a1Pw* tm;
{	result = NIM_NIL;
	tm = typeMap;
	{
		while (1) {
			RootObj* T3_;
			if (!!((tm == ((tyObject_LayeredIdTablecolonObjectType___9aSR8D74Pb4ozXN6gEJ9a1Pw*) NIM_NIL)))) goto LA2;
			T3_ = NIM_NIL;
			T3_ = idTableGet__astalgo_64((*tm).topLayer, &key->Sup);
			result = ((tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA*) (T3_));
			{
				if (!!((result == ((tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA*) NIM_NIL)))) goto LA6_;
				goto BeforeRet_;
			}
			LA6_: ;
			tm = (*tm).nextLayer;
		} LA2: ;
	}
	}BeforeRet_: ;
	return result;
}
static N_INLINE(NI, len__ast_3990)(tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* n) {
	NI result;
	NI T1_;
	result = (NI)0;
	T1_ = ((*n).sons ? (*n).sons->Sup.len : 0);
	result = T1_;
	return result;
}
static N_INLINE(NIM_BOOL, sameFlags__types_2287)(tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* a, tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* b) {
	NIM_BOOL result;
	result = (NIM_BOOL)0;
	result = ((eqTypeFlags__ast_481 & (*a).flags) == (eqTypeFlags__ast_481 & (*b).flags));
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA*, searchInstTypes__semtypinst_44)(tyObject_ModuleGraphcolonObjectType___nOSrcYqJTxXt2ptNc0gnWg* g, tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* key) {
	tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* result;
	tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* genericTyp;
{	result = NIM_NIL;
	genericTyp = (*key).sons->data[((NI) 0)];
	{
		NIM_BOOL T3_;
		T3_ = (NIM_BOOL)0;
		T3_ = ((*genericTyp).kind == ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 10));
		if (!(T3_)) goto LA4_;
		T3_ = !(((*genericTyp).sym == ((tyObject_TSym__3r34mwqcVmg5JFNmiaVncw*) NIM_NIL)));
		LA4_: ;
		if (!!(T3_)) goto LA5_;
		goto BeforeRet_;
	}
	LA5_: ;
	{
		tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* inst;
		inst = NIM_NIL;
		{
			NIM_BOOL T10_;
			tySequence__dlD6tEGzYLLpKVq3XwuFlA** x;
			T10_ = (NIM_BOOL)0;
			T10_ = contains__modulegraphs_3033((*g).typeInstCache, (*(*genericTyp).sym).Sup.itemId);
			if (!T10_) goto LA11_;
			x = X5BX5D___modulegraphs_3349((&(*g).typeInstCache), (*(*genericTyp).sym).Sup.itemId);
			{
				tyObject_LazyType__wgv9a1JCOBXm9azerxcvz5gQ* t;
				NI i;
				NI L;
				NI T14_;
				t = (tyObject_LazyType__wgv9a1JCOBXm9azerxcvz5gQ*)0;
				i = ((NI) 0);
				T14_ = ((*x) ? (*x)->Sup.len : 0);
				L = T14_;
				{
					while (1) {
						if (!(i < L)) goto LA16;
						t = (&(*x)->data[i]);
						inst = resolveType__modulegraphs_2889(g, t);
						{
							{
								tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* xX60gensym15_;
								tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* xX60gensym16_;
								xX60gensym15_ = inst;
								xX60gensym16_ = key;
								if (!((NI)((NI)((NU64)(((NI) ((*xX60gensym15_).Sup.itemId.module))) << (NU64)(((NI) 24))) + ((NI) ((*xX60gensym15_).Sup.itemId.item))) == (NI)((NI)((NU64)(((NI) ((*xX60gensym16_).Sup.itemId.module))) << (NU64)(((NI) 24))) + ((NI) ((*xX60gensym16_).Sup.itemId.item))))) goto LA20_;
								result = inst;
								goto BeforeRet_;
							}
							LA20_: ;
							{
								NI T24_;
								NI T25_;
								T24_ = (NI)0;
								T24_ = len__ast_3990(inst);
								T25_ = (NI)0;
								T25_ = len__ast_3990(key);
								if (!(T24_ < T25_)) goto LA26_;
								goto BeforeRet_;
							}
							LA26_: ;
							{
								NIM_BOOL T30_;
								T30_ = (NIM_BOOL)0;
								T30_ = sameFlags__types_2287(inst, key);
								if (!!(T30_)) goto LA31_;
								goto LA17;
							}
							LA31_: ;
							{
								{
									NI j;
									NI colontmp_;
									NI T35_;
									NI res;
									j = (NI)0;
									colontmp_ = (NI)0;
									T35_ = (((*key).sons ? (*key).sons->Sup.len : 0)-1);
									colontmp_ = T35_;
									res = ((NI) 1);
									{
										while (1) {
											if (!(res <= colontmp_)) goto LA37;
											j = res;
											{
												NIM_BOOL T40_;
												T40_ = (NIM_BOOL)0;
												T40_ = compareTypes__types_2720((*inst).sons->data[j], (*key).sons->data[j], ((tyEnum_TDistinctCompare__UuPcvyG2RecjPyQDW4WlFw) 0), 136);
												if (!!(T40_)) goto LA41_;
												goto LA33;
											}
											LA41_: ;
											res += ((NI) 1);
										} LA37: ;
									}
								}
								result = inst;
								goto BeforeRet_;
							} LA33: ;
						} LA17: ;
						i += ((NI) 1);
					} LA16: ;
				}
			}
		}
		LA11_: ;
	}
	}BeforeRet_: ;
	return result;
}
static N_INLINE(void, nimCopyMem)(void* dest, void* source, NI size) {
	void* T1_;
	T1_ = (void*)0;
	T1_ = memcpy(dest, source, ((size_t) (size)));
}
static N_INLINE(void, copyMem__system_1733)(void* dest, void* source, NI size) {
	nimCopyMem(dest, source, size);
}
static N_INLINE(void, appendString)(NimStringDesc* dest, NimStringDesc* src) {
	{
		if (!!((src == ((NimStringDesc*) NIM_NIL)))) goto LA3_;
		copyMem__system_1733(((void*) ((&(*dest).data[(*dest).Sup.len]))), ((void*) ((*src).data)), ((NI) ((NI)((*src).Sup.len + ((NI) 1)))));
		(*dest).Sup.len += (*src).Sup.len;
	}
	LA3_: ;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA*, lookupTypeVar__semtypinst_476)(tyObject_TReplTypeVars__itU2h89a2PcJoJ5bHADfePw* cl, tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* t) {
	tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* result;
{	result = NIM_NIL;
	result = lookup__semtypinst_158((*cl).typeMap, t);
	{
		NimStringDesc* T11_;
		NimStringDesc* T12_;
		if (!(result == ((tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA*) NIM_NIL))) goto LA3_;
		{
			NIM_BOOL T7_;
			T7_ = (NIM_BOOL)0;
			T7_ = (*cl).allowMetaTypes;
			if (T7_) goto LA8_;
			T7_ = (((*t).flags &((NU64)1<<((NU)(((tyEnum_TTypeFlag__Vrztsndr9a9bj8bQ3cn49bwWw) 11))&63U)))!=0);
			LA8_: ;
			if (!T7_) goto LA9_;
			goto BeforeRet_;
		}
		LA9_: ;
		T11_ = NIM_NIL;
		T12_ = NIM_NIL;
		T12_ = typeToString__types_50(t, ((tyEnum_TPreferedDesc__lx9aDnWjKktcSUo0yfjOvMg) 0));
		T11_ = rawNewString((T12_ ? T12_->Sup.len : 0) + 22);
appendString(T11_, ((NimStringDesc*) &TM__ro83HSRkGiU2zIkT6iR9aSA_6));
appendString(T11_, T12_);
appendString(T11_, ((NimStringDesc*) &TM__ro83HSRkGiU2zIkT6iR9aSA_7));
		liMessage__msgs_1128((*(*(*cl).c).graph).config, (*(*t).sym).info, ((tyEnum_TMsgKind__J0cVyqzpFKvufCivtQUgHQ) 15), T11_, ((tyEnum_TErrorHandling__sOC1wCv9bUYRquMih1VRi3w) 0), TM__ro83HSRkGiU2zIkT6iR9aSA_8, NIM_FALSE);
		result = errorType__semdata_1032((*cl).c);
		idTablePut__astalgo_70((&(*(*cl).typeMap).topLayer), &t->Sup, (*((RootObj**) (&(result)))));
	}
	goto LA1_;
	LA3_: ;
	{
		NIM_BOOL T14_;
		T14_ = (NIM_BOOL)0;
		T14_ = ((*result).kind == ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 12));
		if (!(T14_)) goto LA15_;
		T14_ = !((*cl).allowMetaTypes);
		LA15_: ;
		if (!T14_) goto LA16_;
		internalErrorImpl__msgs_1441((*(*(*cl).c).graph).config, (*cl).info, ((NimStringDesc*) &TM__ro83HSRkGiU2zIkT6iR9aSA_9), TM__ro83HSRkGiU2zIkT6iR9aSA_10);
	}
	goto LA1_;
	LA16_: ;
	LA1_: ;
	}BeforeRet_: ;
	return result;
}
static N_INLINE(tyObject_ItemId__wg9aowaxscbUe2F0nV9btZLg, nextTypeId__ast_3122)(tyObject_IdGeneratorcolonObjectType___WVCsDyf9bR1PcjDFjcjm9bRg* x) {
	tyObject_ItemId__wg9aowaxscbUe2F0nV9btZLg result;
	nimZeroMem((void*)(&result), sizeof(tyObject_ItemId__wg9aowaxscbUe2F0nV9btZLg));
	(*x).typeId_0 += ((NI) 1);
	nimZeroMem((void*)(&result), sizeof(tyObject_ItemId__wg9aowaxscbUe2F0nV9btZLg));
	result.module = (*x).module;
	result.item = (*x).typeId_0;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA*, instCopyType__semtypinst_492)(tyObject_TReplTypeVars__itU2h89a2PcJoJ5bHADfePw* cl, tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* t) {
	tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* result;
{	result = NIM_NIL;
	{
		if (!(*cl).allowMetaTypes) goto LA3_;
		result = exactReplica__ast_4039(t);
	}
	goto LA1_;
	LA3_: ;
	{
		tyObject_ItemId__wg9aowaxscbUe2F0nV9btZLg T6_;
		T6_ = nextTypeId__ast_3122((*(*cl).c).Sup.idgen);
		result = copyType__ast_4034(t, T6_, (*t).owner);
		copyTypeProps__modulegraphs_8910((*(*cl).c).graph, ((NI) ((*(*(*cl).c).Sup.idgen).module)), result, t);
	}
	LA1_: ;
	{
		if (!(*cl).allowMetaTypes) goto LA9_;
		goto BeforeRet_;
	}
	LA9_: ;
	(*result).flags |= ((NU64)1)<<((((tyEnum_TTypeFlag__Vrztsndr9a9bj8bQ3cn49bwWw) 8)) & 63);
	{
		NIM_BOOL T13_;
		NIM_BOOL T15_;
		T13_ = (NIM_BOOL)0;
		T13_ = ((*t).kind == ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 6) || (*t).kind == ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 8) || (*t).kind == ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 12) || (*t).kind >= ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 51) && (*t).kind <= ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 54) || (*t).kind >= ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 56) && (*t).kind <= ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 59));
		if (T13_) goto LA14_;
		T15_ = (NIM_BOOL)0;
		T15_ = ((*t).kind == ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 60));
		if (!(T15_)) goto LA16_;
		T15_ = ((*t).n == ((tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw*) NIM_NIL));
		LA16_: ;
		T13_ = T15_;
		LA14_: ;
		if (!!(T13_)) goto LA17_;
		(*result).flags = ((*result).flags & ~ 2097664);
	}
	goto LA11_;
	LA17_: ;
	{
		(*result).flags &= ~(((NU64)1) << ((((tyEnum_TTypeFlag__Vrztsndr9a9bj8bQ3cn49bwWw) 31)) & 63));
	}
	LA11_: ;
	}BeforeRet_: ;
	return result;
}
static N_INLINE(NI, pluspercent___system_696)(NI x, NI y) {
	NI result;
	result = (NI)0;
	result = ((NI) ((NU)((NU64)(((NU) (x))) + (NU64)(((NU) (y))))));
	return result;
}
static N_INLINE(void, incRef__system_5311)(tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g* c) {
	(*c).refcount = pluspercent___system_696((*c).refcount, ((NI) 8));
}
static N_INLINE(NI, minuspercent___system_716)(NI x, NI y) {
	NI result;
	result = (NI)0;
	result = ((NI) ((NU)((NU64)(((NU) (x))) - (NU64)(((NU) (y))))));
	return result;
}
static N_INLINE(tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g*, usrToCell__system_5273)(void* usr) {
	tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g* result;
	NI T1_;
	result = (tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g*)0;
	T1_ = (NI)0;
	T1_ = minuspercent___system_716(((NI) (ptrdiff_t) (usr)), ((NI) 16));
	result = ((tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g*) (T1_));
	return result;
}
static N_INLINE(NIM_BOOL, ltpercent___system_1005)(NI x, NI y) {
	NIM_BOOL result;
	result = (NIM_BOOL)0;
	result = ((NU64)(((NU) (x))) < (NU64)(((NU) (y))));
	return result;
}
static N_INLINE(void, rtlAddZCT__system_5316)(tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g* c) {
	addZCT__system_5267((&gch__system_5220.zct), c);
}
static N_INLINE(void, decRef__system_5318)(tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g* c) {
	(*c).refcount = minuspercent___system_716((*c).refcount, ((NI) 8));
	{
		NIM_BOOL T3_;
		T3_ = (NIM_BOOL)0;
		T3_ = ltpercent___system_1005((*c).refcount, ((NI) 8));
		if (!T3_) goto LA4_;
		rtlAddZCT__system_5316(c);
	}
	LA4_: ;
}
static N_INLINE(void, asgnRef)(void** dest, void* src) {
	{
		tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g* T5_;
		if (!!((src == NIM_NIL))) goto LA3_;
		T5_ = (tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g*)0;
		T5_ = usrToCell__system_5273(src);
		incRef__system_5311(T5_);
	}
	LA3_: ;
	{
		tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g* T10_;
		if (!!(((*dest) == NIM_NIL))) goto LA8_;
		T10_ = (tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g*)0;
		T10_ = usrToCell__system_5273((*dest));
		decRef__system_5318(T10_);
	}
	LA8_: ;
	(*dest) = src;
}
N_LIB_PRIVATE N_NIMCALL(void, cacheTypeInst__semtypinst_88)(tyObject_TContext__TE0bwjD2I16QW6s9c4AgPvw* c, tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* inst) {
	tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* gt;
	tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* t;
{	gt = (*inst).sons->data[((NI) 0)];
	{
		if (!((*gt).kind == ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 10))) goto LA3_;
		t = lastSon__ast_3731(gt);
	}
	goto LA1_;
	LA3_: ;
	{
		t = gt;
	}
	LA1_: ;
	{
		if (!((*t).kind == ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 12) || (*t).kind >= ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 50) && (*t).kind <= ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 54) || (*t).kind >= ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 56) && (*t).kind <= ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 60))) goto LA8_;
		goto BeforeRet_;
	}
	LA8_: ;
	addToGenericCache__semdata_2424(c, (*gt).sym, inst);
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_LayeredIdTablecolonObjectType___9aSR8D74Pb4ozXN6gEJ9a1Pw*, newTypeMapLayer__semtypinst_155)(tyObject_TReplTypeVars__itU2h89a2PcJoJ5bHADfePw* cl) {
	tyObject_LayeredIdTablecolonObjectType___9aSR8D74Pb4ozXN6gEJ9a1Pw* result;
	tyObject_LayeredIdTablecolonObjectType___9aSR8D74Pb4ozXN6gEJ9a1Pw* T1_;
	result = NIM_NIL;
	T1_ = NIM_NIL;
	T1_ = (tyObject_LayeredIdTablecolonObjectType___9aSR8D74Pb4ozXN6gEJ9a1Pw*) newObj((&NTIlayeredidtable__bE7TGBjv9bCsVJO148OW9cHA_), sizeof(tyObject_LayeredIdTablecolonObjectType___9aSR8D74Pb4ozXN6gEJ9a1Pw));
	result = T1_;
	asgnRef((void**) (&(*result).nextLayer), (*cl).typeMap);
	initIdTable__ast_4084((&(*result).topLayer));
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, checkPartialConstructedType__semtypinst_13)(tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ* conf, tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw info, tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* t) {
	{
		NIM_BOOL T3_;
		T3_ = (NIM_BOOL)0;
		T3_ = ((*t).kind == ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 23) || (*t).kind == ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 47));
		if (!(T3_)) goto LA4_;
		T3_ = ((*(*t).sons->data[((NI) 0)]).kind == ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 23) || (*(*t).sons->data[((NI) 0)]).kind == ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 47));
		LA4_: ;
		if (!T3_) goto LA5_;
		liMessage__msgs_1128(conf, info, ((tyEnum_TMsgKind__J0cVyqzpFKvufCivtQUgHQ) 15), ((NimStringDesc*) &TM__ro83HSRkGiU2zIkT6iR9aSA_11), ((tyEnum_TErrorHandling__sOC1wCv9bUYRquMih1VRi3w) 0), TM__ro83HSRkGiU2zIkT6iR9aSA_12, NIM_FALSE);
	}
	LA5_: ;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA*, handleGenericInvocation__semtypinst_521)(tyObject_TReplTypeVars__itU2h89a2PcJoJ5bHADfePw* cl, tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* t) {
	tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* result;
	tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* body;
	tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* header;
	tyObject_ItemId__wg9aowaxscbUe2F0nV9btZLg T44_;
	tySequence__vKogasEnJSPhbQmA8r4Y9aA* T45_;
	NIM_BOOL oldSkipTypedesc;
	tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* bbody;
	tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* newbody;
{	result = NIM_NIL;
	body = (*t).sons->data[((NI) 0)];
	{
		if (!!(((*body).kind == ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 10)))) goto LA3_;
		internalErrorImpl__msgs_1441((*(*(*cl).c).graph).config, (*cl).info, ((NimStringDesc*) &TM__ro83HSRkGiU2zIkT6iR9aSA_3), TM__ro83HSRkGiU2zIkT6iR9aSA_4);
	}
	LA3_: ;
	header = t;
	{
		RootObj* T9_;
		if (!(*cl).allowMetaTypes) goto LA7_;
		T9_ = NIM_NIL;
		T9_ = idTableGet__astalgo_64((*cl).localCache, &t->Sup);
		result = ((tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA*) (T9_));
	}
	goto LA5_;
	LA7_: ;
	{
		result = searchInstTypes__semtypinst_44((*(*cl).c).graph, t);
	}
	LA5_: ;
	{
		NIM_BOOL T13_;
		T13_ = (NIM_BOOL)0;
		T13_ = !((result == ((tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA*) NIM_NIL)));
		if (!(T13_)) goto LA14_;
		T13_ = sameFlags__types_2287(result, t);
		LA14_: ;
		if (!T13_) goto LA15_;
		goto BeforeRet_;
	}
	LA15_: ;
	{
		NI i;
		NI colontmp_;
		NI i_2;
		i = (NI)0;
		colontmp_ = (NI)0;
		colontmp_ = len__ast_3990(t);
		i_2 = ((NI) 1);
		{
			while (1) {
				tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* x;
				if (!(i_2 < colontmp_)) goto LA19;
				i = i_2;
				x = (*t).sons->data[i];
				{
					if (!((*x).kind == ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 12))) goto LA22_;
					x = lookupTypeVar__semtypinst_476(cl, x);
					{
						if (!!((x == ((tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA*) NIM_NIL)))) goto LA26_;
						{
							if (!(header == t)) goto LA30_;
							header = instCopyType__semtypinst_492(cl, t);
						}
						LA30_: ;
						asgnRef((void**) (&(*header).sons->data[i]), x);
						propagateToOwner__ast_4207(header, x, NIM_TRUE);
					}
					LA26_: ;
				}
				goto LA20_;
				LA22_: ;
				{
					propagateToOwner__ast_4207(header, x, NIM_TRUE);
				}
				LA20_: ;
				i_2 += ((NI) 1);
			} LA19: ;
		}
	}
	{
		if (!!((header == t))) goto LA35_;
		result = searchInstTypes__semtypinst_44((*(*cl).c).graph, header);
		{
			NIM_BOOL T39_;
			T39_ = (NIM_BOOL)0;
			T39_ = !((result == ((tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA*) NIM_NIL)));
			if (!(T39_)) goto LA40_;
			T39_ = sameFlags__types_2287(result, t);
			LA40_: ;
			if (!T39_) goto LA41_;
			goto BeforeRet_;
		}
		LA41_: ;
	}
	goto LA33_;
	LA35_: ;
	{
		header = instCopyType__semtypinst_492(cl, t);
	}
	LA33_: ;
	T44_ = nextTypeId__ast_3122((*(*cl).c).Sup.idgen);
	result = newType__ast_3884(((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 11), T44_, (*(*t).sons->data[((NI) 0)]).owner);
	(*result).flags = (*header).flags;
	T45_ = NIM_NIL;
	T45_ = (tySequence__vKogasEnJSPhbQmA8r4Y9aA*) newSeq((&NTIttypeseq__vKogasEnJSPhbQmA8r4Y9aA_), 1);
	asgnRef((void**) (&T45_->data[0]), (*header).sons->data[((NI) 0)]);
	asgnRef((void**) (&(*result).sons), T45_);
	{
		if (!!((*cl).allowMetaTypes)) goto LA48_;
		cacheTypeInst__semtypinst_88((*cl).c, result);
	}
	goto LA46_;
	LA48_: ;
	{
		idTablePut__astalgo_70((&(*cl).localCache), &t->Sup, (*((RootObj**) (&(result)))));
	}
	LA46_: ;
	oldSkipTypedesc = (*cl).skipTypedesc;
	(*cl).skipTypedesc = NIM_TRUE;
	unsureAsgnRef((void**) (&(*cl).typeMap), newTypeMapLayer__semtypinst_155(cl));
	{
		NI i_3;
		NI colontmp__2;
		NI i_4;
		i_3 = (NI)0;
		colontmp__2 = (NI)0;
		colontmp__2 = len__ast_3990(t);
		i_4 = ((NI) 1);
		{
			while (1) {
				tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* x_2;
				tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* T54_;
				if (!(i_4 < colontmp__2)) goto LA53;
				i_3 = i_4;
				T54_ = NIM_NIL;
				{
					if (!((*(*header).sons->data[i_3]).kind == ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 11))) goto LA57_;
					T54_ = (*t).sons->data[i_3];
				}
				goto LA55_;
				LA57_: ;
				{
					T54_ = (*header).sons->data[i_3];
				}
				LA55_: ;
				x_2 = replaceTypeVarsT__semtypinst_178(cl, T54_);
				asgnRef((void**) (&(*header).sons->data[i_3]), x_2);
				propagateToOwner__ast_4207(header, x_2, NIM_TRUE);
				idTablePut__astalgo_70((&(*(*cl).typeMap).topLayer), (*((tyObject_TIdObj__1qw9bcK4rZXhGbJEJhkKQFA**) (&((*body).sons->data[(NI)(i_3 - ((NI) 1))])))), (*((RootObj**) (&(x_2)))));
				i_4 += ((NI) 1);
			} LA53: ;
		}
	}
	{
		NI i_5;
		NI colontmp__3;
		NI i_6;
		i_5 = (NI)0;
		colontmp__3 = (NI)0;
		colontmp__3 = len__ast_3990(t);
		i_6 = ((NI) 1);
		{
			while (1) {
				if (!(i_6 < colontmp__3)) goto LA62;
				i_5 = i_6;
				rawAddSon__ast_4276(result, (*header).sons->data[i_5], NIM_FALSE);
				i_6 += ((NI) 1);
			} LA62: ;
		}
	}
	{
		if (!((*body).kind == ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 50))) goto LA65_;
		goto BeforeRet_;
	}
	LA65_: ;
	bbody = lastSon__ast_3731(body);
	newbody = replaceTypeVarsT__semtypinst_178(cl, bbody);
	(*cl).skipTypedesc = oldSkipTypedesc;
	(*newbody).flags = ((*newbody).flags | (((*t).flags | (*body).flags) & ~ 2097664));
	(*result).flags = (((*result).flags | (*newbody).flags) & ~ 2097664);
	unsureAsgnRef((void**) (&(*cl).typeMap), (*(*cl).typeMap).nextLayer);
	{
		NIM_BOOL T69_;
		T69_ = (NIM_BOOL)0;
		T69_ = isGenericAlias__types_2267(newbody);
		if (!T69_) goto LA70_;
		newbody = skipGenericAlias__types_2281(newbody);
	}
	LA70_: ;
	rawAddSon__ast_4276(result, newbody, NIM_TRUE);
	checkPartialConstructedType__semtypinst_13((*(*(*cl).c).graph).config, (*cl).info, newbody);
	{
		tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* dc;
		tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* mm;
		if (!!((*cl).allowMetaTypes)) goto LA74_;
		dc = getAttachedOp__modulegraphs_4049((*(*cl).c).graph, newbody, ((tyEnum_TTypeAttachedOp__0IDqFfYT9a3F5i6tmCmdORQ) 4));
		{
			NIM_BOOL T78_;
			tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* T82_;
			T78_ = (NIM_BOOL)0;
			T78_ = !((dc == ((tyObject_TSym__3r34mwqcVmg5JFNmiaVncw*) NIM_NIL)));
			if (!(T78_)) goto LA79_;
			T78_ = !((((*dc).flags &((NU64)1<<((NU)(((tyEnum_TSymFlag__9be9c6fEXk5NwyPvxxb6toPA) 2))&63U)))!=0));
			LA79_: ;
			if (!T78_) goto LA80_;
			T82_ = NIM_NIL;
			T82_ = (*(*cl).c).instTypeBoundOp((*cl).c, dc, result, (*cl).info, ((tyEnum_TTypeAttachedOp__0IDqFfYT9a3F5i6tmCmdORQ) 4), ((NI) 1));
			setAttachedOp__modulegraphs_4445((*(*cl).c).graph, (*(*(*cl).c).module).position, newbody, ((tyEnum_TTypeAttachedOp__0IDqFfYT9a3F5i6tmCmdORQ) 4), T82_);
		}
		LA80_: ;
		{
			if (!((*newbody).typeInst == ((tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA*) NIM_NIL))) goto LA85_;
			asgnRef((void**) (&(*newbody).typeInst), result);
			{
				NIM_BOOL T89_;
				T89_ = (NIM_BOOL)0;
				T89_ = (((*newbody).flags &((NU64)1<<((NU)(((tyEnum_TTypeFlag__Vrztsndr9a9bj8bQ3cn49bwWw) 34))&63U)))!=0);
				if (!(T89_)) goto LA90_;
				T89_ = !(((*newbody).kind == ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 11)));
				LA90_: ;
				if (!T89_) goto LA91_;
				{
					tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* T95_;
					T95_ = NIM_NIL;
					T95_ = lastSon__ast_3731(newbody);
					if (!!(((*T95_).typeInst == ((tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA*) NIM_NIL)))) goto LA96_;
				}
				goto LA93_;
				LA96_: ;
				{
					tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* T99_;
					T99_ = NIM_NIL;
					T99_ = lastSon__ast_3731(newbody);
					asgnRef((void**) (&(*T99_).typeInst), result);
				}
				LA93_: ;
			}
			LA91_: ;
		}
		LA85_: ;
		mm = skipTypes__ast_3723(bbody, TM__ro83HSRkGiU2zIkT6iR9aSA_13);
		{
			if (!!((((*mm).flags &((NU64)1<<((NU)(((tyEnum_TTypeFlag__Vrztsndr9a9bj8bQ3cn49bwWw) 8))&63U)))!=0))) goto LA102_;
			(*mm).flags |= ((NU64)1)<<((((tyEnum_TTypeFlag__Vrztsndr9a9bj8bQ3cn49bwWw) 8)) & 63);
			{
				NI col;
				tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* meth;
				col = (NI)0;
				meth = NIM_NIL;
				{
					NIM_BOOL T107_;
					T107_ = (NIM_BOOL)0;
					T107_ = contains__modulegraphs_7294((*(*(*cl).c).graph).methodsPerType, (*mm).Sup.itemId);
					if (!T107_) goto LA108_;
					{
						tyTuple__RWXAsQlFoGYyEQZp1G65sg* it;
						NI i_7;
						NI L;
						tySequence__m4PVWjcAAjfxlwJxLkKn8A** T111_;
						NI T112_;
						it = (tyTuple__RWXAsQlFoGYyEQZp1G65sg*)0;
						i_7 = ((NI) 0);
						T111_ = (tySequence__m4PVWjcAAjfxlwJxLkKn8A**)0;
						T111_ = X5BX5D___modulegraphs_7610((&(*(*(*cl).c).graph).methodsPerType), (*mm).Sup.itemId);
						T112_ = ((*T111_) ? (*T111_)->Sup.len : 0);
						L = T112_;
						{
							while (1) {
								tySequence__m4PVWjcAAjfxlwJxLkKn8A** T115_;
								tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* T116_;
								if (!(i_7 < L)) goto LA114;
								T115_ = (tySequence__m4PVWjcAAjfxlwJxLkKn8A**)0;
								T115_ = X5BX5D___modulegraphs_7610((&(*(*(*cl).c).graph).methodsPerType), (*mm).Sup.itemId);
								it = (&(*T115_)->data[i_7]);
								col = (*it).Field0;
								meth = resolveSym__modulegraphs_2904((*(*cl).c).graph, (&(*it).Field1));
								T116_ = NIM_NIL;
								T116_ = (*(*cl).c).instTypeBoundOp((*cl).c, meth, result, (*cl).info, ((tyEnum_TTypeAttachedOp__0IDqFfYT9a3F5i6tmCmdORQ) 1), col);
								(void)(T116_);
								i_7 += ((NI) 1);
							} LA114: ;
						}
					}
				}
				LA108_: ;
			}
			(*mm).flags &= ~(((NU64)1) << ((((tyEnum_TTypeFlag__Vrztsndr9a9bj8bQ3cn49bwWw) 8)) & 63));
		}
		LA102_: ;
	}
	LA74_: ;
	}BeforeRet_: ;
	return result;
}
static N_INLINE(tyObject_ItemId__wg9aowaxscbUe2F0nV9btZLg, nextSymId__ast_3103)(tyObject_IdGeneratorcolonObjectType___WVCsDyf9bR1PcjDFjcjm9bRg* x) {
	tyObject_ItemId__wg9aowaxscbUe2F0nV9btZLg result;
	nimZeroMem((void*)(&result), sizeof(tyObject_ItemId__wg9aowaxscbUe2F0nV9btZLg));
	(*x).symId += ((NI) 1);
	nimZeroMem((void*)(&result), sizeof(tyObject_ItemId__wg9aowaxscbUe2F0nV9btZLg));
	result.module = (*x).module;
	result.item = (*x).symId;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TSym__3r34mwqcVmg5JFNmiaVncw*, replaceTypeVarsS__semtypinst_127)(tyObject_TReplTypeVars__itU2h89a2PcJoJ5bHADfePw* cl, tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* s) {
	tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* result;
	tyObject_ItemId__wg9aowaxscbUe2F0nV9btZLg T17_;
{	result = NIM_NIL;
	{
		if (!(s == ((tyObject_TSym__3r34mwqcVmg5JFNmiaVncw*) NIM_NIL))) goto LA3_;
		result = ((tyObject_TSym__3r34mwqcVmg5JFNmiaVncw*) NIM_NIL);
		goto BeforeRet_;
	}
	LA3_: ;
	{
		NIM_BOOL T7_;
		T7_ = (NIM_BOOL)0;
		T7_ = !(((*cl).owner == ((tyObject_TSym__3r34mwqcVmg5JFNmiaVncw*) NIM_NIL)));
		if (!(T7_)) goto LA8_;
		T7_ = !(((*s).owner == (*cl).owner));
		LA8_: ;
		if (!T7_) goto LA9_;
		result = s;
		goto BeforeRet_;
	}
	LA9_: ;
	{
		NIM_BOOL T13_;
		T13_ = (NIM_BOOL)0;
		T13_ = ((521984 &((NU32)1<<((NU)((*s).kind)&31U)))!=0);
		if (T13_) goto LA14_;
		T13_ = !(((*s).magic == ((tyEnum_TMagic__3qAy6bDUDlF8Fc2RR6pF9ag) 0)));
		LA14_: ;
		if (!T13_) goto LA15_;
		result = s;
		goto BeforeRet_;
	}
	LA15_: ;
	T17_ = nextSymId__ast_3103((*(*cl).c).Sup.idgen);
	result = copySym__ast_4042(s, T17_);
	(*result).flags |= ((NU64)1)<<((((tyEnum_TSymFlag__9be9c6fEXk5NwyPvxxb6toPA) 2)) & 63);
	asgnRef((void**) (&(*result).owner), (*s).owner);
	asgnRef((void**) (&(*result).typ), replaceTypeVarsT__semtypinst_178(cl, (*s).typ));
	{
		if (!!(((*result).kind == ((tyEnum_TSymKind__sjiB9b9aO1FRPetW6gPYZbfw) 7)))) goto LA20_;
		asgnRef((void**) (&(*result).ast), replaceTypeVarsN__semtypinst_130(cl, (*s).ast, ((NI) 0)));
	}
	LA20_: ;
	}BeforeRet_: ;
	return result;
}
static N_INLINE(NI, len__ast_3155)(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n) {
	NI result;
	NI T1_;
	result = (NI)0;
	T1_ = ((*n)._kind_6.sons ? (*n)._kind_6.sons->Sup.len : 0);
	result = T1_;
	return result;
}
static N_INLINE(NI, safeLen__ast_3148)(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n) {
	NI result;
	result = (NI)0;
	{
		if (!((*n).kind >= ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 0) && (*n).kind <= ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 23))) goto LA3_;
		result = ((NI) 0);
	}
	goto LA1_;
	LA3_: ;
	{
		result = len__ast_3155(n);
	}
	LA1_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw*, prepareNode__semtypinst_182)(tyObject_TReplTypeVars__itU2h89a2PcJoJ5bHADfePw* cl, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n) {
	tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* result;
	tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* t;
	NIM_BOOL isCall;
{	result = NIM_NIL;
	t = replaceTypeVarsT__semtypinst_178(cl, (*n).typ);
	{
		NIM_BOOL T3_;
		NIM_BOOL T4_;
		T3_ = (NIM_BOOL)0;
		T4_ = (NIM_BOOL)0;
		T4_ = !((t == ((tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA*) NIM_NIL)));
		if (!(T4_)) goto LA5_;
		T4_ = ((*t).kind == ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 60));
		LA5_: ;
		T3_ = T4_;
		if (!(T3_)) goto LA6_;
		T3_ = !(((*t).n == ((tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw*) NIM_NIL)));
		LA6_: ;
		if (!T3_) goto LA7_;
		{
			if (!(((*t).flags &((NU64)1<<((NU)(((tyEnum_TTypeFlag__Vrztsndr9a9bj8bQ3cn49bwWw) 9))&63U)))!=0)) goto LA11_;
			result = prepareNode__semtypinst_182(cl, (*t).n);
		}
		goto LA9_;
		LA11_: ;
		{
			result = (*t).n;
		}
		LA9_: ;
		goto BeforeRet_;
	}
	LA7_: ;
	result = copyNode__ast_4324(n);
	asgnRef((void**) (&(*result).typ), t);
	{
		if (!((*result).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 3))) goto LA16_;
		asgnRef((void**) (&(*result)._kind_4.sym), replaceTypeVarsS__semtypinst_127(cl, (*n)._kind_4.sym));
	}
	LA16_: ;
	isCall = ((*result).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 27) || (*result).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 29) || (*result).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 30) || (*result).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 31) || (*result).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 26) || (*result).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 28) || (*result).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 32));
	{
		NI i;
		NI colontmp_;
		NI i_2;
		i = (NI)0;
		colontmp_ = (NI)0;
		colontmp_ = safeLen__ast_3148(n);
		i_2 = ((NI) 0);
		{
			while (1) {
				if (!(i_2 < colontmp_)) goto LA20;
				i = i_2;
				{
					NIM_BOOL T23_;
					T23_ = (NIM_BOOL)0;
					T23_ = isCall;
					if (!(T23_)) goto LA24_;
					T23_ = (i == ((NI) 0));
					LA24_: ;
					if (!T23_) goto LA25_;
					add__ast_4798(result, (*n)._kind_6.sons->data[i]);
				}
				goto LA21_;
				LA25_: ;
				{
					tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* T28_;
					T28_ = NIM_NIL;
					T28_ = prepareNode__semtypinst_182(cl, (*n)._kind_6.sons->data[i]);
					add__ast_4798(result, T28_);
				}
				LA21_: ;
				i_2 += ((NI) 1);
			} LA20: ;
		}
	}
	}BeforeRet_: ;
	return result;
}
static N_INLINE(void, nimGCunrefNoCycle)(void* p) {
	tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g* T1_;
	T1_ = (tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g*)0;
	T1_ = usrToCell__system_5273(p);
	decRef__system_5318(T1_);
}
static N_INLINE(tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA*, skipIntLit__magicsys_124)(tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* t, tyObject_IdGeneratorcolonObjectType___WVCsDyf9bR1PcjDFjcjm9bRg* id) {
	tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* result;
	result = NIM_NIL;
	{
		NIM_BOOL T3_;
		tyObject_ItemId__wg9aowaxscbUe2F0nV9btZLg T7_;
		T3_ = (NIM_BOOL)0;
		T3_ = !(((*t).n == ((tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw*) NIM_NIL)));
		if (!(T3_)) goto LA4_;
		T3_ = ((*t).kind == ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 31) || (*t).kind == ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 36));
		LA4_: ;
		if (!T3_) goto LA5_;
		T7_ = nextTypeId__ast_3122(id);
		result = copyType__ast_4034(t, T7_, (*t).owner);
		asgnRef((void**) (&(*result).n), ((tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw*) NIM_NIL));
	}
	goto LA1_;
	LA5_: ;
	{
		result = t;
	}
	LA1_: ;
	return result;
}
static N_INLINE(void, addInt__stdZprivateZdigitsutils_189)(NimStringDesc** result, NI x) {
	addInt__stdZprivateZdigitsutils_167(result, ((NI64) (x)));
}
static N_INLINE(NimStringDesc*, toFileLineCol__msgs_625)(tyTuple__kN8up2W6YKc5YA9avn5mV5w info) {
	NimStringDesc* result;
	result = NIM_NIL;
	result = resizeString(result, (info.Field0 ? info.Field0->Sup.len : 0) + 0);
appendString(result, info.Field0);
	{
		if (!(((NI) 0) < info.Field1)) goto LA3_;
		result = resizeString(result, 1);
appendString(result, ((NimStringDesc*) &TM__ro83HSRkGiU2zIkT6iR9aSA_22));
		addInt__stdZprivateZdigitsutils_189((&result), info.Field1);
		{
			if (!(((NI) 0) < (NI)(info.Field2 + ((NI) 1)))) goto LA7_;
			result = resizeString(result, 2);
appendString(result, ((NimStringDesc*) &TM__ro83HSRkGiU2zIkT6iR9aSA_23));
			addInt__stdZprivateZdigitsutils_189((&result), (NI)(info.Field2 + ((NI) 1)));
		}
		LA7_: ;
		result = resizeString(result, 1);
appendString(result, ((NimStringDesc*) &TM__ro83HSRkGiU2zIkT6iR9aSA_24));
	}
	LA3_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, propagateFieldFlags__semtypinst_786)(tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* t, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n) {
{	{
		if (!(n == 0)) goto LA3_;
		goto BeforeRet_;
	}
	LA3_: ;
	switch ((*n).kind) {
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 3):
	{
		propagateToOwner__ast_4207(t, (*(*n)._kind_4.sym).typ, NIM_TRUE);
	}
	break;
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 138):
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 139):
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 85):
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 88):
	{
		{
			tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* son;
			son = NIM_NIL;
			{
				NI i;
				NI colontmp_;
				NI i_2;
				i = (NI)0;
				colontmp_ = (NI)0;
				colontmp_ = safeLen__ast_3148(n);
				i_2 = ((NI) 0);
				{
					while (1) {
						if (!(i_2 < colontmp_)) goto LA10;
						i = i_2;
						son = (*n)._kind_6.sons->data[i];
						propagateFieldFlags__semtypinst_786(t, son);
						i_2 += ((NI) 1);
					} LA10: ;
				}
			}
		}
	}
	break;
	default:
	{
	}
	break;
	}
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, eraseVoidParams__semtypinst_694)(tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* t) {
	{
		NIM_BOOL T3_;
		T3_ = (NIM_BOOL)0;
		T3_ = !(((*t).sons->data[((NI) 0)] == ((tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA*) NIM_NIL)));
		if (!(T3_)) goto LA4_;
		T3_ = ((*(*t).sons->data[((NI) 0)]).kind == ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 63));
		LA4_: ;
		if (!T3_) goto LA5_;
		asgnRef((void**) (&(*t).sons->data[((NI) 0)]), ((tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA*) NIM_NIL));
	}
	LA5_: ;
	{
		NI i;
		NI colontmp_;
		NI i_2;
		i = (NI)0;
		colontmp_ = (NI)0;
		colontmp_ = len__ast_3990(t);
		i_2 = ((NI) 1);
		{
			while (1) {
				if (!(i_2 < colontmp_)) goto LA9;
				i = i_2;
				{
					NI pos;
					if (!((*(*t).sons->data[i]).kind == ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 63))) goto LA12_;
					pos = i;
					{
						NI j;
						NI colontmp__2;
						NI colontmp__3;
						NI i_3;
						j = (NI)0;
						colontmp__2 = (NI)0;
						colontmp__3 = (NI)0;
						colontmp__2 = (NI)(i + ((NI) 1));
						colontmp__3 = len__ast_3990(t);
						i_3 = colontmp__2;
						{
							while (1) {
								if (!(i_3 < colontmp__3)) goto LA16;
								j = i_3;
								{
									if (!!(((*(*t).sons->data[j]).kind == ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 63)))) goto LA19_;
									asgnRef((void**) (&(*t).sons->data[pos]), (*t).sons->data[j]);
									asgnRef((void**) (&(*(*t).n)._kind_6.sons->data[pos]), (*(*t).n)._kind_6.sons->data[j]);
									pos += ((NI) 1);
								}
								LA19_: ;
								i_3 += ((NI) 1);
							} LA16: ;
						}
					}
					asgnRef((void**) (&(*t).sons), (tySequence__vKogasEnJSPhbQmA8r4Y9aA*) setLengthSeqV2(((*t).sons)?&((*t).sons)->Sup:NIM_NIL, (&NTIttypeseq__vKogasEnJSPhbQmA8r4Y9aA_), ((NI) (pos))));
					asgnRef((void**) (&(*(*t).n)._kind_6.sons), (tySequence__IeU9azYSNIK3V9b36Ir6NZcw*) setLengthSeqV2(((*(*t).n)._kind_6.sons)?&((*(*t).n)._kind_6.sons)->Sup:NIM_NIL, (&NTItnodeseq__IeU9azYSNIK3V9b36Ir6NZcw_), ((NI) (pos))));
					goto LA7;
				}
				LA12_: ;
				i_2 += ((NI) 1);
			} LA9: ;
		}
	} LA7: ;
}
N_LIB_PRIVATE N_NIMCALL(void, skipIntLiteralParams__semtypinst_750)(tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* t, tyObject_IdGeneratorcolonObjectType___WVCsDyf9bR1PcjDFjcjm9bRg* idgen) {
	{
		NI i;
		NI colontmp_;
		NI i_2;
		i = (NI)0;
		colontmp_ = (NI)0;
		colontmp_ = len__ast_3990(t);
		i_2 = ((NI) 0);
		{
			while (1) {
				if (!(i_2 < colontmp_)) goto LA3;
				i = i_2;
				{
					tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* p;
					tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* skipped;
					p = (*t).sons->data[i];
					{
						if (!(p == ((tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA*) NIM_NIL))) goto LA7_;
						goto LA4;
					}
					LA7_: ;
					skipped = skipIntLit__magicsys_124(p, idgen);
					{
						if (!!((skipped == p))) goto LA11_;
						asgnRef((void**) (&(*t).sons->data[i]), skipped);
						{
							if (!(((NI) 0) < i)) goto LA15_;
							asgnRef((void**) (&(*(*(*(*t).n)._kind_6.sons->data[i])._kind_4.sym).typ), skipped);
						}
						LA15_: ;
					}
					LA11_: ;
				} LA4: ;
				i_2 += ((NI) 1);
			} LA3: ;
		}
	}
	{
		NIM_BOOL T19_;
		T19_ = (NIM_BOOL)0;
		T19_ = !(((*t).sons->data[((NI) 0)] == ((tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA*) NIM_NIL)));
		if (!(T19_)) goto LA20_;
		T19_ = ((*(*t).sons->data[((NI) 0)]).kind == ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 60));
		LA20_: ;
		if (!T19_) goto LA21_;
		asgnRef((void**) (&(*t).sons->data[((NI) 0)]), base__types_63((*t).sons->data[((NI) 0)]));
	}
	LA21_: ;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw*, replaceObjBranches__semtypinst_277)(tyObject_TReplTypeVars__itU2h89a2PcJoJ5bHADfePw* cl, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n) {
	tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* result;
	result = NIM_NIL;
	result = n;
	switch ((*n).kind) {
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 0) ... ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 23):
	{
	}
	break;
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 140):
	{
		tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* branch;
		branch = ((tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw*) NIM_NIL);
		{
			NI i;
			NI colontmp_;
			NI i_2;
			i = (NI)0;
			colontmp_ = (NI)0;
			colontmp_ = len__ast_3155(n);
			i_2 = ((NI) 0);
			{
				while (1) {
					tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* it;
					if (!(i_2 < colontmp_)) goto LA5;
					i = i_2;
					it = (*n)._kind_6.sons->data[i];
					{
						if (!(it == ((tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw*) NIM_NIL))) goto LA8_;
						illFormedAst__semdata_1101(n, (*(*(*cl).c).graph).config);
					}
					LA8_: ;
					switch ((*it).kind) {
					case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 86):
					{
						tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* cond;
						tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* e;
						checkSonsLen__semdata_1107(it, ((NI) 2), (*(*(*cl).c).graph).config);
						cond = (*it)._kind_6.sons->data[((NI) 0)];
						e = (*(*cl).c).semConstExpr((*cl).c, cond, ((tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA*) NIM_NIL));
						{
							if (!!(((*e).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 6)))) goto LA13_;
							internalErrorImpl__msgs_1441((*(*(*cl).c).graph).config, (*e).info, ((NimStringDesc*) &TM__ro83HSRkGiU2zIkT6iR9aSA_27), TM__ro83HSRkGiU2zIkT6iR9aSA_28);
						}
						LA13_: ;
						{
							NIM_BOOL T17_;
							T17_ = (NIM_BOOL)0;
							T17_ = !(((*e)._kind_1.intVal == IL64(0)));
							if (!(T17_)) goto LA18_;
							T17_ = (branch == ((tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw*) NIM_NIL));
							LA18_: ;
							if (!T17_) goto LA19_;
							branch = (*it)._kind_6.sons->data[((NI) 1)];
						}
						LA19_: ;
					}
					break;
					case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 88):
					{
						checkSonsLen__semdata_1107(it, ((NI) 1), (*(*(*cl).c).graph).config);
						{
							if (!(branch == ((tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw*) NIM_NIL))) goto LA24_;
							branch = (*it)._kind_6.sons->data[((NI) 0)];
						}
						LA24_: ;
					}
					break;
					default:
					{
						illFormedAst__semdata_1101(n, (*(*(*cl).c).graph).config);
					}
					break;
					}
					i_2 += ((NI) 1);
				} LA5: ;
			}
		}
		{
			if (!!((branch == ((tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw*) NIM_NIL)))) goto LA29_;
			result = replaceObjBranches__semtypinst_277(cl, branch);
		}
		goto LA27_;
		LA29_: ;
		{
			result = newNodeI__ast_3320(((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 138), (*n).info);
		}
		LA27_: ;
	}
	break;
	default:
	{
		{
			NI i_3;
			NI colontmp__2;
			NI i_4;
			i_3 = (NI)0;
			colontmp__2 = (NI)0;
			colontmp__2 = len__ast_3155(n);
			i_4 = ((NI) 0);
			{
				while (1) {
					if (!(i_4 < colontmp__2)) goto LA35;
					i_3 = i_4;
					asgnRef((void**) (&(*n)._kind_6.sons->data[i_3]), replaceObjBranches__semtypinst_277(cl, (*n)._kind_6.sons->data[i_3]));
					i_4 += ((NI) 1);
				} LA35: ;
			}
		}
	}
	break;
	}
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA*, replaceTypeVarsTAux__semtypinst_124)(tyObject_TReplTypeVars__itU2h89a2PcJoJ5bHADfePw* cl, tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* t) {
	tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* result;
{	result = NIM_NIL;
	result = t;
	{
		if (!(t == ((tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA*) NIM_NIL))) goto LA3_;
		goto BeforeRet_;
	}
	LA3_: ;
	{
		tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* lookup;
		if (!((*t).kind == ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 12) || (*t).kind >= ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 51) && (*t).kind <= ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 54) || (*t).kind >= ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 56) && (*t).kind <= ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 60) || (*t).kind == ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 62))) goto LA7_;
		lookup = lookup__semtypinst_158((*cl).typeMap, t);
		{
			if (!!((lookup == ((tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA*) NIM_NIL)))) goto LA11_;
			result = lookup;
			goto BeforeRet_;
		}
		LA11_: ;
	}
	LA7_: ;
	switch ((*t).kind) {
	case ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 9):
	{
		result = handleGenericInvocation__semtypinst_521(cl, t);
		{
			tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* T16_;
			T16_ = NIM_NIL;
			T16_ = lastSon__ast_3731(result);
			if (!((*T16_).kind == ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 52))) goto LA17_;
			(*result).kind = ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 53);
		}
		LA17_: ;
	}
	break;
	case ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 10):
	{
		NimStringDesc* T20_;
		NimStringDesc* T21_;
		T20_ = NIM_NIL;
		T21_ = NIM_NIL;
		T21_ = typeToString__types_50(t, ((tyEnum_TPreferedDesc__lx9aDnWjKktcSUo0yfjOvMg) 1));
		T20_ = rawNewString((T21_ ? T21_->Sup.len : 0) + 60);
appendString(T20_, ((NimStringDesc*) &TM__ro83HSRkGiU2zIkT6iR9aSA_6));
appendString(T20_, T21_);
appendString(T20_, ((NimStringDesc*) &TM__ro83HSRkGiU2zIkT6iR9aSA_14));
		liMessage__msgs_1128((*(*(*cl).c).graph).config, (*cl).info, ((tyEnum_TMsgKind__J0cVyqzpFKvufCivtQUgHQ) 15), T20_, ((tyEnum_TErrorHandling__sOC1wCv9bUYRquMih1VRi3w) 0), TM__ro83HSRkGiU2zIkT6iR9aSA_15, NIM_FALSE);
		result = errorType__semdata_1032((*cl).c);
	}
	break;
	case ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 61):
	{
		tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n;
		{
			if (!(*cl).allowMetaTypes) goto LA25_;
			goto BeforeRet_;
		}
		LA25_: ;
		n = prepareNode__semtypinst_182(cl, (*t).n);
		{
			if (!!(((*n).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 1)))) goto LA29_;
			n = (*(*cl).c).semConstExpr((*cl).c, n, ((tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA*) NIM_NIL));
		}
		LA29_: ;
		{
			if (!((*(*n).typ).kind == ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 8))) goto LA33_;
			result = skipTypes__ast_3723((*n).typ, TM__ro83HSRkGiU2zIkT6iR9aSA_16);
		}
		goto LA31_;
		LA33_: ;
		{
			{
				NIM_BOOL T38_;
				T38_ = (NIM_BOOL)0;
				T38_ = !(((*(*n).typ).kind == ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 60)));
				if (!(T38_)) goto LA39_;
				T38_ = !(((*n).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 4)));
				LA39_: ;
				if (!T38_) goto LA40_;
				result = newTypeS__semdata_763(((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 60), (*cl).c);
				if ((*result).sons) { nimGCunrefNoCycle((*result).sons); (*result).sons = NIM_NIL; }
				(*result).sons = (tySequence__vKogasEnJSPhbQmA8r4Y9aA*) newSeqRC1((&NTIttypeseq__vKogasEnJSPhbQmA8r4Y9aA_), 1);
				asgnRef((void**) (&(*result).sons->data[0]), (*n).typ);
				asgnRef((void**) (&(*result).n), n);
			}
			goto LA36_;
			LA40_: ;
			{
				result = (*n).typ;
			}
			LA36_: ;
		}
		LA31_: ;
	}
	break;
	case ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 31):
	case ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 36):
	{
		result = skipIntLit__magicsys_124(t, (*(*cl).c).Sup.idgen);
	}
	break;
	case ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 8):
	{
		tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* lookup_2;
		lookup_2 = lookup__semtypinst_158((*cl).typeMap, t);
		{
			if (!!((lookup_2 == ((tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA*) NIM_NIL)))) goto LA47_;
			result = lookup_2;
			{
				if (!!(((*result).kind == ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 8)))) goto LA51_;
				result = makeTypeDesc__concepts_49((*cl).c, result);
			}
			goto LA49_;
			LA51_: ;
			{
				NIM_BOOL T54_;
				T54_ = (NIM_BOOL)0;
				T54_ = (((*t).flags &((NU64)1<<((NU)(((tyEnum_TTypeFlag__Vrztsndr9a9bj8bQ3cn49bwWw) 9))&63U)))!=0);
				if (T54_) goto LA55_;
				T54_ = (*cl).skipTypedesc;
				LA55_: ;
				if (!T54_) goto LA56_;
				result = base__types_63(result);
			}
			goto LA49_;
			LA56_: ;
			LA49_: ;
		}
		goto LA45_;
		LA47_: ;
		{
			tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* T61_;
			if (!!(((*(*t).sons->data[((NI) 0)]).kind == ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 0)))) goto LA59_;
			T61_ = NIM_NIL;
			T61_ = replaceTypeVarsT__semtypinst_178(cl, (*t).sons->data[((NI) 0)]);
			result = makeTypeDesc__concepts_49((*cl).c, T61_);
		}
		goto LA45_;
		LA59_: ;
		LA45_: ;
	}
	break;
	case ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 52):
	case ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 60):
	{
		result = t;
	}
	break;
	case ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 11):
	case ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 53):
	{
		tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* T84_;
		{
			NIM_BOOL T66_;
			NIM_BOOL T68_;
			T66_ = (NIM_BOOL)0;
			T66_ = ((*t).sym == ((tyObject_TSym__3r34mwqcVmg5JFNmiaVncw*) NIM_NIL));
			if (T66_) goto LA67_;
			T68_ = (NIM_BOOL)0;
			T68_ = !(((*t).sym == ((tyObject_TSym__3r34mwqcVmg5JFNmiaVncw*) NIM_NIL)));
			if (!(T68_)) goto LA69_;
			T68_ = (((*(*t).sym).flags &((NU64)1<<((NU)(((tyEnum_TSymFlag__9be9c6fEXk5NwyPvxxb6toPA) 48))&63U)))!=0);
			LA69_: ;
			T66_ = T68_;
			LA67_: ;
			if (!T66_) goto LA70_;
			{
				RootObj* T76_;
				if (!(((NI) 100) < (*cl).recursionLimit)) goto LA74_;
				T76_ = NIM_NIL;
				T76_ = idTableGet__astalgo_64((*cl).localCache, &t->Sup);
				result = ((tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA*) (T76_));
				{
					if (!!((result == ((tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA*) NIM_NIL)))) goto LA79_;
					goto BeforeRet_;
				}
				LA79_: ;
			}
			LA74_: ;
			(*cl).recursionLimit += ((NI) 1);
		}
		LA70_: ;
		result = instCopyType__semtypinst_492(cl, t);
		idTablePut__astalgo_70((&(*cl).localCache), &t->Sup, (*((RootObj**) (&(result)))));
		{
			NI i;
			NI colontmp_;
			NI i_2;
			i = (NI)0;
			colontmp_ = (NI)0;
			colontmp_ = len__ast_3990(result);
			i_2 = ((NI) 1);
			{
				while (1) {
					if (!(i_2 < colontmp_)) goto LA83;
					i = i_2;
					asgnRef((void**) (&(*result).sons->data[i]), replaceTypeVarsT__semtypinst_178(cl, (*result).sons->data[i]));
					i_2 += ((NI) 1);
				} LA83: ;
			}
		}
		T84_ = NIM_NIL;
		T84_ = lastSon__ast_3731(result);
		propagateToOwner__ast_4207(result, T84_, NIM_TRUE);
	}
	break;
	default:
	{
		{
			NIM_BOOL T88_;
			T88_ = (NIM_BOOL)0;
			T88_ = containsGenericType__types_3412(t);
			if (!T88_) goto LA89_;
			{
				NIM_BOOL T93_;
				NIM_BOOL T95_;
				T93_ = (NIM_BOOL)0;
				T93_ = ((*t).sym == ((tyObject_TSym__3r34mwqcVmg5JFNmiaVncw*) NIM_NIL));
				if (T93_) goto LA94_;
				T95_ = (NIM_BOOL)0;
				T95_ = !(((*t).sym == ((tyObject_TSym__3r34mwqcVmg5JFNmiaVncw*) NIM_NIL)));
				if (!(T95_)) goto LA96_;
				T95_ = (((*(*t).sym).flags &((NU64)1<<((NU)(((tyEnum_TSymFlag__9be9c6fEXk5NwyPvxxb6toPA) 48))&63U)))!=0);
				LA96_: ;
				T93_ = T95_;
				LA94_: ;
				if (!T93_) goto LA97_;
				{
					RootObj* T103_;
					if (!(((NI) 100) < (*cl).recursionLimit)) goto LA101_;
					T103_ = NIM_NIL;
					T103_ = idTableGet__astalgo_64((*cl).localCache, &t->Sup);
					result = ((tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA*) (T103_));
					{
						if (!!((result == ((tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA*) NIM_NIL)))) goto LA106_;
						goto BeforeRet_;
					}
					LA106_: ;
				}
				LA101_: ;
				(*cl).recursionLimit += ((NI) 1);
			}
			LA97_: ;
			result = instCopyType__semtypinst_492(cl, t);
			(*result).size = IL64(-1);
			idTablePut__astalgo_70((&(*cl).localCache), &t->Sup, (*((RootObj**) (&(result)))));
			{
				NI i_3;
				NI colontmp__2;
				NI i_4;
				i_3 = (NI)0;
				colontmp__2 = (NI)0;
				colontmp__2 = len__ast_3990(result);
				i_4 = ((NI) 0);
				{
					while (1) {
						if (!(i_4 < colontmp__2)) goto LA110;
						i_3 = i_4;
						{
							tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* r;
							if (!!(((*result).sons->data[i_3] == ((tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA*) NIM_NIL)))) goto LA113_;
							{
								tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw T119_;
								NimStringDesc* T125_;
								NimStringDesc* T126_;
								if (!((*(*result).sons->data[i_3]).kind == ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 10))) goto LA117_;
								{
									if (!!(((*t).sym == ((tyObject_TSym__3r34mwqcVmg5JFNmiaVncw*) NIM_NIL)))) goto LA122_;
									T119_ = (*(*t).sym).info;
								}
								goto LA120_;
								LA122_: ;
								{
									T119_ = (*cl).info;
								}
								LA120_: ;
								T125_ = NIM_NIL;
								T126_ = NIM_NIL;
								T126_ = typeToString__types_50((*result).sons->data[i_3], ((tyEnum_TPreferedDesc__lx9aDnWjKktcSUo0yfjOvMg) 1));
								T125_ = rawNewString((T126_ ? T126_->Sup.len : 0) + ((*(*(*t).owner).name).s ? (*(*(*t).owner).name).s->Sup.len : 0) + 89);
appendString(T125_, ((NimStringDesc*) &TM__ro83HSRkGiU2zIkT6iR9aSA_17));
appendString(T125_, T126_);
appendString(T125_, ((NimStringDesc*) &TM__ro83HSRkGiU2zIkT6iR9aSA_18));
appendString(T125_, (*(*(*t).owner).name).s);
appendString(T125_, ((NimStringDesc*) &TM__ro83HSRkGiU2zIkT6iR9aSA_14));
								liMessage__msgs_1128((*(*(*cl).c).graph).config, T119_, ((tyEnum_TMsgKind__J0cVyqzpFKvufCivtQUgHQ) 15), T125_, ((tyEnum_TErrorHandling__sOC1wCv9bUYRquMih1VRi3w) 0), TM__ro83HSRkGiU2zIkT6iR9aSA_19, NIM_FALSE);
							}
							LA117_: ;
							r = replaceTypeVarsT__semtypinst_178(cl, (*result).sons->data[i_3]);
							{
								tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* r2;
								if (!((*result).kind == ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 17))) goto LA129_;
								r2 = skipTypes__ast_3723(r, TM__ro83HSRkGiU2zIkT6iR9aSA_20);
								{
									if (!((*r2).kind == ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 21) || (*r2).kind == ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 22))) goto LA133_;
									r = skipTypes__ast_3723(r2, TM__ro83HSRkGiU2zIkT6iR9aSA_21);
								}
								LA133_: ;
							}
							LA129_: ;
							asgnRef((void**) (&(*result).sons->data[i_3]), r);
							{
								NIM_BOOL T137_;
								T137_ = (NIM_BOOL)0;
								T137_ = !(((*result).kind == ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 16)));
								if (T137_) goto LA138_;
								T137_ = !((i_3 == ((NI) 0)));
								LA138_: ;
								if (!T137_) goto LA139_;
								propagateToOwner__ast_4207(result, r, NIM_TRUE);
							}
							LA139_: ;
						}
						LA113_: ;
						i_4 += ((NI) 1);
					} LA110: ;
				}
			}
			asgnRef((void**) (&(*result).n), replaceTypeVarsN__semtypinst_130(cl, (*result).n, ((*result).kind == ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 25))));
			switch ((*result).kind) {
			case ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 16):
			{
				tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* idx;
				idx = (*result).sons->data[((NI) 0)];
				{
					NimStringDesc* argX60gensym195_;
					if (!!(!(((*idx).kind == ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 60))))) goto LA144_;
					argX60gensym195_ = toFileLineCol__msgs_625(TM__ro83HSRkGiU2zIkT6iR9aSA_25);
					internalErrorImpl__msgs_1441((*(*(*cl).c).graph).config, unknownLineInfo__lineinfos_284, argX60gensym195_, TM__ro83HSRkGiU2zIkT6iR9aSA_25);
				}
				LA144_: ;
			}
			break;
			case ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 17):
			case ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 18):
			{
				propagateFieldFlags__semtypinst_786(result, (*result).n);
				{
					NIM_BOOL T149_;
					T149_ = (NIM_BOOL)0;
					T149_ = ((*result).kind == ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 17));
					if (!(T149_)) goto LA150_;
					T149_ = (*(*cl).c).computeRequiresInit((*cl).c, result);
					LA150_: ;
					if (!T149_) goto LA151_;
					(*result).flags |= ((NU64)1)<<((((tyEnum_TTypeFlag__Vrztsndr9a9bj8bQ3cn49bwWw) 18)) & 63);
				}
				LA151_: ;
			}
			break;
			case ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 25):
			{
				eraseVoidParams__semtypinst_694(result);
				skipIntLiteralParams__semtypinst_750(result, (*(*cl).c).Sup.idgen);
			}
			break;
			case ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 20):
			{
				asgnRef((void**) (&(*result).sons->data[((NI) 0)]), skipTypes__ast_3723((*result).sons->data[((NI) 0)], TM__ro83HSRkGiU2zIkT6iR9aSA_26));
			}
			break;
			default:
			{
			}
			break;
			}
		}
		goto LA86_;
		LA89_: ;
		{
			result = t;
			{
				NIM_BOOL T159_;
				NIM_BOOL T160_;
				NIM_BOOL T161_;
				NI T163_;
				tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* T168_;
				T159_ = (NIM_BOOL)0;
				T160_ = (NIM_BOOL)0;
				T161_ = (NIM_BOOL)0;
				T161_ = ((*t).kind == ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 22));
				if (!(T161_)) goto LA162_;
				T163_ = (NI)0;
				T163_ = len__ast_3990(t);
				T161_ = (((NI) 0) < T163_);
				LA162_: ;
				T160_ = T161_;
				if (!(T160_)) goto LA164_;
				T160_ = ((*(*t).sons->data[((NI) 0)]).kind == ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 17));
				LA164_: ;
				T159_ = T160_;
				if (!(T159_)) goto LA165_;
				T159_ = !(((*(*t).sons->data[((NI) 0)]).n == ((tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw*) NIM_NIL)));
				LA165_: ;
				if (!T159_) goto LA166_;
				T168_ = NIM_NIL;
				T168_ = replaceObjBranches__semtypinst_277((&(*cl)), (*(*t).sons->data[((NI) 0)]).n);
				(void)(T168_);
			}
			goto LA157_;
			LA166_: ;
			{
				NIM_BOOL T170_;
				T170_ = (NIM_BOOL)0;
				T170_ = !(((*result).n == ((tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw*) NIM_NIL)));
				if (!(T170_)) goto LA171_;
				T170_ = ((*t).kind == ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 17));
				LA171_: ;
				if (!T170_) goto LA172_;
				(*result).size = IL64(-1);
				asgnRef((void**) (&(*result).n), replaceObjBranches__semtypinst_277((&(*cl)), (*result).n));
			}
			goto LA157_;
			LA172_: ;
			LA157_: ;
		}
		LA86_: ;
	}
	break;
	}
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA*, replaceTypeVarsT__semtypinst_178)(tyObject_TReplTypeVars__itU2h89a2PcJoJ5bHADfePw* cl, tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* t) {
	tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* result;
	result = NIM_NIL;
	result = replaceTypeVarsTAux__semtypinst_124(cl, t);
	return result;
}
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, hasValuelessStatics__semtypinst_329)(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n) {
	NIM_BOOL result;
{	result = (NIM_BOOL)0;
	{
		NI T3_;
		NIM_BOOL T6_;
		T3_ = (NI)0;
		T3_ = safeLen__ast_3148(n);
		if (!(T3_ == ((NI) 0))) goto LA4_;
		T6_ = (NIM_BOOL)0;
		T6_ = ((*n).typ == ((tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA*) NIM_NIL));
		if (T6_) goto LA7_;
		T6_ = ((*(*n).typ).kind == ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 60));
		LA7_: ;
		result = T6_;
	}
	goto LA1_;
	LA4_: ;
	{
		{
			tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* x;
			x = NIM_NIL;
			{
				NI i;
				NI colontmp_;
				NI i_2;
				i = (NI)0;
				colontmp_ = (NI)0;
				colontmp_ = safeLen__ast_3148(n);
				i_2 = ((NI) 0);
				{
					while (1) {
						if (!(i_2 < colontmp_)) goto LA12;
						i = i_2;
						x = (*n)._kind_6.sons->data[i];
						{
							NIM_BOOL T15_;
							T15_ = (NIM_BOOL)0;
							T15_ = hasValuelessStatics__semtypinst_329(x);
							if (!T15_) goto LA16_;
							result = NIM_TRUE;
							goto BeforeRet_;
						}
						LA16_: ;
						i_2 += ((NI) 1);
					} LA12: ;
				}
			}
		}
		result = NIM_FALSE;
	}
	LA1_: ;
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, isTypeParam__semtypinst_227)(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n) {
	NIM_BOOL result;
	NIM_BOOL T1_;
	NIM_BOOL T3_;
	NIM_BOOL T5_;
{	result = (NIM_BOOL)0;
	T1_ = (NIM_BOOL)0;
	T1_ = ((*n).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 3));
	if (!(T1_)) goto LA2_;
	T3_ = (NIM_BOOL)0;
	T3_ = ((*(*n)._kind_4.sym).kind == ((tyEnum_TSymKind__sjiB9b9aO1FRPetW6gPYZbfw) 4));
	if (T3_) goto LA4_;
	T5_ = (NIM_BOOL)0;
	T5_ = ((*(*n)._kind_4.sym).kind == ((tyEnum_TSymKind__sjiB9b9aO1FRPetW6gPYZbfw) 7));
	if (!(T5_)) goto LA6_;
	T5_ = (((*(*n)._kind_4.sym).flags &((NU64)1<<((NU)(((tyEnum_TSymFlag__9be9c6fEXk5NwyPvxxb6toPA) 2))&63U)))!=0);
	LA6_: ;
	T3_ = T5_;
	LA4_: ;
	T1_ = T3_;
	LA2_: ;
	result = T1_;
	goto BeforeRet_;
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw*, reResolveCallsWithTypedescParams__semtypinst_246)(tyObject_TReplTypeVars__itU2h89a2PcJoJ5bHADfePw* cl, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n) {
	tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* result;
{	result = NIM_NIL;
	{
		NIM_BOOL T3_;
		NIM_BOOL needsFixing;
		T3_ = (NIM_BOOL)0;
		T3_ = ((*n).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 27) || (*n).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 29) || (*n).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 30) || (*n).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 31) || (*n).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 26) || (*n).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 28) || (*n).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 32));
		if (!(T3_)) goto LA4_;
		T3_ = (((*(*(*n)._kind_6.sons->data[((NI) 0)])._kind_4.sym).flags &((NU64)1<<((NU)(((tyEnum_TSymFlag__9be9c6fEXk5NwyPvxxb6toPA) 2))&63U)))!=0);
		LA4_: ;
		if (!T3_) goto LA5_;
		needsFixing = NIM_FALSE;
		{
			NI i;
			NI colontmp_;
			NI i_2;
			i = (NI)0;
			colontmp_ = (NI)0;
			colontmp_ = safeLen__ast_3148(n);
			i_2 = ((NI) 1);
			{
				while (1) {
					if (!(i_2 < colontmp_)) goto LA9;
					i = i_2;
					{
						NIM_BOOL T12_;
						T12_ = (NIM_BOOL)0;
						T12_ = isTypeParam__semtypinst_227((*n)._kind_6.sons->data[i]);
						if (!T12_) goto LA13_;
						needsFixing = NIM_TRUE;
					}
					LA13_: ;
					i_2 += ((NI) 1);
				} LA9: ;
			}
		}
		{
			if (!needsFixing) goto LA17_;
			asgnRef((void**) (&(*n)._kind_6.sons->data[((NI) 0)]), newSymNode__ast_3704((*(*(*n)._kind_6.sons->data[((NI) 0)])._kind_4.sym).owner));
			result = (*(*cl).c).semOverloadedCall((*cl).c, n, n, 12288, 0);
			goto BeforeRet_;
		}
		LA17_: ;
	}
	LA5_: ;
	{
		NI i_3;
		NI colontmp__2;
		NI i_4;
		i_3 = (NI)0;
		colontmp__2 = (NI)0;
		colontmp__2 = safeLen__ast_3148(n);
		i_4 = ((NI) 0);
		{
			while (1) {
				if (!(i_4 < colontmp__2)) goto LA21;
				i_3 = i_4;
				asgnRef((void**) (&(*n)._kind_6.sons->data[i_3]), reResolveCallsWithTypedescParams__semtypinst_246(cl, (*n)._kind_6.sons->data[i_3]));
				i_4 += ((NI) 1);
			} LA21: ;
		}
	}
	result = n;
	goto BeforeRet_;
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw*, replaceTypeVarsN__semtypinst_130)(tyObject_TReplTypeVars__itU2h89a2PcJoJ5bHADfePw* cl, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n, NI start) {
	tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* result;
{	result = NIM_NIL;
	{
		if (!(n == ((tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw*) NIM_NIL))) goto LA3_;
		goto BeforeRet_;
	}
	LA3_: ;
	result = copyNode__ast_4324(n);
	{
		if (!!(((*n).typ == ((tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA*) NIM_NIL)))) goto LA7_;
		asgnRef((void**) (&(*result).typ), replaceTypeVarsT__semtypinst_178(cl, (*n).typ));
	}
	LA7_: ;
	switch ((*n).kind) {
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 0) ... ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 2):
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 4) ... ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 23):
	{
	}
	break;
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 57):
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 56):
	{
		result = n;
	}
	break;
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 3):
	{
		asgnRef((void**) (&(*result)._kind_4.sym), replaceTypeVarsS__semtypinst_127(cl, (*n)._kind_4.sym));
		{
			if (!((*(*(*result)._kind_4.sym).typ).kind == ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 63))) goto LA14_;
			result = newNodeI__ast_3320(((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 138), (*n).info);
		}
		LA14_: ;
	}
	break;
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 140):
	{
		tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* branch;
		branch = ((tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw*) NIM_NIL);
		{
			NI i;
			NI colontmp_;
			NI i_2;
			i = (NI)0;
			colontmp_ = (NI)0;
			colontmp_ = len__ast_3155(n);
			i_2 = ((NI) 0);
			{
				while (1) {
					tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* it;
					if (!(i_2 < colontmp_)) goto LA19;
					i = i_2;
					it = (*n)._kind_6.sons->data[i];
					{
						if (!(it == ((tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw*) NIM_NIL))) goto LA22_;
						illFormedAst__semdata_1101(n, (*(*(*cl).c).graph).config);
					}
					LA22_: ;
					switch ((*it).kind) {
					case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 86):
					{
						tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* cond;
						checkSonsLen__semdata_1107(it, ((NI) 2), (*(*(*cl).c).graph).config);
						cond = prepareNode__semtypinst_182(cl, (*it)._kind_6.sons->data[((NI) 0)]);
						{
							NIM_BOOL T27_;
							tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* e;
							T27_ = (NIM_BOOL)0;
							T27_ = hasValuelessStatics__semtypinst_329(cond);
							if (!!(T27_)) goto LA28_;
							e = (*(*cl).c).semConstExpr((*cl).c, cond, ((tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA*) NIM_NIL));
							{
								if (!!(((*e).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 6)))) goto LA32_;
								internalErrorImpl__msgs_1441((*(*(*cl).c).graph).config, (*e).info, ((NimStringDesc*) &TM__ro83HSRkGiU2zIkT6iR9aSA_27), TM__ro83HSRkGiU2zIkT6iR9aSA_29);
							}
							LA32_: ;
							{
								NIM_BOOL T36_;
								T36_ = (NIM_BOOL)0;
								T36_ = !(((*e)._kind_1.intVal == IL64(0)));
								if (!(T36_)) goto LA37_;
								T36_ = (branch == ((tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw*) NIM_NIL));
								LA37_: ;
								if (!T36_) goto LA38_;
								branch = (*it)._kind_6.sons->data[((NI) 1)];
							}
							LA38_: ;
						}
						LA28_: ;
					}
					break;
					case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 88):
					{
						checkSonsLen__semdata_1107(it, ((NI) 1), (*(*(*cl).c).graph).config);
						{
							if (!(branch == ((tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw*) NIM_NIL))) goto LA43_;
							branch = (*it)._kind_6.sons->data[((NI) 0)];
						}
						LA43_: ;
					}
					break;
					default:
					{
						illFormedAst__semdata_1101(n, (*(*(*cl).c).graph).config);
					}
					break;
					}
					i_2 += ((NI) 1);
				} LA19: ;
			}
		}
		{
			if (!!((branch == ((tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw*) NIM_NIL)))) goto LA48_;
			result = replaceTypeVarsN__semtypinst_130(cl, branch, ((NI) 0));
		}
		goto LA46_;
		LA48_: ;
		{
			result = newNodeI__ast_3320(((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 138), (*n).info);
		}
		LA46_: ;
	}
	break;
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 62):
	{
		tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n_2;
		n_2 = prepareNode__semtypinst_182(cl, n);
		n_2 = reResolveCallsWithTypedescParams__semtypinst_246(cl, n_2);
		{
			if (!(*cl).allowMetaTypes) goto LA54_;
			result = n_2;
		}
		goto LA52_;
		LA54_: ;
		{
			result = (*(*cl).c).semExpr((*cl).c, n_2, 0, ((tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA*) NIM_NIL));
		}
		LA52_: ;
		{
			if (!!((*cl).allowMetaTypes)) goto LA59_;
		}
		LA59_: ;
	}
	break;
	default:
	{
		{
			NI T64_;
			NI T67_;
			T64_ = (NI)0;
			T64_ = len__ast_3155(n);
			if (!(((NI) 0) < T64_)) goto LA65_;
			T67_ = (NI)0;
			T67_ = len__ast_3155(n);
			newSons__semtypinst_416(result, T67_);
			{
				if (!(((NI) 0) < start)) goto LA70_;
				asgnRef((void**) (&(*result)._kind_6.sons->data[((NI) 0)]), (*n)._kind_6.sons->data[((NI) 0)]);
			}
			LA70_: ;
			{
				NI i_3;
				NI colontmp__2;
				NI i_4;
				i_3 = (NI)0;
				colontmp__2 = (NI)0;
				colontmp__2 = len__ast_3155(n);
				i_4 = start;
				{
					while (1) {
						if (!(i_4 < colontmp__2)) goto LA74;
						i_3 = i_4;
						asgnRef((void**) (&(*result)._kind_6.sons->data[i_3]), replaceTypeVarsN__semtypinst_130(cl, (*n)._kind_6.sons->data[i_3], ((NI) 0)));
						i_4 += ((NI) 1);
					} LA74: ;
				}
			}
		}
		LA65_: ;
	}
	break;
	}
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw*, replaceTypesInBody__semtypinst_1024)(tyObject_TContext__TE0bwjD2I16QW6s9c4AgPvw* p, tyObject_TIdTable__Cs7vbulfMjKciTA2Uv9b6vQ pt, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n, tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* owner, NIM_BOOL allowMetaTypes) {
	tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* result;
	tyObject_LayeredIdTablecolonObjectType___9aSR8D74Pb4ozXN6gEJ9a1Pw* typeMap;
	tyObject_TReplTypeVars__itU2h89a2PcJoJ5bHADfePw cl;
	result = NIM_NIL;
	typeMap = initLayeredTypeMap__semtypinst_134(pt);
	nimZeroMem((void*)(&cl), sizeof(tyObject_TReplTypeVars__itU2h89a2PcJoJ5bHADfePw));
	initTypeVars__semtypinst_1018(p, typeMap, (*n).info, owner, (&cl));
	cl.allowMetaTypes = allowMetaTypes;
	pushInfoContext__msgs_500((*(*p).graph).config, (*n).info, ((NimStringDesc*) NIM_NIL));
	result = replaceTypeVarsN__semtypinst_130((&cl), n, ((NI) 0));
	popInfoContext__msgs_517((*(*p).graph).config);
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, recomputeFieldPositions__semtypinst_1042)(tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* t, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* obj, NI* currPosition) {
	{
		NIM_BOOL T3_;
		NIM_BOOL T4_;
		NI T6_;
		tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* b;
		T3_ = (NIM_BOOL)0;
		T4_ = (NIM_BOOL)0;
		T4_ = !((t == ((tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA*) NIM_NIL)));
		if (!(T4_)) goto LA5_;
		T6_ = (NI)0;
		T6_ = len__ast_3990(t);
		T4_ = (((NI) 0) < T6_);
		LA5_: ;
		T3_ = T4_;
		if (!(T3_)) goto LA7_;
		T3_ = !(((*t).sons->data[((NI) 0)] == ((tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA*) NIM_NIL)));
		LA7_: ;
		if (!T3_) goto LA8_;
		b = skipTypes__ast_3723((*t).sons->data[((NI) 0)], TM__ro83HSRkGiU2zIkT6iR9aSA_31);
		recomputeFieldPositions__semtypinst_1042(b, (*b).n, currPosition);
	}
	LA8_: ;
	switch ((*obj).kind) {
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 138):
	{
		{
			NI i;
			NI colontmp_;
			NI i_2;
			i = (NI)0;
			colontmp_ = (NI)0;
			colontmp_ = len__ast_3155(obj);
			i_2 = ((NI) 0);
			{
				while (1) {
					if (!(i_2 < colontmp_)) goto LA13;
					i = i_2;
					recomputeFieldPositions__semtypinst_1042(((tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA*) NIM_NIL), (*obj)._kind_6.sons->data[i], currPosition);
					i_2 += ((NI) 1);
				} LA13: ;
			}
		}
	}
	break;
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 139):
	{
		recomputeFieldPositions__semtypinst_1042(((tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA*) NIM_NIL), (*obj)._kind_6.sons->data[((NI) 0)], currPosition);
		{
			NI i_3;
			NI colontmp__2;
			NI i_4;
			i_3 = (NI)0;
			colontmp__2 = (NI)0;
			colontmp__2 = len__ast_3155(obj);
			i_4 = ((NI) 1);
			{
				while (1) {
					tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* T18_;
					if (!(i_4 < colontmp__2)) goto LA17;
					i_3 = i_4;
					T18_ = NIM_NIL;
					T18_ = lastSon__ast_4833((*obj)._kind_6.sons->data[i_3]);
					recomputeFieldPositions__semtypinst_1042(((tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA*) NIM_NIL), T18_, currPosition);
					i_4 += ((NI) 1);
				} LA17: ;
			}
		}
	}
	break;
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 3):
	{
		(*(*obj)._kind_4.sym).position = (*currPosition);
		(*currPosition) += ((NI) 1);
	}
	break;
	default:
	{
	}
	break;
	}
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA*, generateTypeInstance__semtypinst_1086)(tyObject_TContext__TE0bwjD2I16QW6s9c4AgPvw* p, tyObject_TIdTable__Cs7vbulfMjKciTA2Uv9b6vQ pt, tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw info, tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* t) {
	tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* result;
	tyObject_LayeredIdTablecolonObjectType___9aSR8D74Pb4ozXN6gEJ9a1Pw* typeMap;
	tyObject_TReplTypeVars__itU2h89a2PcJoJ5bHADfePw cl;
	tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* objType;
	result = NIM_NIL;
	typeMap = initLayeredTypeMap__semtypinst_134(pt);
	nimZeroMem((void*)(&cl), sizeof(tyObject_TReplTypeVars__itU2h89a2PcJoJ5bHADfePw));
	initTypeVars__semtypinst_1018(p, typeMap, info, ((tyObject_TSym__3r34mwqcVmg5JFNmiaVncw*) NIM_NIL), (&cl));
	pushInfoContext__msgs_500((*(*p).graph).config, info, ((NimStringDesc*) NIM_NIL));
	result = replaceTypeVarsT__semtypinst_178((&cl), t);
	popInfoContext__msgs_517((*(*p).graph).config);
	objType = skipTypes__ast_3723(result, TM__ro83HSRkGiU2zIkT6iR9aSA_30);
	{
		NI position;
		if (!((*objType).kind == ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 17))) goto LA3_;
		position = ((NI) 0);
		recomputeFieldPositions__semtypinst_1042(objType, (*objType).n, (&position));
	}
	LA3_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA*, prepareMetatypeForSigmatch__semtypinst_1100)(tyObject_TContext__TE0bwjD2I16QW6s9c4AgPvw* p, tyObject_TIdTable__Cs7vbulfMjKciTA2Uv9b6vQ pt, tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw info, tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* t) {
	tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* result;
	tyObject_LayeredIdTablecolonObjectType___9aSR8D74Pb4ozXN6gEJ9a1Pw* typeMap;
	tyObject_TReplTypeVars__itU2h89a2PcJoJ5bHADfePw cl;
	result = NIM_NIL;
	typeMap = initLayeredTypeMap__semtypinst_134(pt);
	nimZeroMem((void*)(&cl), sizeof(tyObject_TReplTypeVars__itU2h89a2PcJoJ5bHADfePw));
	initTypeVars__semtypinst_1018(p, typeMap, info, ((tyObject_TSym__3r34mwqcVmg5JFNmiaVncw*) NIM_NIL), (&cl));
	cl.allowMetaTypes = NIM_TRUE;
	pushInfoContext__msgs_500((*(*p).graph).config, info, ((NimStringDesc*) NIM_NIL));
	result = replaceTypeVarsT__semtypinst_178((&cl), t);
	popInfoContext__msgs_517((*(*p).graph).config);
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, checkConstructedType__semtypinst_26)(tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ* conf, tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw info, tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* typ) {
	tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* t;
	t = skipTypes__ast_3723(typ, TM__ro83HSRkGiU2zIkT6iR9aSA_32);
	{
		if (!((*t).kind == ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 51) || (*t).kind == ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 54) || (*t).kind == ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 52) || (*t).kind == ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 53) || (*t).kind == ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 56) || (*t).kind == ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 57) || (*t).kind == ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 58) || (*t).kind == ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 59))) goto LA3_;
	}
	goto LA1_;
	LA3_: ;
	{
		NIM_BOOL T6_;
		T6_ = (NIM_BOOL)0;
		T6_ = ((*t).kind == ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 23) || (*t).kind == ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 47));
		if (!(T6_)) goto LA7_;
		T6_ = ((*(*t).sons->data[((NI) 0)]).kind == ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 23) || (*(*t).sons->data[((NI) 0)]).kind == ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 47));
		LA7_: ;
		if (!T6_) goto LA8_;
		liMessage__msgs_1128(conf, info, ((tyEnum_TMsgKind__J0cVyqzpFKvufCivtQUgHQ) 15), ((NimStringDesc*) &TM__ro83HSRkGiU2zIkT6iR9aSA_11), ((tyEnum_TErrorHandling__sOC1wCv9bUYRquMih1VRi3w) 0), TM__ro83HSRkGiU2zIkT6iR9aSA_33, NIM_FALSE);
	}
	goto LA1_;
	LA8_: ;
	{
		NIM_BOOL T11_;
		NI64 T12_;
		NimStringDesc* T16_;
		NimStringDesc* T17_;
		T11_ = (NIM_BOOL)0;
		T12_ = (NI64)0;
		T12_ = computeSize__types_3369(conf, t);
		T11_ = (T12_ == IL64(-2));
		if (T11_) goto LA13_;
		T11_ = isTupleRecursive__types_4060(t);
		LA13_: ;
		if (!T11_) goto LA14_;
		T16_ = NIM_NIL;
		T17_ = NIM_NIL;
		T17_ = typeToString__types_50(t, ((tyEnum_TPreferedDesc__lx9aDnWjKktcSUo0yfjOvMg) 0));
		T16_ = rawNewString((T17_ ? T17_->Sup.len : 0) + 28);
appendString(T16_, ((NimStringDesc*) &TM__ro83HSRkGiU2zIkT6iR9aSA_34));
appendString(T16_, T17_);
appendString(T16_, ((NimStringDesc*) &TM__ro83HSRkGiU2zIkT6iR9aSA_7));
		liMessage__msgs_1128(conf, info, ((tyEnum_TMsgKind__J0cVyqzpFKvufCivtQUgHQ) 15), T16_, ((tyEnum_TErrorHandling__sOC1wCv9bUYRquMih1VRi3w) 0), TM__ro83HSRkGiU2zIkT6iR9aSA_35, NIM_FALSE);
	}
	goto LA1_;
	LA14_: ;
	LA1_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, atmsemtypinstdotnim_DatInit000)(void) {
static TNimNode* TM__ro83HSRkGiU2zIkT6iR9aSA_2_2[2];
static TNimNode TM__ro83HSRkGiU2zIkT6iR9aSA_0[3];
NTIlayeredidtable58objecttype__9aSR8D74Pb4ozXN6gEJ9a1Pw_.size = sizeof(tyObject_LayeredIdTablecolonObjectType___9aSR8D74Pb4ozXN6gEJ9a1Pw);
NTIlayeredidtable58objecttype__9aSR8D74Pb4ozXN6gEJ9a1Pw_.align = NIM_ALIGNOF(tyObject_LayeredIdTablecolonObjectType___9aSR8D74Pb4ozXN6gEJ9a1Pw);
NTIlayeredidtable58objecttype__9aSR8D74Pb4ozXN6gEJ9a1Pw_.kind = 18;
NTIlayeredidtable58objecttype__9aSR8D74Pb4ozXN6gEJ9a1Pw_.base = 0;
NTIlayeredidtable58objecttype__9aSR8D74Pb4ozXN6gEJ9a1Pw_.flags = 2;
TM__ro83HSRkGiU2zIkT6iR9aSA_2_2[0] = &TM__ro83HSRkGiU2zIkT6iR9aSA_0[1];
TM__ro83HSRkGiU2zIkT6iR9aSA_0[1].kind = 1;
TM__ro83HSRkGiU2zIkT6iR9aSA_0[1].offset = offsetof(tyObject_LayeredIdTablecolonObjectType___9aSR8D74Pb4ozXN6gEJ9a1Pw, topLayer);
TM__ro83HSRkGiU2zIkT6iR9aSA_0[1].typ = (&NTItidtable__Cs7vbulfMjKciTA2Uv9b6vQ_);
TM__ro83HSRkGiU2zIkT6iR9aSA_0[1].name = "topLayer";
TM__ro83HSRkGiU2zIkT6iR9aSA_2_2[1] = &TM__ro83HSRkGiU2zIkT6iR9aSA_0[2];
TM__ro83HSRkGiU2zIkT6iR9aSA_0[2].kind = 1;
TM__ro83HSRkGiU2zIkT6iR9aSA_0[2].offset = offsetof(tyObject_LayeredIdTablecolonObjectType___9aSR8D74Pb4ozXN6gEJ9a1Pw, nextLayer);
TM__ro83HSRkGiU2zIkT6iR9aSA_0[2].typ = (&NTIlayeredidtable__bE7TGBjv9bCsVJO148OW9cHA_);
TM__ro83HSRkGiU2zIkT6iR9aSA_0[2].name = "nextLayer";
TM__ro83HSRkGiU2zIkT6iR9aSA_0[0].len = 2; TM__ro83HSRkGiU2zIkT6iR9aSA_0[0].kind = 2; TM__ro83HSRkGiU2zIkT6iR9aSA_0[0].sons = &TM__ro83HSRkGiU2zIkT6iR9aSA_2_2[0];
NTIlayeredidtable58objecttype__9aSR8D74Pb4ozXN6gEJ9a1Pw_.node = &TM__ro83HSRkGiU2zIkT6iR9aSA_0[0];
NTIlayeredidtable__bE7TGBjv9bCsVJO148OW9cHA_.size = sizeof(tyObject_LayeredIdTablecolonObjectType___9aSR8D74Pb4ozXN6gEJ9a1Pw*);
NTIlayeredidtable__bE7TGBjv9bCsVJO148OW9cHA_.align = NIM_ALIGNOF(tyObject_LayeredIdTablecolonObjectType___9aSR8D74Pb4ozXN6gEJ9a1Pw*);
NTIlayeredidtable__bE7TGBjv9bCsVJO148OW9cHA_.kind = 22;
NTIlayeredidtable__bE7TGBjv9bCsVJO148OW9cHA_.base = (&NTIlayeredidtable58objecttype__9aSR8D74Pb4ozXN6gEJ9a1Pw_);
NTIlayeredidtable__bE7TGBjv9bCsVJO148OW9cHA_.flags = 2;
NTIlayeredidtable__bE7TGBjv9bCsVJO148OW9cHA_.marker = Marker_tyRef__bE7TGBjv9bCsVJO148OW9cHA;
}

